@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/GenericInterface/Operation/Session/SessionCreate.pm - GenericInterface SessionCreate operation backend
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,10 +12,15 @@ package Kernel::GenericInterface::Operation::Session::SessionCreate;
 use strict;
 use warnings;
 
-use Kernel::GenericInterface::Operation::Common;
-use Kernel::GenericInterface::Operation::Session::Common;
 use Kernel::System::VariableCheck qw(IsStringWithData IsHashRefWithData);
 
+use base qw(
+    Kernel::GenericInterface::Operation::Common
+    Kernel::GenericInterface::Operation::Session::Common
+);
+
+our $ObjectManagerDisabled = 1;
+
 =head1 NAME
 
 Kernel::GenericInterface::Operation::Ticket::SessionCreate - GenericInterface Session Create Operation backend
@@ -42,10 +48,11 @@ sub new {
 
     # check needed objects
     for my $Needed (
-        qw(DebuggerObject ConfigObject MainObject LogObject TimeObject DBObject EncodeObject WebserviceID)
+        qw(DebuggerObject WebserviceID)
         )
     {
         if ( !$Param{$Needed} ) {
+
             return {
                 Success      => 0,
                 ErrorMessage => "Got no $Needed!"
@@ -55,10 +62,6 @@ sub new {
         $Self->{$Needed} = $Param{$Needed};
     }
 
-    # create additional objects
-    $Self->{CommonObject}        = Kernel::GenericInterface::Operation::Common->new( %{$Self} );
-    $Self->{SessionCommonObject} = Kernel::GenericInterface::Operation::Session::Common->new( %{$Self} );
-
     return $Self;
 }
 
@@ -89,7 +92,8 @@ sub Run {
 
     # check needed stuff
     if ( !IsHashRefWithData( $Param{Data} ) ) {
-        return $Self->{CommonObject}->ReturnError(
+
+        return $Self->ReturnError(
             ErrorCode    => 'SessionCreate.MissingParameter',
             ErrorMessage => "SessionCreate: The request is empty!",
         );
@@ -97,19 +101,21 @@ sub Run {
 
     for my $Needed (qw( Password )) {
         if ( !$Param{Data}->{$Needed} ) {
-            return $Self->{CommonObject}->ReturnError(
+
+            return $Self->ReturnError(
                 ErrorCode    => 'SessionCreate.MissingParameter',
                 ErrorMessage => "SessionCreate: $Needed parameter is missing!",
             );
         }
     }
 
-    my $SessionID = $Self->{SessionCommonObject}->CreateSessionID(
+    my $SessionID = $Self->CreateSessionID(
         %Param,
     );
 
     if ( !$SessionID ) {
-        return $Self->{CommonObject}->ReturnError(
+
+        return $Self->ReturnError(
             ErrorCode    => 'SessionCreate.AuthFail',
             ErrorMessage => "SessionCreate: Authorization failing!",
         );
