@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/GenericInterface/Transport.pm - GenericInterface network transport interface
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +12,11 @@ package Kernel::GenericInterface::Transport;
 use strict;
 use warnings;
 
+# prevent 'Used once' warning for Kernel::OM
+use Kernel::System::ObjectManager;
+
+our $ObjectManagerDisabled = 1;
+
 =head1 NAME
 
 Kernel::GenericInterface::Transport - GenericInterface network transport interface
@@ -27,53 +33,21 @@ Kernel::GenericInterface::Transport - GenericInterface network transport interfa
 
 create an object.
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Time;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
     use Kernel::GenericInterface::Debugger;
     use Kernel::GenericInterface::Transport;
 
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
     my $DebuggerObject = Kernel::GenericInterface::Debugger->new(
-        ConfigObject   => $ConfigObject,
-        EncodeObject   => $EncodeObject,
-        LogObject      => $LogObject,
-        MainObject     => $MainObject,
-        DebuggerObject => $DebuggerObject,
+        DebuggerConfig   => {
+            DebugThreshold  => 'debug',
+            TestMode        => 0,           # optional, in testing mode the data will not be written to the DB
+            # ...
+        },
+        WebserviceID      => 12,
+        CommunicationType => Requester, # Requester or Provider
+        RemoteIP          => 192.168.1.1, # optional
     );
     my $TransportObject = Kernel::GenericInterface::Transport->new(
-        ConfigObject  => $ConfigObject,
-        LogObject     => $LogObject,
-        DBObject      => $DBObject,
-        MainObject    => $MainObject,
-        TimeObject    => $TimeObject,
-        EncodeObject  => $EncodeObject,
-
+        DebuggerObject => $DebuggerObject,
         TransportConfig => {
             Type => 'HTTP::SOAP',
             Config => {
@@ -90,10 +64,7 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    for my $Needed (
-        qw(MainObject ConfigObject LogObject EncodeObject TimeObject DBObject DebuggerObject TransportConfig)
-        )
-    {
+    for my $Needed (qw( DebuggerObject TransportConfig)) {
         $Self->{$Needed} = $Param{$Needed} || return {
             Success => 0,
             Summary => "Got no $Needed!",
@@ -103,7 +74,7 @@ sub new {
     # select and instantiate the backend
     my $Backend = 'Kernel::GenericInterface::Transport::' . $Self->{TransportConfig}->{Type};
 
-    if ( !$Self->{MainObject}->Require($Backend) ) {
+    if ( !$Kernel::OM->Get('Kernel::System::Main')->Require($Backend) ) {
         return $Self->{DebuggerObject}->Error( Summary => "Backend $Backend not found." );
     }
     $Self->{BackendObject} = $Backend->new( %{$Self} );
@@ -139,6 +110,7 @@ sub ProviderProcessRequest {
 
     # make sure an operation is provided in success case
     if ( $Result->{Success} && !$Result->{Operation} ) {
+
         return $Self->{DebuggerObject}->Error(
             Summary => 'TransportObject backend did not return an operation',
         );
@@ -171,12 +143,14 @@ sub ProviderGenerateResponse {
     my ( $Self, %Param ) = @_;
 
     if ( !defined $Param{Success} ) {
+
         return $Self->{DebuggerObject}->Error(
             Summary => 'Missing parameter Success.',
         );
     }
 
     if ( $Param{Data} && ref $Param{Data} ne 'HASH' ) {
+
         return $Self->{DebuggerObject}->Error(
             Summary => 'Data is not a hash reference.',
         );
@@ -210,12 +184,14 @@ sub RequesterPerformRequest {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{Operation} ) {
+
         return $Self->{DebuggerObject}->Error(
             Summary => 'Missing parameter Operation.',
         );
     }
 
     if ( $Param{Data} && ref $Param{Data} ne 'HASH' ) {
+
         return $Self->{DebuggerObject}->Error(
             Summary => 'Data is not a hash reference.',
         );
