@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AdminCustomerUserGroup.pm - to add/update/delete groups <-> users
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -394,8 +395,9 @@ sub _Change {
         Name => "ChangeHeading$VisibleType{$NeType}",
     );
 
+    TYPE:
     for my $Type ( @{ $Self->{ConfigObject}->Get('System::Customer::Permission') } ) {
-        next if !$Type;
+        next TYPE if !$Type;
         my $Mark = $Type eq 'rw' ? "Highlight" : '';
         $Self->{LayoutObject}->Block(
             Name => 'ChangeHeader',
@@ -464,8 +466,9 @@ sub _Change {
             },
         );
 
+        TYPE:
         for my $Type ( @{ $Self->{ConfigObject}->Get('System::Customer::Permission') } ) {
-            next if !$Type;
+            next TYPE if !$Type;
             my $Mark     = $Type eq 'rw'        ? "Highlight"          : '';
             my $Selected = $Param{$Type}->{$ID} ? ' checked="checked"' : '';
             $Self->{LayoutObject}->Block(
