@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AdminEmail.pm - to send a email to all agents
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +12,8 @@ package Kernel::Modules::AdminEmail;
 use strict;
 use warnings;
 
+use Kernel::System::CustomerGroup;
+use Kernel::System::CustomerUser;
 use Kernel::System::Email;
 
 sub new {
