@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AdminMailAccount.pm - to add/update/delete MailAccount accounts
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -299,10 +300,11 @@ sub _Overview {
 
             my @List = $Self->{ValidObject}->ValidIDsGet();
 
+            LIST_ELEMENT:
             for my $ListElement (@List) {
                 if ( $Data{ValidID} eq $ListElement ) {
                     $Data{Invalid} = '';
-                    last;
+                    last LIST_ELEMENT;
                 }
                 else {
                     $Data{Invalid} = 'Invalid';
