@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AdminNotificationEvent.pm - to manage event-based notifications
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -50,6 +51,13 @@ sub new {
     $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
     $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
 
+    $Self->{Config} = $Self->{ConfigObject}->Get("Frontend::Admin::$Self->{Action}");
+
+    $Self->{RichText} = $Self->{ConfigObject}->Get('Frontend::RichText');
+    if ( $Self->{RichText} && !$Self->{Config}->{RichText} ) {
+        $Self->{RichText} = 0;
+    }
+
     # get the dynamic fields for this screen
     $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
         Valid      => 1,
@@ -67,6 +75,12 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    # set type for notifications
+    my $NotificationType = 'text/plain';
+    if ( $Self->{RichText} ) {
+        $NotificationType = 'text/html';
+    }
+
     # ------------------------------------------------------------ #
     # change
     # ------------------------------------------------------------ #
@@ -104,6 +118,7 @@ sub Run {
         {
             $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
+        PARAMETER:
         for my $Parameter (
             qw(Recipients RecipientAgents RecipientGroups RecipientRoles RecipientEmail
             Events StateID QueueID PriorityID LockID TypeID ServiceID SLAID
@@ -113,7 +128,7 @@ sub Run {
             )
         {
             my @Data = $Self->{ParamObject}->GetArray( Param => $Parameter );
-            next if !@Data;
+            next PARAMETER if !@Data;
             $GetParam{Data}->{$Parameter} = \@Data;
         }
 
@@ -173,13 +188,13 @@ sub Run {
             }
         }
 
-        # required Article filter only on ArticleCreate and Article Send event
+        # required Article filter only on ArticleCreate and ArticleSend event
         # if isn't selected at least one of the article filter fields, notification isn't updated
         if ( !$ArticleFilterMissing ) {
             $Ok = $Self->{NotificationEventObject}->NotificationUpdate(
                 %GetParam,
                 Charset => $Self->{LayoutObject}->{UserCharset},
-                Type    => 'text/plain',
+                Type    => $NotificationType,
                 UserID  => $Self->{UserID},
             );
         }
@@ -194,6 +209,7 @@ sub Run {
                 Data         => \%Param,
             );
             $Output .= $Self->{LayoutObject}->Footer();
+
             return $Output;
         }
         else {
@@ -269,6 +285,7 @@ sub Run {
         {
             $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
+        PARAMETER:
         for my $Parameter (
             qw(Recipients RecipientAgents RecipientRoles RecipientGroups RecipientEmail Events StateID QueueID
             PriorityID LockID TypeID ServiceID SLAID CustomerID CustomerUserID
@@ -277,7 +294,7 @@ sub Run {
             )
         {
             my @Data = $Self->{ParamObject}->GetArray( Param => $Parameter );
-            next if !@Data;
+            next PARAMETER if !@Data;
             $GetParam{Data}->{$Parameter} = \@Data;
         }
 
@@ -343,7 +360,7 @@ sub Run {
             $ID = $Self->{NotificationEventObject}->NotificationAdd(
                 %GetParam,
                 Charset => $Self->{LayoutObject}->{UserCharset},
-                Type    => 'text/plain',
+                Type    => $NotificationType,
                 UserID  => $Self->{UserID},
             );
         }
@@ -382,6 +399,7 @@ sub Run {
                 $GetParam{ArticleSubjectMatchServerError} = "ServerError";
                 $GetParam{ArticleBodyMatchServerError}    = "ServerError";
             }
+
             my $Output = $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
             $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
@@ -706,6 +724,36 @@ sub _Edit {
         );
     }
 
+    # add rich text editor
+    if ( $Self->{RichText} ) {
+
+        # make sure body is rich text (if body is based on config)
+        if ( $Param{Type} && $Param{Type} =~ m{text\/plain}xmsi ) {
+            $Param{Body} = $Self->{LayoutObject}->Ascii2RichText(
+                String => $Param{Body},
+            );
+        }
+
+        # use height/width defined for this screen
+        $Param{RichTextHeight} = $Self->{Config}->{RichTextHeight} || 0;
+        $Param{RichTextWidth}  = $Self->{Config}->{RichTextWidth}  || 0;
+
+        $Self->{LayoutObject}->Block(
+            Name => 'RichText',
+            Data => \%Param,
+        );
+    }
+    else {
+
+        # reformat from html to plain
+        if ( $Param{Type} && $Param{Type} =~ m{text\/html}xmsi && $Param{Body} ) {
+
+            $Param{Body} = $Self->{LayoutObject}->RichText2Ascii(
+                String => $Param{Body},
+            );
+        }
+    }
+
     $Param{ArticleTypesStrg} = $Self->{LayoutObject}->BuildSelection(
         Data        => { $Self->{TicketObject}->ArticleTypeList( Result => 'HASH' ), },
         Name        => 'ArticleTypeID',
@@ -755,10 +803,11 @@ sub _Edit {
     );
 
     # take over data fields
+    KEY:
     for my $Key (qw(RecipientEmail CustomerID CustomerUserID ArticleSubjectMatch ArticleBodyMatch))
     {
-        next if !$Param{Data}->{$Key};
-        next if !defined $Param{Data}->{$Key}->[0];
+        next KEY if !$Param{Data}->{$Key};
+        next KEY if !defined $Param{Data}->{$Key}->[0];
         $Param{$Key} = $Param{Data}->{$Key}->[0];
     }
 
