@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AdminPackageManager.pm - manage software packages
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,11 +13,14 @@ package Kernel::Modules::AdminPackageManager;
 use strict;
 use warnings;
 
-use XML::FeedPP;
-
+use Kernel::System::CloudService;
 use Kernel::System::Package;
+use Kernel::System::SystemData;
 use Kernel::System::Web::UploadCache;
-use Kernel::System::Cache;
+
+use Kernel::System::VariableCheck qw(:all);
+
+our $ObjectManagerDisabled = 1;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -34,7 +38,12 @@ sub new {
 
     $Self->{PackageObject}     = Kernel::System::Package->new(%Param);
     $Self->{UploadCacheObject} = Kernel::System::Web::UploadCache->new(%Param);
-    $Self->{CacheObject}       = Kernel::System::Cache->new(%Param);
+    $Self->{CacheObject}       = $Kernel::OM->Get('Kernel::System::Cache');
+    $Self->{SystemDataObject}  = Kernel::System::SystemData->new(%Param);
+    $Self->{RegistrationState} = $Self->{SystemDataObject}->SystemDataGet(
+        Key => 'Registration::State',
+    ) || '';
+    $Self->{CloudServiceObject} = Kernel::System::CloudService->new(%Param);
 
     return $Self;
 }
@@ -198,12 +207,12 @@ sub Run {
         my $Verified = $Self->{PackageObject}->PackageVerify(
             Package   => $Package,
             Structure => \%Structure,
-        ) || 'verified';
+        ) || 'unknown';
         my %VerifyInfo = $Self->{PackageObject}->PackageVerifyInfo();
 
         # translate description
         if ( $Self->{LayoutObject}->{LanguageObject} ) {
-            $VerifyInfo{Description} = $Self->{LayoutObject}->{LanguageObject}->Get(
+            $VerifyInfo{Description} = $Self->{LayoutObject}->{LanguageObject}->Translate(
                 $VerifyInfo{Description}
             );
         }
@@ -222,7 +231,36 @@ sub Run {
                 Version => $Version,
             },
         );
+
+        my @RepositoryList = $Self->{PackageObject}->RepositoryList(
+            Result => 'short',
+        );
+
+        # if visible property is not enable, return error screen
+        if (
+            defined $Structure{PackageIsVisible}
+            && exists $Structure{PackageIsVisible}->{Content}
+            && !$Structure{PackageIsVisible}->{Content}
+            )
+        {
+            return $Self->{LayoutObject}->ErrorScreen( Message => 'No such package!' );
+        }
+
+        PACKAGEACTION:
         for my $PackageAction (qw(DownloadLocal Rebuild Reinstall)) {
+
+            if (
+                $PackageAction eq 'DownloadLocal'
+                && (
+                    defined $Structure{PackageIsDownloadable}
+                    && exists $Structure{PackageIsDownloadable}->{Content}
+                    && !$Structure{PackageIsDownloadable}->{Content}
+                )
+                )
+            {
+                next PACKAGEACTION;
+            }
+
             $Self->{LayoutObject}->Block(
                 Name => 'Package' . $PackageAction,
                 Data => {
@@ -395,6 +433,26 @@ sub Run {
                                 %{$Hash},
                             },
                         );
+
+                        # check if is possible to download files
+                        if (
+                            !defined $Structure{PackageIsDownloadable}
+                            || (
+                                defined $Structure{PackageIsDownloadable}->{Content}
+                                && $Structure{PackageIsDownloadable}->{Content} eq '1'
+                            )
+                            )
+                        {
+                            $Self->{LayoutObject}->Block(
+                                Name => "PackageItemFilelistFileLink",
+                                Data => {
+                                    Name    => $Name,
+                                    Version => $Version,
+                                    %{$Hash},
+                                },
+                            );
+                        }
+
                         if ( $DeployInfo{File}->{ $Hash->{Location} } ) {
                             if ( $DeployInfo{File}->{ $Hash->{Location} } =~ /different/ ) {
                                 $Self->{LayoutObject}->Block(
@@ -451,9 +509,11 @@ sub Run {
         if ( !$Deployed ) {
             $Output .= $Self->{LayoutObject}->Notify(
                 Priority => 'Error',
-                Data     => "$Name $Version"
-                    . ' - $Text{"Package not correctly deployed! Please reinstall the package."}',
-                Link => '$Env{"Baselink"}Action=$Env{"Action"};Subaction=View;Name='
+                Data     => "$Name $Version - "
+                    . $Self->{LayoutObject}->{LanguageObject}
+                    ->Translate("Package not correctly deployed! Please reinstall the package."),
+                Link => $Self->{LayoutObject}->{Baselink}
+                    . 'Action=AdminPackageManager;Subaction=View;Name='
                     . $Name
                     . ';Version='
                     . $Version,
@@ -465,7 +525,9 @@ sub Run {
             $Output .= $Self->{LayoutObject}->Notify(
                 Priority => 'Error',
                 Data     => "$Name $Version - "
-                    . '$Text{"Package not verified by the OTRS Group! It is recommended not to use this package."}',
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate(
+                    "Package not verified by the OTRS Group! It is recommended not to use this package."
+                    ),
             );
         }
 
@@ -489,21 +551,39 @@ sub Run {
             Source => $Source,
             File   => $File,
         );
+
         if ( !$Package ) {
             return $Self->{LayoutObject}->ErrorScreen( Message => 'No such package!' );
         }
+        elsif ( substr( $Package, 0, length('ErrorMessage:') ) eq 'ErrorMessage:' ) {
+
+            # an error from the Package::CloudFileGet function
+            return $Self->{LayoutObject}->ErrorScreen( Message => $Package );
+        }
         my %Structure = $Self->{PackageObject}->PackageParse( String => $Package );
         $Self->{LayoutObject}->Block(
             Name => 'Package',
             Data => { %Param, %Frontend, },
         );
-        $Self->{LayoutObject}->Block(
-            Name => 'PackageDownloadRemote',
-            Data => {
-                %Param, %Frontend,
-                File => $File,
-            },
-        );
+
+        # allow to download only if package is allow to do it
+        if (
+            !defined $Structure{PackageIsDownloadable}
+            || (
+                defined $Structure{PackageIsDownloadable}->{Content}
+                && $Structure{PackageIsDownloadable}->{Content} eq '1'
+            )
+            )
+        {
+
+            $Self->{LayoutObject}->Block(
+                Name => 'PackageDownloadRemote',
+                Data => {
+                    %Param, %Frontend,
+                    File => $File,
+                },
+            );
+        }
 
         # check if file is requested
         if ($Location) {
@@ -651,6 +731,26 @@ sub Run {
                                 %{$Hash},
                             },
                         );
+
+                        # check if is possible to download files
+                        if (
+                            !defined $Structure{PackageIsDownloadable}
+                            || (
+                                defined $Structure{PackageIsDownloadable}->{Content}
+                                && $Structure{PackageIsDownloadable}->{Content} eq '1'
+                            )
+                            )
+                        {
+                            $Self->{LayoutObject}->Block(
+                                Name => "PackageItemFilelistFileLink",
+                                Data => {
+                                    Name    => $Structure{Name}->{Content},
+                                    Version => $Structure{Version}->{Content},
+                                    File    => $File,
+                                    %{$Hash},
+                                },
+                            );
+                        }
                     }
                     else {
                         $Self->{LayoutObject}->Block(
@@ -1195,9 +1295,24 @@ sub Run {
     if ( $Self->{ConfigObject}->Get('Package::RepositoryRoot') ) {
         %RepositoryRoot = $Self->{PackageObject}->PackageOnlineRepositories();
     }
+
+    # show cloud repo if system is registered
+    my $RepositoryCloudList;
+    if ( $Self->{RegistrationState} eq 'registered' ) {
+
+        $RepositoryCloudList =
+            $Self->{PackageObject}->RepositoryCloudList( NoCache => 1 );
+    }
+
+    # in case Source is present on repository cloud list
+    # the call for retrieving data about it, should be performed
+    # using the CloudService backend
+    my $FromCloud = ( $RepositoryCloudList->{$Source} ? 1 : 0 );
+
     $Frontend{SourceList} = $Self->{LayoutObject}->BuildSelection(
-        Data        => { %List, %RepositoryRoot, },
+        Data        => { %List, %RepositoryRoot, %{$RepositoryCloudList}, },
         Name        => 'Source',
+        Title       => 'Repository List',
         Max         => 40,
         Translation => 0,
         SelectedID  => $Source,
@@ -1208,9 +1323,11 @@ sub Run {
         Data => { %Param, %Frontend, },
     );
     if ($Source) {
+
         my @List = $Self->{PackageObject}->PackageOnlineList(
-            URL  => $Source,
-            Lang => $Self->{LayoutObject}->{UserLanguage},
+            URL       => $Source,
+            Lang      => $Self->{LayoutObject}->{UserLanguage},
+            FromCloud => $FromCloud,
         );
         if ( !@List ) {
             $OutputNotify .= $Self->{LayoutObject}->Notify(
@@ -1283,6 +1400,16 @@ sub Run {
 
     my @RepositoryList = $Self->{PackageObject}->RepositoryList();
 
+    # remove not visible packages
+    @RepositoryList = map {
+        (
+            !defined $_->{PackageIsVisible}
+                || ( $_->{PackageIsVisible}->{Content} && $_->{PackageIsVisible}->{Content} eq '1' )
+            )
+            ? $_
+            : ()
+    } @RepositoryList;
+
     # if there are no local packages to show, a msg is displayed
     if ( !@RepositoryList ) {
         $Self->{LayoutObject}->Block(
@@ -1297,6 +1424,8 @@ sub Run {
     }
 
     my %NotVerifiedPackages;
+    my %UnknownVerficationPackages;
+
     for my $Package (@RepositoryList) {
 
         my %Data = $Self->_MessageGet( Info => $Package->{Description} );
@@ -1337,16 +1466,28 @@ sub Run {
         }
 
         if ( $Package->{Status} eq 'installed' ) {
-            $Self->{LayoutObject}->Block(
-                Name => 'ShowLocalPackageUninstall',
-                Data => {
-                    %{$Package},
-                    Name    => $Package->{Name}->{Content},
-                    Version => $Package->{Version}->{Content},
-                    Vendor  => $Package->{Vendor}->{Content},
-                    URL     => $Package->{URL}->{Content},
-                },
-            );
+
+            if (
+                !defined $Package->{PackageIsRemovable}
+                || (
+                    defined $Package->{PackageIsRemovable}->{Content}
+                    && $Package->{PackageIsRemovable}->{Content} eq '1'
+                )
+                )
+            {
+
+                $Self->{LayoutObject}->Block(
+                    Name => 'ShowLocalPackageUninstall',
+                    Data => {
+                        %{$Package},
+                        Name    => $Package->{Name}->{Content},
+                        Version => $Package->{Version}->{Content},
+                        Vendor  => $Package->{Vendor}->{Content},
+                        URL     => $Package->{URL}->{Content},
+                    },
+                );
+            }
+
             if (
                 !$Self->{PackageObject}->DeployCheck(
                     Name    => $Package->{Name}->{Content},
@@ -1387,6 +1528,14 @@ sub Run {
         {
             $NotVerifiedPackages{ $Package->{Name}->{Content} } = $Package->{Version}->{Content};
         }
+        elsif (
+            $VerificationData{ $Package->{Name}->{Content} }
+            && $VerificationData{ $Package->{Name}->{Content} } eq 'unknown'
+            )
+        {
+            $UnknownVerficationPackages{ $Package->{Name}->{Content} } = $Package->{Version}->{Content};
+        }
+
     }
 
     # show file upload
@@ -1452,9 +1601,11 @@ sub Run {
     for my $ReinstallKey ( sort keys %NeedReinstall ) {
         $Output .= $Self->{LayoutObject}->Notify(
             Priority => 'Error',
-            Data     => "$ReinstallKey $NeedReinstall{$ReinstallKey}"
-                . ' - $Text{"Package not correctly deployed! Please reinstall the package."}',
-            Link => '$Env{"Baselink"}Action=$Env{"Action"};Subaction=View;Name='
+            Data     => "$ReinstallKey $NeedReinstall{$ReinstallKey} - "
+                . $Self->{LayoutObject}->{LanguageObject}
+                ->Translate("Package not correctly deployed! Please reinstall the package."),
+            Link => $Self->{LayoutObject}->{Baselink}
+                . 'Action=AdminPackageManager;Subaction=View;Name='
                 . $ReinstallKey
                 . ';Version='
                 . $NeedReinstall{$ReinstallKey},
@@ -1470,7 +1621,24 @@ sub Run {
         $Output .= $Self->{LayoutObject}->Notify(
             Priority => 'Error',
             Data     => "$Package $NotVerifiedPackages{$Package} - "
-                . '$Text{"Package not verified by the OTRS Group! It is recommended not to use this package."}',
+                . $Self->{LayoutObject}->{LanguageObject}->Translate(
+                "Package not verified by the OTRS Group! It is recommended not to use this package."
+                ),
+        );
+    }
+
+    VERIFICATION:
+    for my $Package ( sort keys %UnknownVerficationPackages ) {
+
+        next VERIFICATION if !$Package;
+        next VERIFICATION if !$UnknownVerficationPackages{$Package};
+
+        $Output .= $Self->{LayoutObject}->Notify(
+            Priority => 'Error',
+            Data     => "$Package $UnknownVerficationPackages{$Package} - "
+                . $Self->{LayoutObject}->{LanguageObject}->Translate(
+                "Package not verified due a communication issue with verification server!"
+                ),
         );
     }
 
@@ -1492,9 +1660,10 @@ sub _MessageGet {
         || $Self->{ConfigObject}->Get('DefaultLanguage');
 
     if ( $Param{Info} ) {
+        TAG:
         for my $Tag ( @{ $Param{Info} } ) {
             if ( $Param{Type} ) {
-                next if $Tag->{Type} !~ /^$Param{Type}/i;
+                next TAG if $Tag->{Type} !~ /^$Param{Type}/i;
             }
             $Use = 1;
             if ( $Tag->{Format} && $Tag->{Format} =~ /plain/i ) {
@@ -1623,7 +1792,7 @@ sub _InstallHandling {
 
     # translate description
     if ( $Self->{LayoutObject}->{LanguageObject} ) {
-        $VerifyInfo{Description} = $Self->{LayoutObject}->{LanguageObject}->Get(
+        $VerifyInfo{Description} = $Self->{LayoutObject}->{LanguageObject}->Translate(
             $VerifyInfo{Description}
         );
     }
@@ -1665,6 +1834,17 @@ sub _InstallHandling {
         );
     }
 
+    # get cloud repositories
+    my $RepositoryCloudList =
+        $Self->{PackageObject}->RepositoryCloudList();
+
+    # in case Source is present on repository cloud list
+    # the package shold be retrieved using the CloudService backend
+    my $FromCloud = 0;
+    if ( $Param{Source} && $RepositoryCloudList->{ $Param{Source} } ) {
+        $FromCloud = 1;
+    }
+
     # intro before installation
     if ( %Data && !$IntroInstallPre ) {
 
@@ -1699,7 +1879,13 @@ sub _InstallHandling {
     }
 
     # install package
-    elsif ( $Self->{PackageObject}->PackageInstall( String => $Param{Package} ) ) {
+    elsif (
+        $Self->{PackageObject}->PackageInstall(
+            String    => $Param{Package},
+            FromCloud => $FromCloud
+        )
+        )
+    {
 
         # intro screen
         my %Data;
@@ -1838,22 +2024,13 @@ sub _UpgradeHandling {
 sub _GetFeatureAddonData {
     my ( $Self, %Param ) = @_;
 
-    # Default URL
-    my $FeedURL = 'http://www.otrs.com/feed/?post_type=feature_add_ons&lang=en';
-
     my $Language = $Self->{LayoutObject}->{UserLanguage};
 
-    # Check if URL for UserLanguage is available
-    if ( $Language =~ m/^de/ ) {
-        $FeedURL = 'http://www.otrs.com/feed/?post_type=feature_add_ons&lang=de';
-    }
+    # cleanup main language for languages like es_MX (es in this case)
+    $Language = substr $Language, 0, 2;
 
-    if ( $Language =~ m/^es/ ) {
-        $FeedURL = 'http://www.otrs.com/feed/?post_type=feature_add_ons&lang=es';
-    }
-
-    my $CacheKey  = "FeatureAddonData::$FeedURL";
-    my $CacheTTL  = 60 * 60 * 24;                   # 1 day
+    my $CacheKey  = "FeatureAddonData::$Language";
+    my $CacheTTL  = 60 * 60 * 24;                    # 1 day
     my $CacheType = 'PackageManager';
 
     my $CacheResult = $Self->{CacheObject}->Get(
@@ -1863,47 +2040,58 @@ sub _GetFeatureAddonData {
 
     return $CacheResult if ref $CacheResult eq 'ARRAY';
 
-    # set proxy settings can't use Kernel::System::WebAgent because of used
-    # XML::FeedPP to get RSS files
-    my $Proxy = $Self->{ConfigObject}->Get('WebUserAgent::Proxy');
-    if ($Proxy) {
-        $ENV{CGI_HTTP_PROXY} = $Proxy;
+    my $CloudService = 'PublicFeeds';
+    my $Operation    = 'FAOFeed';
+
+    # prepare cloud service request
+    my %RequestParams = (
+        RequestData => {
+            $CloudService => [
+                {
+                    Operation => $Operation,
+                    Data      => {
+                        Language => $Language,
+                    },
+                },
+            ],
+        },
+    );
+
+    # dispatch the cloud service request
+    my $RequestResult = $Self->{CloudServiceObject}->Request(%RequestParams);
+
+    # as this is the only operation an unsuccessful request means that the operation was also
+    # unsuccessful
+    if ( !IsHashRefWithData($RequestResult) ) {
+        return "Can't connect to OTRS Feature Add-on list server!";
     }
 
-    # get content
-    my $Feed = eval {
-        XML::FeedPP->new(
-            $FeedURL,
-            'xml_deref' => 1,
-            'utf8_flag' => 1,
-        );
-    };
+    my $OperationResult = $Self->{CloudServiceObject}->OperationResultGet(
+        RequestResult => $RequestResult,
+        CloudService  => $CloudService,
+        Operation     => $Operation,
+    );
 
-    return if !$Feed;
-
-    my @Result;
-    my $Count = 0;
-    ITEM:
-    for my $Item ( $Feed->get_item() ) {
-        $Count++;
-        last ITEM if $Count > 100;
-
-        push @Result, {
-            Title       => $Item->title(),
-            Link        => $Item->link(),
-            Description => $Item->get('content:encoded'),
-        };
+    if ( !IsHashRefWithData($OperationResult) ) {
+        return "Can't get OTRS Feature Add-on list from server";
     }
+    elsif ( !$OperationResult->{Success} ) {
+        return $OperationResult->{ErrorMessage} || "Can't get OTRS Feature Add-on from server!";
+    }
+
+    my $FAOFeed = $OperationResult->{Data}->{FAOs};
+
+    return if !IsArrayRefWithData($FAOFeed);
 
     # set cache
     $Self->{CacheObject}->Set(
         Type  => $CacheType,
         Key   => $CacheKey,
-        Value => \@Result,
+        Value => $FAOFeed,
         TTL   => $CacheTTL,
     );
 
-    return \@Result;
+    return $FAOFeed;
 }
 
 1;
