@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AdminProcessManagementPath.pm - process management path
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -313,7 +314,7 @@ sub _ShowEdit {
         Data        => \@TransitionList,
         Name        => "Transition",
         ID          => "Transition",
-        Title       => $Self->{LayoutObject}->{LanguageObject}->Get("Transition"),
+        Title       => $Self->{LayoutObject}->{LanguageObject}->Translate("Transition"),
         Translation => 1,
         Class       => 'W50pc',
     );
