@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AdminQueue.pm - to add/update/delete queues
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -167,6 +168,16 @@ sub Run {
             }
         }
 
+        # check if a queue exist with this name
+        my $NameExists = $Self->{QueueObject}->NameExistsCheck(
+            Name => $GetParam{Name},
+            ID   => $GetParam{QueueID}
+        );
+        if ($NameExists) {
+            $Errors{NameExists} = 1;
+            $Errors{'NameInvalid'} = 'ServerError';
+        }
+
         # if no errors occurred
         if ( !%Errors ) {
 
@@ -344,6 +355,13 @@ sub Run {
             }
         }
 
+        # check if a queue exist with this name
+        my $NameExists = $Self->{QueueObject}->NameExistsCheck( Name => $GetParam{Name} );
+        if ($NameExists) {
+            $Errors{NameExists} = 1;
+            $Errors{'NameInvalid'} = 'ServerError';
+        }
+
         # if no errors occurred
         if ( !%Errors ) {
 
@@ -694,6 +712,14 @@ sub _Edit {
         );
     }
 
+    # show appropriate messages for ServerError
+    if ( defined $Param{Errors}->{NameExists} && $Param{Errors}->{NameExists} == 1 ) {
+        $Self->{LayoutObject}->Block( Name => 'ExistNameServerError' );
+    }
+    else {
+        $Self->{LayoutObject}->Block( Name => 'NameServerError' );
+    }
+
     # show each preferences setting
     my %Preferences;
     if ( $Self->{ConfigObject}->Get('QueuePreferences') ) {
