@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AdminRoleGroup.pm - to add/update/delete groups <-> users
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -124,8 +125,9 @@ sub Run {
             for my $Permission ( sort keys %Permissions ) {
                 $NewPermission{$Permission} = 0;
                 my @Array = @{ $Permissions{$Permission} };
+                ID:
                 for my $ID (@Array) {
-                    next if !$ID;
+                    next ID if !$ID;
                     if ( $RoleID == $ID ) {
                         $NewPermission{$Permission} = 1;
                     }
@@ -211,8 +213,9 @@ sub _Change {
 
     $Self->{LayoutObject}->Block( Name => "ChangeHeader$NeType" );
 
+    TYPE:
     for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-        next if !$Type;
+        next TYPE if !$Type;
         my $Mark = $Type eq 'rw' ? "Highlight" : '';
         $Self->{LayoutObject}->Block(
             Name => 'ChangeHeader',
@@ -236,8 +239,9 @@ sub _Change {
                 NeType => $NeType,
             },
         );
+        TYPE:
         for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-            next if !$Type;
+            next TYPE if !$Type;
             my $Mark     = $Type eq 'rw'        ? "Highlight"          : '';
             my $Selected = $Param{$Type}->{$ID} ? ' checked="checked"' : '';
 
