@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AdminUser.pm - to add/update/delete user and preferences
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -187,7 +188,6 @@ sub Run {
             UserLogin => $GetParam{UserLogin},
             UserID    => $GetParam{UserID}
         );
-
         if ($UserLoginExists) {
             $Errors{UserLoginExists} = 1;
             $Errors{'UserLoginInvalid'} = 'ServerError';
@@ -205,8 +205,9 @@ sub Run {
 
             if ($Update) {
                 my %Preferences = %{ $Self->{ConfigObject}->Get('PreferencesGroups') };
+                GROUP:
                 for my $Group ( sort keys %Preferences ) {
-                    next if $Group eq 'Password';
+                    next GROUP if $Group eq 'Password';
 
                     # get user data
                     my %UserData = $Self->{UserObject}->GetUserData(
@@ -265,12 +266,7 @@ sub Run {
             }
         }
         my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Note
-            ? $Self->{LayoutObject}->Notify(
-            Priority => 'Error',
-            Info     => $Note,
-            )
-            : '';
+        $Output .= $Note;
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
             Action    => 'Change',
@@ -347,7 +343,6 @@ sub Run {
 
         # check if a user with this login (username) already exits
         my $UserLoginExists = $Self->{UserObject}->UserLoginExistsCheck( UserLogin => $GetParam{UserLogin} );
-
         if ($UserLoginExists) {
             $Errors{UserLoginExists} = 1;
             $Errors{'UserLoginInvalid'} = 'ServerError';
@@ -367,8 +362,9 @@ sub Run {
 
                 # update preferences
                 my %Preferences = %{ $Self->{ConfigObject}->Get('PreferencesGroups') };
+                GROUP:
                 for my $Group ( sort keys %Preferences ) {
-                    next if $Group eq 'Password';
+                    next GROUP if $Group eq 'Password';
 
                     # get user data
                     my %UserData = $Self->{UserObject}->GetUserData(
@@ -547,11 +543,12 @@ sub _Edit {
             next GROUP if $Preferences{$Group}->{Column} ne $Column;
 
             if ( $Data{ $Preferences{$Group}->{Prio} } ) {
+                COUNT:
                 for ( 1 .. 151 ) {
                     $Preferences{$Group}->{Prio}++;
                     if ( !$Data{ $Preferences{$Group}->{Prio} } ) {
                         $Data{ $Preferences{$Group}->{Prio} } = $Group;
-                        last;
+                        last COUNT;
                     }
                 }
             }
@@ -565,14 +562,15 @@ sub _Edit {
         }
 
         # show each preferences setting
+        PRIO:
         for my $Prio ( sort keys %Data ) {
             my $Group = $Data{$Prio};
             if ( !$Self->{ConfigObject}->{PreferencesGroups}->{$Group} ) {
-                next;
+                next PRIO;
             }
             my %Preference = %{ $Self->{ConfigObject}->{PreferencesGroups}->{$Group} };
             if ( $Group eq 'Password' ) {
-                next;
+                next PRIO;
             }
             my $Module = $Preference{Module} || 'Kernel::Output::HTML::PreferencesGeneric';
 
