@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AgentBook.pm - addressbook module
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +13,7 @@ use strict;
 use warnings;
 
 use Kernel::System::CustomerUser;
+our $ObjectManagerDisabled = 1;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -29,7 +31,6 @@ sub new {
 
     # create additional objects
     $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new(%Param);
-    $Self->{JSONObject}         = Kernel::System::JSON->new( %{$Self} );
 
     return $Self;
 }
@@ -81,7 +82,8 @@ sub Run {
                     Email => $List{$_}->{Email},
                     Count => $Count,
                     CustomerDataJSON =>
-                        $Self->{JSONObject}->Encode( Data => { $List{$_}->{Email} => $List{$_}->{CustomerKey} } ),
+                        $Kernel::OM->Get('Kernel::System::JSON')
+                        ->Encode( Data => { $List{$_}->{Email} => $List{$_}->{CustomerKey} } ),
                 },
             );
             $Count++;
