@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AgentLinkObject.pm - to link objects
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -194,9 +195,10 @@ sub Run {
                 # output an error notification
                 $Output .= $Self->{LayoutObject}->Notify(
                     Priority => 'Error',
-                    Data     => '$Text{"Can not delete link with %s!", "'
-                        . $TargetObjectDescription{Normal}
-                        . '"}',
+                    Data     => $Self->{LayoutObject}->{LanguageObject}->Translate(
+                        "Can not delete link with %s!",
+                        $TargetObjectDescription{Normal},
+                    ),
                 );
             }
         }
@@ -350,16 +352,19 @@ sub Run {
                         }
 
                         # translate the type name
-                        $TypeName = $Self->{LayoutObject}->{LanguageObject}->Get($TypeName);
+                        $TypeName = $Self->{LayoutObject}->{LanguageObject}->Translate($TypeName);
 
                         # output an error notification
                         $Output .= $Self->{LayoutObject}->Notify(
                             Priority => 'Error',
-                            Data     => '$Text{"Can not create link with %s!", "'
-                                . $TargetObjectDescription{Normal}
-                                . '"} $Text{"Object already linked as %s.", "'
-                                . $TypeName
-                                . '"}',
+                            Data     => $Self->{LayoutObject}->{LanguageObject}->Translate(
+                                "Can not create link with %s!",
+                                $TargetObjectDescription{Normal},
+                                )
+                                . $Self->{LayoutObject}->{LanguageObject}->Translate(
+                                "Object already linked as %s.",
+                                $TypeName,
+                                ),
                         );
 
                         next TARGETKEYORG;
@@ -424,9 +429,10 @@ sub Run {
                     # output an error notification
                     $Output .= $Self->{LayoutObject}->Notify(
                         Priority => 'Error',
-                        Data     => '$Text{"Can not create link with %s!", "'
-                            . $TargetObjectDescription{Normal}
-                            . '"}',
+                        Data     => $Self->{LayoutObject}->{LanguageObject}->Translate(
+                            "Can not create link with %s!",
+                            $TargetObjectDescription{Normal}
+                        ),
                     );
                 }
             }
@@ -623,7 +629,7 @@ sub Run {
 
             next POSSIBLETYPE if !$Type{Pointed};
 
-            # create the source name
+            # create the target name
             my %TargetName;
             $TargetName{Key}   = $PossibleType . '::Target';
             $TargetName{Value} = $Type{TargetName};
