@@ -1,6 +1,6 @@
 # --
 # Kernel/Modules/AgentPreferences.pm - provides agent preferences
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -114,14 +114,20 @@ sub Run {
             for my $ParamItem (@Params) {
                 my @Array = $Self->{ParamObject}->GetArray(
                     Param => $ParamItem->{Name},
-                    Raw => $ParamItem->{Raw} || 0,
+                    Raw   => $ParamItem->{Raw} || 0,
                 );
                 if ( defined $ParamItem->{Name} ) {
                     $GetParam{ $ParamItem->{Name} } = \@Array;
                 }
             }
 
-            if ( $Object->Run( GetParam => \%GetParam, UserData => \%UserData ) ) {
+            if (
+                $Object->Run(
+                    GetParam => \%GetParam,
+                    UserData => \%UserData
+                )
+                )
+            {
                 $Message .= $Object->Message();
             }
             else {
@@ -164,13 +170,16 @@ sub Run {
         );
     }
     elsif ($Message) {
-        $Output .= $Self->{LayoutObject}->Notify( Info => $Message, );
+        $Output .= $Self->{LayoutObject}->Notify(
+            Info => $Message,
+        );
     }
 
     # get user data
     my %UserData = $Self->{UserObject}->GetUserData( UserID => $Self->{UserID} );
     $Output .= $Self->AgentPreferencesForm( UserData => \%UserData );
     $Output .= $Self->{LayoutObject}->Footer();
+
     return $Output;
 }
 
@@ -234,12 +243,13 @@ sub AgentPreferencesForm {
         }
 
         # show each preferences setting
+        PRIO:
         for my $Prio ( sort keys %Data ) {
             my $Group = $Data{$Prio};
-            next if !$Self->{ConfigObject}->{PreferencesGroups}->{$Group};
+            next PRIO if !$Self->{ConfigObject}->{PreferencesGroups}->{$Group};
 
             my %Preference = %{ $Self->{ConfigObject}->{PreferencesGroups}->{$Group} };
-            next if !$Preference{Active};
+            next PRIO if !$Preference{Active};
 
             # load module
             my $Module = $Preference{Module} || 'Kernel::Output::HTML::PreferencesGeneric';
@@ -252,7 +262,7 @@ sub AgentPreferencesForm {
                 Debug      => $Self->{Debug},
             );
             my @Params = $Object->Param( UserData => $Param{UserData} );
-            next if !@Params;
+            next PRIO if !@Params;
 
             # show item
             $Self->{LayoutObject}->Block(
