@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AgentTicketEscalationView.pm - status for all open tickets
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -166,8 +167,6 @@ sub Run {
             Refresh => $Refresh,
         );
         $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Self->{LayoutObject}->Print( Output => \$Output );
-        $Output = '';
     }
 
     my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $Self->{TimeObject}->SystemTime2Date(
@@ -386,6 +385,9 @@ sub Run {
         },
 
         Escalation => 1,
+
+        # do not print the result earlier, but return complete content
+        Output => 1,
     );
 
     $Output .= $Self->{LayoutObject}->Footer();
