@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AgentTicketLock.pm - to set or unset a lock for tickets
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -10,7 +11,6 @@ package Kernel::Modules::AgentTicketLock;
 
 use strict;
 use warnings;
-
 use Kernel::System::VariableCheck qw(:all);
 
 sub new {
@@ -54,8 +54,11 @@ sub Run {
     }
 
     # get ACL restrictions
-    $Self->{TicketObject}->TicketAcl(
-        Data          => '-',
+    my %PossibleActions = ( 1 => $Self->{Action} );
+
+    my $ACL = $Self->{TicketObject}->TicketAcl(
+        Data          => \%PossibleActions,
+        Action        => $Self->{Action},
         TicketID      => $Self->{TicketID},
         ReturnType    => 'Action',
         ReturnSubType => '-',
@@ -64,10 +67,12 @@ sub Run {
     my %AclAction = $Self->{TicketObject}->TicketAclActionData();
 
     # check if ACL restrictions exist
-    if ( IsHashRefWithData( \%AclAction ) ) {
+    if ( $ACL || IsHashRefWithData( \%AclAction ) ) {
+
+        my %AclActionLookup = reverse %AclAction;
 
         # show error screen if ACL prohibits this action
-        if ( defined $AclAction{ $Self->{Action} } && $AclAction{ $Self->{Action} } eq '0' ) {
+        if ( !$AclActionLookup{ $Self->{Action} } ) {
             return $Self->{LayoutObject}->NoPermission( WithHeader => 'yes' );
         }
     }
@@ -157,16 +162,6 @@ sub Run {
     if ( $Self->{QueueID} ) {
         return $Self->{LayoutObject}->Redirect( OP => ";QueueID=$Self->{QueueID}" );
     }
-
-    # get return module string and redirect if present
-    my $ReturnModule = $Self->{ParamObject}->GetParam( Param => 'ReturnModule' ) || '';
-
-    if ( IsStringWithData($ReturnModule) ) {
-        return $Self->{LayoutObject}->Redirect(
-            OP => $ReturnModule,
-        );
-    }
-
     return $Self->{LayoutObject}->Redirect(
         OP => "Action=AgentTicketZoom;TicketID=$Self->{TicketID}",
     );
