@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AgentTicketQueue.pm - the queue view of all tickets
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -64,9 +65,24 @@ sub Run {
     my $SortBy = $Self->{ParamObject}->GetParam( Param => 'SortBy' )
         || $Self->{Config}->{'SortBy::Default'}
         || 'Age';
-    my $OrderBy = $Self->{ParamObject}->GetParam( Param => 'OrderBy' )
-        || $Self->{Config}->{'Order::Default'}
+
+    # Determine the default ordering to be used. Observe the QueueSort setting.
+    my $DefaultOrderBy = $Self->{Config}->{'Order::Default'}
         || 'Up';
+    if ( $Self->{Config}->{QueueSort} ) {
+        if ( defined $Self->{Config}->{QueueSort}->{ $Self->{QueueID} } ) {
+            if ( $Self->{Config}->{QueueSort}->{ $Self->{QueueID} } ) {
+                $DefaultOrderBy = 'Down';
+            }
+            else {
+                $DefaultOrderBy = 'Up';
+            }
+        }
+    }
+
+    # Set the sort order from the request parameters, or take the default.
+    my $OrderBy = $Self->{ParamObject}->GetParam( Param => 'OrderBy' )
+        || $DefaultOrderBy;
 
     # store last queue screen
     $Self->{SessionObject}->UpdateSessionID(
@@ -168,24 +184,6 @@ sub Run {
         $GetColumnFilter{ 'DynamicField_' . $DynamicFieldConfig->{Name} } = $FilterValue;
     }
 
-    # if we have only one queue, check if there
-    # is a setting in Config.pm for sorting
-    if ( !$OrderBy ) {
-        if ( $Self->{Config}->{QueueSort} ) {
-            if ( defined $Self->{Config}->{QueueSort}->{ $Self->{QueueID} } ) {
-                if ( $Self->{Config}->{QueueSort}->{ $Self->{QueueID} } ) {
-                    $OrderBy = 'Down';
-                }
-                else {
-                    $OrderBy = 'Up';
-                }
-            }
-        }
-    }
-    if ( !$OrderBy ) {
-        $OrderBy = $Self->{Config}->{'Order::Default'} || 'Up';
-    }
-
     # build NavigationBar & to get the output faster!
     my $Refresh = '';
     if ( $Self->{UserRefreshTime} ) {
@@ -198,8 +196,6 @@ sub Run {
             Refresh => $Refresh,
         );
         $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Self->{LayoutObject}->Print( Output => \$Output );
-        $Output = '';
     }
 
     # viewable locks
@@ -443,47 +439,47 @@ sub Run {
     );
 
     # show tickets
-    $Self->{LayoutObject}->Print(
-        Output => \$Self->{LayoutObject}->TicketListShow(
+    $Output .= $Self->{LayoutObject}->TicketListShow(
+        Filter     => $Self->{Filter},
+        Filters    => \%NavBarFilter,
+        FilterLink => $LinkFilter,
 
-            Filter     => $Self->{Filter},
-            Filters    => \%NavBarFilter,
-            FilterLink => $LinkFilter,
-
-            DataInTheMiddle => $Self->{LayoutObject}->Output(
-                TemplateFile => 'AgentTicketQueue',
-                Data         => \%NavBar,
-            ),
-
-            TicketIDs => \@ViewableTickets,
-
-            OriginalTicketIDs => \@OriginalViewableTickets,
-            GetColumnFilter   => \%GetColumnFilter,
-            LastColumnFilter  => $LastColumnFilter,
-            Action            => 'AgentTicketQueue',
-            Total             => $CountTotal,
-            RequestedURL      => $Self->{RequestedURL},
-
-            NavBar => \%NavBar,
-            View   => $Self->{View},
-
-            Bulk       => 1,
-            TitleName  => 'QueueView',
-            TitleValue => $NavBar{SelectedQueue},
-
-            Env        => $Self,
-            LinkPage   => $LinkPage,
-            LinkSort   => $LinkSort,
-            LinkFilter => $LinkFilter,
-
-            OrderBy             => $OrderBy,
-            SortBy              => $SortBy,
-            EnableColumnFilters => 1,
-            ColumnFilterForm    => {
-                QueueID => $Self->{QueueID} || '',
-                Filter  => $Self->{Filter}  || '',
-            },
+        DataInTheMiddle => $Self->{LayoutObject}->Output(
+            TemplateFile => 'AgentTicketQueue',
+            Data         => \%NavBar,
         ),
+
+        TicketIDs => \@ViewableTickets,
+
+        OriginalTicketIDs => \@OriginalViewableTickets,
+        GetColumnFilter   => \%GetColumnFilter,
+        LastColumnFilter  => $LastColumnFilter,
+        Action            => 'AgentTicketQueue',
+        Total             => $CountTotal,
+        RequestedURL      => $Self->{RequestedURL},
+
+        NavBar => \%NavBar,
+        View   => $Self->{View},
+
+        Bulk       => 1,
+        TitleName  => 'QueueView',
+        TitleValue => $NavBar{SelectedQueue},
+
+        Env        => $Self,
+        LinkPage   => $LinkPage,
+        LinkSort   => $LinkSort,
+        LinkFilter => $LinkFilter,
+
+        OrderBy             => $OrderBy,
+        SortBy              => $SortBy,
+        EnableColumnFilters => 1,
+        ColumnFilterForm    => {
+            QueueID => $Self->{QueueID} || '',
+            Filter  => $Self->{Filter}  || '',
+        },
+
+        # do not print the result earlier, but return complete content
+        Output => 1,
     );
 
     # get page footer
@@ -498,7 +494,6 @@ sub BuildQueueView {
         UserID        => $Self->{UserID},
         QueueID       => $Self->{QueueID},
         ShownQueueIDs => $Param{QueueIDs},
-        Filter        => $Param{Filter},
     );
 
     # build output ...
@@ -519,10 +514,12 @@ sub _MaskQueueView {
     my $QueueIDOfMaxAge = $Param{QueueIDOfMaxAge} || -1;
     my %AllQueues       = %{ $Param{AllQueues} };
     my %Counter;
+    my %Totals;
+    my $HaveTotals = 0;    # flag for "Total" in index backend
     my %UsedQueue;
     my @ListedQueues;
     my $Level       = 0;
-    my $CustomQueue = $Self->{LayoutObject}->{LanguageObject}->Get( $Self->{CustomQueue} );
+    my $CustomQueue = $Self->{LayoutObject}->{LanguageObject}->Translate( $Self->{CustomQueue} );
     $Self->{HighlightAge1} = $Self->{Config}->{HighlightAge1};
     $Self->{HighlightAge2} = $Self->{Config}->{HighlightAge2};
     $Self->{Blink}         = $Self->{Config}->{Blink};
@@ -537,6 +534,7 @@ sub _MaskQueueView {
         push @ListedQueues, $QueueRef;
         my %Queue = %$QueueRef;
         my @Queue = split /::/, $Queue{Queue};
+        $HaveTotals ||= exists $Queue{Total};
 
         # remember counted/used queues
         $UsedQueue{ $Queue{Queue} } = 1;
@@ -550,14 +548,26 @@ sub _MaskQueueView {
             else {
                 $QueueName .= '::' . $Queue[$_];
             }
-            if ( !$Counter{$QueueName} ) {
-                $Counter{$QueueName} = 0;
+            if ( !exists $Counter{$QueueName} ) {
+                $Counter{$QueueName} = 0;    # init
+                $Totals{$QueueName}  = 0;
             }
-            $Counter{$QueueName} = $Counter{$QueueName} + $Queue{Count};
-            if ( $Counter{$QueueName} && !$Queue{$QueueName} && !$UsedQueue{$QueueName} ) {
+            my $Total = $Queue{Total} || 0;
+            $Counter{$QueueName} += $Queue{Count};
+            $Totals{$QueueName}  += $Total;
+            if (
+                ( $Counter{$QueueName} || $Totals{$QueueName} )
+                && !$Queue{$QueueName}
+                && !$UsedQueue{$QueueName}
+                )
+            {
+                # IMHO, this is purely pathological--TicketAcceleratorIndex
+                # sorts queues by name, so we should never stumble across one
+                # that we have not seen before!
                 my %Hash = ();
                 $Hash{Queue} = $QueueName;
                 $Hash{Count} = $Counter{$QueueName};
+                $Hash{Total} = $Total;
                 for ( sort keys %AllQueues ) {
                     if ( $AllQueues{$_} eq $QueueName ) {
                         $Hash{QueueID} = $_;
@@ -578,7 +588,8 @@ sub _MaskQueueView {
         # replace name of CustomQueue
         if ( $Queue{Queue} eq 'CustomQueue' ) {
             $Counter{$CustomQueue} = $Counter{ $Queue{Queue} };
-            $Queue{Queue} = $CustomQueue;
+            $Totals{$CustomQueue}  = $Totals{ $Queue{Queue} };
+            $Queue{Queue}          = $CustomQueue;
         }
         my @QueueName = split /::/, $Queue{Queue};
         my $ShortQueueName = $QueueName[-1];
@@ -635,8 +646,16 @@ sub _MaskQueueView {
         }
 
         # QueueStrg
-        $QueueStrg .= $Self->{LayoutObject}->Ascii2Html( Text => $ShortQueueName )
-            . " ($Counter{$Queue{Queue}})";
+        $QueueStrg .= $Self->{LayoutObject}->Ascii2Html( Text => $ShortQueueName );
+
+        # If the index backend supports totals, we show total tickets
+        # as well as unlocked ones in the form  "QueueName (total / unlocked)"
+        if ( $HaveTotals && ( $Totals{ $Queue{Queue} } != $Counter{ $Queue{Queue} } ) ) {
+            $QueueStrg .= " ($Totals{$Queue{Queue}}/$Counter{$Queue{Queue}})";
+        }
+        else {
+            $QueueStrg .= " ($Counter{$Queue{Queue}})";
+        }
 
         $QueueStrg .= '</a></li>';
 
