@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/AgentTicketWatchView.pm - to view all locked tickets
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -161,8 +162,6 @@ sub Run {
             Refresh => $Refresh,
         );
         $Output .= $Self->{LayoutObject}->NavigationBar();
-        $Self->{LayoutObject}->Print( Output => \$Output );
-        $Output = '';
     }
 
     # get locked  viewable tickets...
@@ -184,11 +183,12 @@ sub Run {
             $Access = 1;
         }
         else {
+            GROUP:
             for my $Group (@Groups) {
-                next if !$Self->{LayoutObject}->{"UserIsGroup[$Group]"};
+                next GROUP if !$Self->{LayoutObject}->{"UserIsGroup[$Group]"};
                 if ( $Self->{LayoutObject}->{"UserIsGroup[$Group]"} eq 'Yes' ) {
                     $Access = 1;
-                    last;
+                    last GROUP;
                 }
             }
         }
@@ -308,8 +308,9 @@ sub Run {
         }
 
         my @OriginalViewableTicketsTmp;
+        TICKETID:
         for my $TicketIDAll (@OriginalViewableTicketsAll) {
-            next if $OriginalViewableTicketsNotNew{$TicketIDAll};
+            next TICKETID if $OriginalViewableTicketsNotNew{$TicketIDAll};
             push @OriginalViewableTicketsTmp, $TicketIDAll;
         }
         @OriginalViewableTickets = @OriginalViewableTicketsTmp;
@@ -327,8 +328,9 @@ sub Run {
         }
 
         my @ViewableTicketsTmp;
+        TICKETID:
         for my $TicketIDAll (@ViewableTicketsAll) {
-            next if $ViewableTicketsNotNew{$TicketIDAll};
+            next TICKETID if $ViewableTicketsNotNew{$TicketIDAll};
             push @ViewableTicketsTmp, $TicketIDAll;
         }
         @ViewableTickets = @ViewableTicketsTmp;
@@ -464,6 +466,9 @@ sub Run {
         ColumnFilterForm    => {
             Filter => $Self->{Filter} || '',
         },
+
+        # do not print the result earlier, but return complete content
+        Output => 1,
     );
 
     $Output .= $Self->{LayoutObject}->Footer();
