@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/CustomerTicketSearch.pm - Utilities for tickets
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -179,7 +180,7 @@ sub Run {
     else {
         for my $Key (
             qw(TicketNumber From To Cc Subject Body CustomerID ResultForm TimeSearchType StateType
-            SearchInArchive
+            SearchInArchive AttachmentName
             TicketCreateTimePointFormat TicketCreateTimePoint
             TicketCreateTimePointStart
             TicketCreateTimeStart TicketCreateTimeStartDay TicketCreateTimeStartMonth
@@ -287,8 +288,28 @@ sub Run {
         );
     }
 
+    # check for server errors
+    my %ServerErrors;
+    if (
+        $Self->{Subaction} eq 'Search'
+        && !$Self->{EraseTemplate}
+        )
+    {
+
+        # check for stop word errors
+        my %StopWordsServerErrors = $Self->_StopWordsServerErrorsGet(
+            From    => $GetParam{From},
+            To      => $GetParam{To},
+            Cc      => $GetParam{Cc},
+            Subject => $GetParam{Subject},
+            Body    => $GetParam{Body},
+        );
+
+        %ServerErrors = ( %ServerErrors, %StopWordsServerErrors );
+    }
+
     # show result page
-    if ( $Self->{Subaction} eq 'Search' && !$Self->{EraseTemplate} ) {
+    if ( !%ServerErrors && $Self->{Subaction} eq 'Search' && !$Self->{EraseTemplate} ) {
 
         # fill up profile name (e.g. with last-search)
         if ( !$Self->{Profile} || !$Self->{SaveProfile} ) {
@@ -522,8 +543,12 @@ sub Run {
             %DynamicFieldSearchParameters,
         );
 
-        # CSV output
-        if ( $GetParam{ResultForm} eq 'CSV' ) {
+        # CSV and Excel output
+        if (
+            $GetParam{ResultForm} eq 'CSV'
+            || $GetParam{ResultForm} eq 'Excel'
+            )
+        {
 
             # create head (actual head and head for data fill)
             my @TmpCSVHead = @{ $Self->{Config}->{SearchCSVData} };
@@ -559,14 +584,14 @@ sub Run {
                     );
                     %Data = %Ticket;
                     $Data{Subject} = $Ticket{Title} || 'Untitled';
-                    $Data{Body} = $Self->{LayoutObject}->{LanguageObject}->Get(
+                    $Data{Body} = $Self->{LayoutObject}->{LanguageObject}->Translate(
                         'This item has no articles yet.'
                     );
                     $Data{From} = '--';
                 }
 
                 for my $Key (qw(State Lock)) {
-                    $Data{$Key} = $Self->{LayoutObject}->{LanguageObject}->Get( $Data{$Key} );
+                    $Data{$Key} = $Self->{LayoutObject}->{LanguageObject}->Translate( $Data{$Key} );
                 }
 
                 $Data{Age} = $Self->{LayoutObject}->CustomerAge(
@@ -580,16 +605,6 @@ sub Run {
                         TicketID      => $TicketID,
                         DynamicFields => 0,
                     );
-                    for my $Articles (@Article) {
-                        if ( $Articles->{Body} ) {
-                            $Data{ArticleTree}
-                                .= "\n-->||$Articles->{ArticleType}||$Articles->{From}||"
-                                . $Articles->{Created}
-                                . "||<--------------\n"
-                                . $Articles->{Body};
-                        }
-                    }
-
                     if ( $#Article == -1 ) {
                         $Data{ArticleTree}
                             .= 'This item has no articles yet.';
@@ -680,17 +695,11 @@ sub Run {
                 CustomerName => 'Customer Realname',
             );
 
-            my @CSVHeadTranslated = map { $Self->{LayoutObject}->{LanguageObject}->Get( $HeaderMap{$_} || $_ ); }
+            my @CSVHeadTranslated = map { $Self->{LayoutObject}->{LanguageObject}->Translate( $HeaderMap{$_} || $_ ); }
                 @CSVHead;
 
-            my $CSV = $Self->{CSVObject}->Array2CSV(
-                Head      => \@CSVHeadTranslated,
-                Data      => \@CSVData,
-                Separator => $UserCSVSeparator,
-            );
-
             # return csv to download
-            my $CSVFile = 'ticket_search';
+            my $FileName = 'ticket_search';
             my ( $s, $m, $h, $D, $M, $Y ) = $Self->{TimeObject}->SystemTime2Date(
                 SystemTime => $Self->{TimeObject}->SystemTime(),
             );
@@ -698,12 +707,38 @@ sub Run {
             $D = sprintf( "%02d", $D );
             $h = sprintf( "%02d", $h );
             $m = sprintf( "%02d", $m );
-            return $Self->{LayoutObject}->Attachment(
-                Filename    => $CSVFile . "_" . "$Y-$M-$D" . "_" . "$h-$m.csv",
-                ContentType => "text/csv; charset=" . $Self->{LayoutObject}->{UserCharset},
-                Content     => $CSV,
-            );
+
+            if ( $GetParam{ResultForm} eq 'CSV' ) {
+
+                my $CSV = $Self->{CSVObject}->Array2CSV(
+                    Head => \@CSVHeadTranslated,
+                    Data => \@CSVData,
+                );
+                return $Self->{LayoutObject}->Attachment(
+                    Filename    => $FileName . "_" . "$Y-$M-$D" . "_" . "$h-$m.csv",
+                    ContentType => "text/csv; charset=" . $Self->{LayoutObject}->{UserCharset},
+                    Content     => $CSV,
+                );
+
+            }
+
+            # return Excel to download
+            elsif ( $GetParam{ResultForm} eq 'Excel' ) {
+                my $Excel = $Self->{CSVObject}->Array2CSV(
+                    Head   => \@CSVHeadTranslated,
+                    Data   => \@CSVData,
+                    Format => "Excel",
+                );
+
+                return $Self->{LayoutObject}->Attachment(
+                    Filename => $FileName . "_" . "$Y-$M-$D" . "_" . "$h-$m.xlsx",
+                    ContentType =>
+                        "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
+                    Content => $Excel,
+                );
+            }
         }
+
         elsif ( $GetParam{ResultForm} eq 'Print' ) {
             for my $TicketID (@ViewableTicketIDs) {
 
@@ -723,7 +758,7 @@ sub Run {
                     );
                     %Article = %Ticket;
                     $Article{Subject} = $Ticket{Title} || 'Untitled';
-                    $Article{Body} = $Self->{LayoutObject}->{LanguageObject}->Get(
+                    $Article{Body} = $Self->{LayoutObject}->{LanguageObject}->Translate(
                         'This item has no articles yet.'
                     );
                     $Article{From} = '--';
@@ -781,8 +816,10 @@ sub Run {
             }
             my $Output = $Self->{LayoutObject}->PrintHeader( Width => 800 );
             if ( @ViewableTicketIDs == $Self->{SearchLimit} ) {
-                $Param{Warning} = '$Text{"Reached max. count of %s search hits!", "'
-                    . $Self->{SearchLimit} . '"}';
+                $Param{Warning} = $Self->{LayoutObject}->{LanguageObject}->Translate(
+                    "Reached max. count of %s search hits!",
+                    $Self->{SearchLimit},
+                );
             }
             $Output .= $Self->{LayoutObject}->Output(
                 TemplateFile => 'CustomerTicketSearchResultPrint',
@@ -901,7 +938,7 @@ sub Run {
                     if ( !%Article ) {
                         %Article = %Ticket;
                         $Article{Subject} = $Ticket{Title} || 'Untitled';
-                        $Article{Body} = $Self->{LayoutObject}->{LanguageObject}->Get(
+                        $Article{Body} = $Self->{LayoutObject}->{LanguageObject}->Translate(
                             'This item has no articles yet.'
                         );
                     }
@@ -1033,13 +1070,15 @@ sub Run {
                 Translation => 0,
             },
         );
+
+        KEY:
         for my $Key (
             qw(TicketNumber From To Cc Subject Body CustomerID TimeSearchType StateType
             StateIDs StateTypeIDs PriorityIDs OwnerIDs ResponsibleIDs
             )
             )
         {
-            next if !$GetParam{$Key};
+            next KEY if !$GetParam{$Key};
             my $Attribute = $IDMap{$Key}->{Name}   || $Key;
             my $Object    = $IDMap{$Key}->{Object} || '';
             my $Method    = $IDMap{$Key}->{Method};
@@ -1056,7 +1095,7 @@ sub Run {
                     if ( $Self->{$Object} ) {
                         $Item = $Self->{$Object}->$Method( $MethodKey => $Item );
                         if ($Translation) {
-                            $Item = $Self->{LayoutObject}->{LanguageObject}->Get($Item);
+                            $Item = $Self->{LayoutObject}->{LanguageObject}->Translate($Item);
                         }
                     }
                     $Value .= $Item;
@@ -1067,7 +1106,7 @@ sub Run {
                 if ( $Self->{$Object} ) {
                     $Item = $Self->{$Object}->$Method( $MethodKey => $Item );
                     if ($Translation) {
-                        $Item = $Self->{LayoutObject}->{LanguageObject}->Get($Item);
+                        $Item = $Self->{LayoutObject}->{LanguageObject}->Translate($Item);
                     }
                 }
                 $Value = $Item;
@@ -1092,7 +1131,7 @@ sub Run {
 
                     $Attribute = 'Created between';
                     $Value     = $StartDate . ' '
-                        . $Self->{LayoutObject}->{LanguageObject}->Get('and') . ' '
+                        . $Self->{LayoutObject}->{LanguageObject}->Translate('and') . ' '
                         . $StopDate;
                 }
                 else {
@@ -1323,7 +1362,8 @@ sub Run {
             %GetParam,
             Profile          => $Self->{Profile},
             Area             => 'Customer',
-            DynamicFieldHTML => \%DynamicFieldHTML
+            DynamicFieldHTML => \%DynamicFieldHTML,
+            %ServerErrors,
         );
         $Output .= $Self->{LayoutObject}->CustomerFooter();
         return $Output;
@@ -1344,6 +1384,7 @@ sub MaskForm {
             Normal => 'Normal',
             Print  => 'Print',
             CSV    => 'CSV',
+            Excel  => 'Excel',
         },
         Name       => 'ResultForm',
         SelectedID => $Param{ResultForm} || 'Normal',
@@ -1360,12 +1401,22 @@ sub MaskForm {
         Name        => 'Profile',
         SelectedID  => $Param{Profile},
     );
-    $Param{ServicesStrg} = $Self->{LayoutObject}->BuildSelection(
-        Data => {
-            $Self->{ServiceObject}->ServiceList(
-                UserID => $Self->{UserID},
+
+    my %ServiceList;
+    if ( $Self->{ConfigObject}->Get('Customer::TicketSearch::AllServices') ) {
+        %ServiceList = $Self->{ServiceObject}->ServiceList(
+            UserID => $Self->{UserID},
             ),
-        },
+    }
+    else {
+        %ServiceList = $Self->{ServiceObject}->CustomerUserServiceMemberList(
+            CustomerUserLogin => $Self->{UserID},
+            Result            => 'HASH',
+            ),
+    }
+
+    $Param{ServicesStrg} = $Self->{LayoutObject}->BuildSelection(
+        Data       => \%ServiceList,
         Name       => 'ServiceIDs',
         Multiple   => 1,
         Size       => 5,
@@ -1584,6 +1635,17 @@ sub MaskForm {
         }
     }
 
+    if (
+        $Self->{ConfigObject}->Get('Ticket::StorageModule') eq
+        'Kernel::System::Ticket::ArticleStorageDB'
+        )
+    {
+        $Self->{LayoutObject}->Block(
+            Name => 'Attachment',
+            Data => \%Param
+        );
+    }
+
     # html search mask output
     return $Self->{LayoutObject}->Output(
         TemplateFile => 'CustomerTicketSearch',
@@ -1591,4 +1653,49 @@ sub MaskForm {
     );
 }
 
+sub _StopWordsServerErrorsGet {
+    my ( $Self, %Param ) = @_;
+
+    if ( !%Param ) {
+        $Self->{LayoutObject}->FatalError( Message => "Got no values to check." );
+    }
+
+    my %StopWordsServerErrors;
+    if ( !$Self->{TicketObject}->SearchStringStopWordsUsageWarningActive() ) {
+        return %StopWordsServerErrors;
+    }
+
+    my %SearchStrings;
+
+    FIELD:
+    for my $Field ( sort keys %Param ) {
+        next FIELD if !defined $Param{$Field};
+        next FIELD if !length $Param{$Field};
+
+        $SearchStrings{$Field} = $Param{$Field};
+    }
+
+    if (%SearchStrings) {
+
+        my $StopWords = $Self->{TicketObject}->SearchStringStopWordsFind(
+            SearchStrings => \%SearchStrings
+        );
+
+        FIELD:
+        for my $Field ( sort keys %{$StopWords} ) {
+            next FIELD if !defined $StopWords->{$Field};
+            next FIELD if ref $StopWords->{$Field} ne 'ARRAY';
+            next FIELD if !@{ $StopWords->{$Field} };
+
+            $StopWordsServerErrors{ $Field . 'Invalid' }        = 'ServerError';
+            $StopWordsServerErrors{ $Field . 'InvalidTooltip' } = $Self->{LayoutObject}->{LanguageObject}
+                ->Translate('Please remove the following words because they cannot be used for the search:')
+                . ' '
+                . join( ',', sort @{ $StopWords->{$Field} } );
+        }
+    }
+
+    return %StopWordsServerErrors;
+}
+
 1;
