@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/CustomerTicketZoom.pm - to get a closer view
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -23,6 +24,8 @@ use Kernel::System::ProcessManagement::Transition;
 use Kernel::System::ProcessManagement::TransitionAction;
 use Kernel::System::VariableCheck qw(:all);
 
+our $ObjectManagerDisabled = 1;
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -48,6 +51,19 @@ sub new {
         $Self->{ZoomExpand} = $Self->{ConfigObject}->Get('Ticket::Frontend::ZoomExpand') || '';
     }
 
+    if ( !defined $Self->{DoNotShowBrowserLinkMessage} ) {
+        my %UserPreferences = $Self->{UserObject}->GetPreferences(
+            UserID => $Self->{UserID},
+        );
+
+        if ( $UserPreferences{UserCustomerDoNotShowBrowserLinkMessage} ) {
+            $Self->{DoNotShowBrowserLinkMessage} = 1;
+        }
+        else {
+            $Self->{DoNotShowBrowserLinkMessage} = 0;
+        }
+    }
+
     # needed objects
     $Self->{AgentUserObject}    = Kernel::System::User->new(%Param);
     $Self->{StateObject}        = Kernel::System::State->new(%Param);
@@ -309,6 +325,23 @@ sub Run {
 
     #   end AJAX Update
 
+    # save, if browser link message was closed
+    elsif ( $Self->{Subaction} eq 'BrowserLinkMessage' ) {
+
+        $Self->{UserObject}->SetPreferences(
+            UserID => $Self->{UserID},
+            Key    => 'UserCustomerDoNotShowBrowserLinkMessage',
+            Value  => 1,
+        );
+
+        return $Self->{LayoutObject}->Attachment(
+            ContentType => 'text/html',
+            Content     => 1,
+            Type        => 'inline',
+            NoCache     => 1,
+        );
+    }
+
     # check follow up
     elsif ( $Self->{Subaction} eq 'Store' ) {
 
@@ -318,14 +351,6 @@ sub Run {
         my $NextScreen = $Self->{NextScreen} || $Self->{Config}->{NextScreenAfterFollowUp};
         my %Error;
 
-        # rewrap body if no rich text is used
-        if ( $GetParam{Body} && !$Self->{LayoutObject}->{BrowserRichText} ) {
-            $GetParam{Body} = $Self->{LayoutObject}->WrapPlainText(
-                MaxCharacters => $Self->{ConfigObject}->Get('Ticket::Frontend::TextAreaNote'),
-                PlainText     => $GetParam{Body},
-            );
-        }
-
         # get follow up option (possible or not)
         my $FollowUpPossible = $Self->{QueueObject}->GetFollowUpOption(
             QueueID => $Ticket{QueueID},
@@ -388,7 +413,8 @@ sub Run {
                 Param => "file_upload",
             );
             $Self->{UploadCacheObject}->FormIDAddFile(
-                FormID => $Self->{FormID},
+                FormID      => $Self->{FormID},
+                Disposition => 'attachment',
                 %UploadStuff,
             );
             $IsUpload = 1;
@@ -642,10 +668,28 @@ sub Run {
         ATTACHMENT:
         for my $Attachment (@AttachmentData) {
 
-            # skip deleted inline images
-            next ATTACHMENT if $Attachment->{ContentID}
-                && $Attachment->{ContentID} =~ /^inline/
-                && $GetParam{Body} !~ /$Attachment->{ContentID}/;
+            my $ContentID = $Attachment->{ContentID};
+            if (
+                $ContentID
+                && ( $Attachment->{ContentType} =~ /image/i )
+                && ( $Attachment->{Disposition} eq 'inline' )
+                )
+            {
+                my $ContentIDHTMLQuote = $Self->{LayoutObject}->Ascii2Html(
+                    Text => $ContentID,
+                );
+
+                # workaround for link encode of rich text editor, see bug#5053
+                my $ContentIDLinkEncode = $Self->{LayoutObject}->LinkEncode($ContentID);
+                $GetParam{Body} =~ s/(ContentID=)$ContentIDLinkEncode/$1$ContentID/g;
+
+                # ignore attachment if not linked in body
+                if ( $GetParam{Body} !~ /(\Q$ContentIDHTMLQuote\E|\Q$ContentID\E)/i ) {
+                    next ATTACHMENT;
+                }
+            }
+
+            # write existing file to backend
             $Self->{TicketObject}->ArticleWriteAttachment(
                 %{$Attachment},
                 ArticleID => $ArticleID,
@@ -1047,40 +1091,28 @@ sub _Mask {
                 $NextActivityDialogs = {};
             }
 
-            # ACL Check is done in the initial "Run" statement
-            # so here we can just pick the possibly reduced Activity Dialogs
-            # map and sort reformat the $NextActivityDialogs hash from it's initial form e.g.:
-            # 1 => 'AD1',
-            # 2 => 'AD3',
-            # 3 => 'AD2',
-            # to a regular array in correct order:
-            # ('AD1', 'AD3', 'AD2')
-
-            my @TmpActivityDialogList = map { $NextActivityDialogs->{$_} }
-                sort { $a <=> $b } keys %{$NextActivityDialogs};
-
             # we have to check if the current user has the needed permissions to view the
             # different activity dialogs, so we loop over every activity dialog and check if there
             # is a permission configured. If there is a permission configured we check this
             # and display/hide the activity dialog link
             my %PermissionRights;
-            my @PermissionActivityDialogList;
+            my %PermissionActivityDialogList;
             ACTIVITYDIALOGPERMISSION:
-            for my $CurrentActivityDialogEntityID (@TmpActivityDialogList) {
-
-                my $CurrentActivityDialog = $Self->{ActivityDialogObject}->ActivityDialogGet(
+            for my $Index ( sort { $a <=> $b } keys %{$NextActivityDialogs} ) {
+                my $CurrentActivityDialogEntityID = $NextActivityDialogs->{$Index};
+                my $CurrentActivityDialog         = $Self->{ActivityDialogObject}->ActivityDialogGet(
                     ActivityDialogEntityID => $CurrentActivityDialogEntityID,
                     Interface              => 'CustomerInterface',
                 );
 
-                # create an interface lookuplist
+                # create an interface lookup-list
                 my %InterfaceLookup = map { $_ => 1 } @{ $CurrentActivityDialog->{Interface} };
 
                 next ACTIVITYDIALOGPERMISSION if !$InterfaceLookup{CustomerInterface};
 
                 if ( $CurrentActivityDialog->{Permission} ) {
 
-                    # performanceboost/cache
+                    # performance-boost/cache
                     if ( !defined $PermissionRights{ $CurrentActivityDialog->{Permission} } ) {
                         $PermissionRights{ $CurrentActivityDialog->{Permission} }
                             = $Self->{TicketObject}->TicketCustomerPermission(
@@ -1090,28 +1122,30 @@ sub _Mask {
                             );
                     }
 
-                    next ACTIVITYDIALOGPERMISSION
-                        if !$PermissionRights{ $CurrentActivityDialog->{Permission} };
+                    if ( !$PermissionRights{ $CurrentActivityDialog->{Permission} } ) {
+                        next ACTIVITYDIALOGPERMISSION;
+                    }
                 }
 
-                push @PermissionActivityDialogList, $CurrentActivityDialogEntityID;
+                $PermissionActivityDialogList{$Index} = $CurrentActivityDialogEntityID;
             }
 
-            my @PossibleActivityDialogs;
-            if (@PermissionActivityDialogList) {
-                @PossibleActivityDialogs = $Self->{TicketObject}->TicketAclActivityDialogData(
-                    ActivityDialogs => \@PermissionActivityDialogList
-                );
-            }
+            # reduce next activity dialogs to the ones that have permissions
+            $NextActivityDialogs = \%PermissionActivityDialogList;
 
-            # reformat the @PossibleActivityDialogs that is of the structure:
-            # @PossibleActivityDialogs = ('AD1', 'AD3', 'AD4', 'AD2');
-            # to get the same structure as in the %NextActivityDialogs
-            # e.g.:
-            # 1 => 'AD1',
-            # 2 => 'AD3',
-            %{$NextActivityDialogs} = map { $_ => $PossibleActivityDialogs[ $_ - 1 ] }
-                1 .. scalar @PossibleActivityDialogs;
+            # get ACL restrictions
+            my $ACL = $Self->{TicketObject}->TicketAcl(
+                Data           => \%PermissionActivityDialogList,
+                TicketID       => $Param{TicketID},
+                Action         => $Self->{Action},
+                ReturnType     => 'ActivityDialog',
+                ReturnSubType  => '-',
+                CustomerUserID => $Self->{UserID},
+            );
+
+            if ($ACL) {
+                %{$NextActivityDialogs} = $Self->{TicketObject}->TicketAclData()
+            }
 
             $Self->{LayoutObject}->Block(
                 Name => 'NextActivities',
@@ -1335,77 +1369,100 @@ sub _Mask {
             );
         }
 
-        # check if just a only html email
-        if ( my $MimeTypeText = $Self->{LayoutObject}->CheckMimeType( %Param, %Article ) ) {
-            $Param{BodyNote} = $MimeTypeText;
-            $Param{Body}     = '';
-        }
-        else {
-
-            # html quoting
-            $Article{Body} = $Self->{LayoutObject}->Ascii2Html(
-                NewLine        => $Self->{ConfigObject}->Get('DefaultViewNewLine'),
-                Text           => $Article{Body},
-                VMax           => $Self->{ConfigObject}->Get('DefaultViewLines') || 5000,
-                HTMLResultMode => 1,
-                LinkFeature    => 1,
+        if ( $Article{ArticleType} eq 'chat-external' || $Article{ArticleType} eq 'chat-internal' )
+        {
+            $Self->{LayoutObject}->Block(
+                Name => 'BodyChat',
+                Data => {
+                    ChatMessages => $Kernel::OM->Get('Kernel::System::JSON')->Decode(
+                        Data => $Article{Body},
+                    ),
+                    }
             );
-
-            # do charset check
-            if ( my $CharsetText = $Self->{LayoutObject}->CheckCharset( %Param, %Article ) ) {
-                $Param{BodyNote} = $CharsetText;
-            }
-        }
-
-        # security="restricted" may break SSO - disable this feature if requested
-        if ( $Self->{ConfigObject}->Get('DisableMSIFrameSecurityRestricted') ) {
-            $Param{MSSecurityRestricted} = '';
         }
         else {
-            $Param{MSSecurityRestricted} = 'security="restricted"';
-        }
 
-        # in case show plain article body (if no html body as attachment exists of if rich
-        # text is not enabled)
-        my $RichText = $Self->{LayoutObject}->{BrowserRichText};
-        if ( $RichText && $Article{AttachmentIDOfHTMLBody} ) {
-            if ( $SelectedArticleID eq $Article{ArticleID} || $Self->{ZoomExpand} ) {
-                $Self->{LayoutObject}->Block(
-                    Name => 'BodyHTMLLoad',
-                    Data => {
-                        %Param,
-                        %Article,
-                    },
-                );
+            # check if just a only html email
+            if ( my $MimeTypeText = $Self->{LayoutObject}->CheckMimeType( %Param, %Article ) ) {
+                $Param{BodyNote} = $MimeTypeText;
+                $Param{Body}     = '';
             }
             else {
-                my $SessionInformation;
 
-                # Append session information to URL if needed
-                if ( !$Self->{LayoutObject}->{SessionIDCookie} ) {
-                    $SessionInformation = $Self->{LayoutObject}->{SessionName} . '='
-                        . $Self->{LayoutObject}->{SessionID};
+                # html quoting
+                $Article{Body} = $Self->{LayoutObject}->Ascii2Html(
+                    NewLine        => $Self->{ConfigObject}->Get('DefaultViewNewLine'),
+                    Text           => $Article{Body},
+                    VMax           => $Self->{ConfigObject}->Get('DefaultViewLines') || 5000,
+                    HTMLResultMode => 1,
+                    LinkFeature    => 1,
+                );
+            }
+
+            # security="restricted" may break SSO - disable this feature if requested
+            if ( $Self->{ConfigObject}->Get('DisableMSIFrameSecurityRestricted') ) {
+                $Param{MSSecurityRestricted} = '';
+            }
+            else {
+                $Param{MSSecurityRestricted} = 'security="restricted"';
+            }
+
+            # in case show plain article body (if no html body as attachment exists of if rich
+            # text is not enabled)
+            my $RichText = $Self->{LayoutObject}->{BrowserRichText};
+            if ( $RichText && $Article{AttachmentIDOfHTMLBody} ) {
+                if ( $SelectedArticleID eq $Article{ArticleID} || $Self->{ZoomExpand} ) {
+                    $Self->{LayoutObject}->Block(
+                        Name => 'BodyHTMLLoad',
+                        Data => {
+                            %Param,
+                            %Article,
+                        },
+                    );
+
+                    # show message about links in iframes, if user didn't close it already
+                    if ( !$Self->{DoNotShowBrowserLinkMessage} ) {
+                        $Self->{LayoutObject}->Block(
+                            Name => 'BrowserLinkMessage',
+                        );
+                    }
                 }
+                else {
+                    my $SessionInformation;
 
+                    # Append session information to URL if needed
+                    if ( !$Self->{LayoutObject}->{SessionIDCookie} ) {
+                        $SessionInformation = $Self->{LayoutObject}->{SessionName} . '='
+                            . $Self->{LayoutObject}->{SessionID};
+                    }
+
+                    $Self->{LayoutObject}->Block(
+                        Name => 'BodyHTMLPlaceholder',
+                        Data => {
+                            %Param,
+                            %Article,
+                            SessionInformation => $SessionInformation,
+                        },
+                    );
+
+                    # show message about links in iframes, if user didn't close it already
+                    if ( !$Self->{DoNotShowBrowserLinkMessage} ) {
+                        $Self->{LayoutObject}->Block(
+                            Name => 'BrowserLinkMessage',
+                        );
+                    }
+                }
+            }
+            else {
                 $Self->{LayoutObject}->Block(
-                    Name => 'BodyHTMLPlaceholder',
+                    Name => 'BodyPlain',
                     Data => {
                         %Param,
                         %Article,
-                        SessionInformation => $SessionInformation,
                     },
                 );
             }
         }
-        else {
-            $Self->{LayoutObject}->Block(
-                Name => 'BodyPlain',
-                Data => {
-                    %Param,
-                    %Article,
-                },
-            );
-        }
 
         # add attachment icon
         if ( $Article{Atms} && %{ $Article{Atms} } ) {
@@ -1437,8 +1494,8 @@ sub _Mask {
                     Data => {
                         %File,
                         Action => 'Download',
-                        Link =>
-                            "\$Env{\"Baselink\"}Action=CustomerTicketAttachment;ArticleID=$Article{ArticleID};FileID=$FileID",
+                        Link   => $Self->{LayoutObject}->{Baselink} .
+                            "Action=CustomerTicketAttachment;ArticleID=$Article{ArticleID};FileID=$FileID",
                         Image  => 'disk-s.png',
                         Target => $Target,
                     },
@@ -1646,7 +1703,15 @@ sub _Mask {
 
         ATTACHMENT:
         for my $Attachment (@Attachments) {
-            next ATTACHMENT if $Attachment->{ContentID} && $Self->{LayoutObject}->{BrowserRichText};
+            if (
+                $Attachment->{ContentID}
+                && $Self->{LayoutObject}->{BrowserRichText}
+                && ( $Attachment->{ContentType} =~ /image/i )
+                && ( $Attachment->{Disposition} eq 'inline' )
+                )
+            {
+                next ATTACHMENT;
+            }
             $Self->{LayoutObject}->Block(
                 Name => 'FollowUpAttachment',
                 Data => $Attachment,
