@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Modules/Installer.pm - provides the DB installer
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -50,13 +51,6 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    if ( $Self->{ConfigObject}->Get('SecureMode') ) {
-        $Self->{LayoutObject}->FatalError(
-            Message => 'SecureMode active!',
-            Comment => 'If you want to re-run the Installer, disable the SecureMode in the SysConfig.',
-        );
-    }
-
     # check env directories
     $Self->{Path} = $Self->{ConfigObject}->Get('Home');
     if ( !-d $Self->{Path} ) {
@@ -164,12 +158,12 @@ sub Run {
     }
 
     # print intro form
-    my $Title = $Self->{LayoutObject}->{LanguageObject}->Get('Install OTRS');
+    my $Title = $Self->{LayoutObject}->{LanguageObject}->Translate('Install OTRS');
     if ( $Self->{Subaction} eq 'Intro' ) {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('Intro')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('Intro')
             );
         $Self->{LayoutObject}->Block(
             Name => 'Intro',
@@ -188,7 +182,7 @@ sub Run {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('License')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('License')
             );
         $Self->{LayoutObject}->Block(
             Name => 'License',
@@ -215,7 +209,7 @@ sub Run {
             my $Output =
                 $Self->{LayoutObject}->Header(
                 Title => "$Title - "
-                    . $Self->{LayoutObject}->{LanguageObject}->Get('Error')
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate('Error')
                 );
             $Output .= $Self->{LayoutObject}->Warning(
                 Message => "Kernel/Config.pm isn't writable!",
@@ -249,7 +243,7 @@ sub Run {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('Database Selection')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('Database Selection')
             );
         $Self->{LayoutObject}->Block(
             Name => 'DatabaseStart',
@@ -323,14 +317,14 @@ sub Run {
 
         if ( $DBType eq 'mysql' ) {
             my $PasswordExplanation = $DBInstallType eq 'CreateDB'
-                ? $Self->{LayoutObject}->{LanguageObject}->Get(
-                'If you have set a root password for your database, it must be entered here. If not, leave this field empty.'
+                ? $Self->{LayoutObject}->{LanguageObject}->Translate(
+                'If you have set a root password for your database, it must be entered here. If not, leave this field empty.',
                 )
-                : $Self->{LayoutObject}->{LanguageObject}->Get('Enter the password for the database user.');
+                : $Self->{LayoutObject}->{LanguageObject}->Translate('Enter the password for the database user.');
             my $Output =
                 $Self->{LayoutObject}->Header(
                 Title => "$Title - "
-                    . $Self->{LayoutObject}->{LanguageObject}->Get('Database') . ' MySQL'
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate('Database') . ' MySQL'
                 );
             $Self->{LayoutObject}->Block(
                 Name => 'DatabaseMySQL',
@@ -374,7 +368,7 @@ sub Run {
             my $Output =
                 $Self->{LayoutObject}->Header(
                 Title => "$Title - "
-                    . $Self->{LayoutObject}->{LanguageObject}->Get('Database')
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate('Database')
                     . ' Microsoft SQL Server'
                 );
             $Self->{LayoutObject}->Block(
@@ -420,7 +414,7 @@ sub Run {
             my $Output =
                 $Self->{LayoutObject}->Header(
                 Title => "$Title - "
-                    . $Self->{LayoutObject}->{LanguageObject}->Get('Database') . ' PostgreSQL'
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate('Database') . ' PostgreSQL'
                 );
             $Self->{LayoutObject}->Block(
                 Name => 'DatabasePostgreSQL',
@@ -460,7 +454,7 @@ sub Run {
             my $Output =
                 $Self->{LayoutObject}->Header(
                 Title => "$Title - "
-                    . $Self->{LayoutObject}->{LanguageObject}->Get('Database') . ' Oracle'
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate('Database') . ' Oracle'
                 );
             $Self->{LayoutObject}->Block(
                 Name => 'DatabaseOracle',
@@ -519,7 +513,7 @@ sub Run {
 
         my $Output = $Self->{LayoutObject}->Header(
             Title => $Title . '-'
-                . $Self->{LayoutObject}->{LanguageObject}->Get(
+                . $Self->{LayoutObject}->{LanguageObject}->Translate(
                 'Create Database'
                 )
         );
@@ -604,8 +598,8 @@ sub Run {
         elsif ( $DB{DBType} eq 'oracle' ) {
 
             # set DSN for Config.pm
-            $DB{ConfigDSN} = 'DBI:Oracle:host=$Self->{DatabaseHost};' . "sid=$DB{DBSID};port=$DB{DBPort}";
-            $DB{DSN}       = "DBI:Oracle:host=$DB{DBHost};sid=$DB{DBSID};port=$DB{DBPort}";
+            $DB{ConfigDSN} = 'DBI:Oracle://$Self->{DatabaseHost}:' . $DB{DBPort} . '/$Self->{Database}';
+            $DB{DSN}       = "DBI:Oracle://$DB{DBHost}:$DB{DBPort}/$DB{DBSID}";
             $Self->{ConfigObject}->Set(
                 Key   => 'Database::Connect',
                 Value => "ALTER SESSION SET NLS_DATE_FORMAT = 'YYYY-MM-DD HH24:MI:SS'",
@@ -656,13 +650,25 @@ sub Run {
         }
 
         # ReConfigure Config.pm
-        my $ReConfigure = $Self->ReConfigure(
-            DatabaseDSN  => $DB{ConfigDSN},
-            DatabaseHost => $DB{DBHost},
-            Database     => $DB{DBName},
-            DatabaseUser => $DB{OTRSDBUser},
-            DatabasePw   => $DB{OTRSDBPassword},
-        );
+        my $ReConfigure;
+        if ( $DB{DBType} eq 'oracle' ) {
+            $ReConfigure = $Self->ReConfigure(
+                DatabaseDSN  => $DB{ConfigDSN},
+                DatabaseHost => $DB{DBHost},
+                Database     => $DB{DBSID},
+                DatabaseUser => $DB{OTRSDBUser},
+                DatabasePw   => $DB{OTRSDBPassword},
+            );
+        }
+        else {
+            $ReConfigure = $Self->ReConfigure(
+                DatabaseDSN  => $DB{ConfigDSN},
+                DatabaseHost => $DB{DBHost},
+                Database     => $DB{DBName},
+                DatabaseUser => $DB{OTRSDBUser},
+                DatabasePw   => $DB{OTRSDBPassword},
+            );
+        }
 
         if ($ReConfigure) {
             my $Output =
@@ -822,7 +828,7 @@ sub Run {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('System Settings')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('System Settings')
             );
 
         $Self->{LayoutObject}->Block(
@@ -922,7 +928,7 @@ sub Run {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('Configure Mail')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('Configure Mail')
             );
         $Self->{LayoutObject}->Block(
             Name => 'ConfigureMail',
@@ -1023,7 +1029,7 @@ sub Run {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('Finished')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('Finished')
             );
         $Self->{LayoutObject}->Block(
             Name => 'Finish',
@@ -1176,7 +1182,7 @@ sub ConnectToDB {
         $Param{DSN} = "DBI:Pg:host=$Param{DBHost};dbname=$Param{DBName}";
     }
     elsif ( $Param{DBType} eq 'oracle' ) {
-        $Param{DSN} = "DBI:Oracle:host=$Param{DBHost};sid=$Param{DBSID};port=$Param{DBPort};"
+        $Param{DSN} = "DBI:Oracle://$Param{DBHost}:$Param{DBPort}/$Param{DBSID}";
     }
 
     # extract driver to load for install test
@@ -1237,6 +1243,47 @@ sub CheckDBRequirements {
         %Param,
     );
 
+    # if mysql, check some more values
+    if ( $Param{DBType} eq 'mysql' && $Result{Successful} == 1 ) {
+
+        # max_allowed_packed
+        my $MySQLMaxAllowedPacket            = 0;
+        my $MySQLMaxAllowedPacketRecommended = 20;
+
+        my $Data = $Result{DBH}->selectall_arrayref("SHOW variables WHERE Variable_name = 'max_allowed_packet'");
+        $MySQLMaxAllowedPacket = $Data->[0]->[1] / 1024 / 1024;
+
+        if ( $MySQLMaxAllowedPacket < $MySQLMaxAllowedPacketRecommended ) {
+            $Result{Successful} = 0;
+            $Result{Message}    = $Self->{LayoutObject}->{LanguageObject}->Translate(
+                "Error: Please make sure your database accepts packages over %s MB in size (it currently only accepts packages up to %s MB). Please adapt the max_allowed_packet setting of your database in order to avoid errors.",
+                $MySQLMaxAllowedPacketRecommended, $MySQLMaxAllowedPacket
+            );
+        }
+    }
+
+    if ( $Param{DBType} eq 'mysql' && $Result{Successful} == 1 ) {
+
+        # innodb_log_file_size
+        my $MySQLInnoDBLogFileSize            = 0;
+        my $MySQLInnoDBLogFileSizeMinimum     = 256;
+        my $MySQLInnoDBLogFileSizeRecommended = 512;
+
+        my $Data = $Result{DBH}->selectall_arrayref("SHOW variables WHERE Variable_name = 'innodb_log_file_size'");
+        $MySQLInnoDBLogFileSize = $Data->[0]->[1] / 1024 / 1024;
+
+        if ( $MySQLInnoDBLogFileSize < $MySQLInnoDBLogFileSizeMinimum ) {
+            $Result{Successful} = 0;
+            $Result{Message}    = $Self->{LayoutObject}->{LanguageObject}->Translate(
+                "Error: Please set the value for innodb_log_file_size on your database to at least %s MB (current: %s MB, recommended: %s MB). For more information, please have a look at %s.",
+                $MySQLInnoDBLogFileSizeMinimum,
+                $MySQLInnoDBLogFileSize,
+                $MySQLInnoDBLogFileSizeRecommended,
+                'http://dev.mysql.com/doc/refman/5.6/en/innodb-data-log-reconfiguration.html',
+            );
+        }
+    }
+
     # delete not necessary key/value pairs
     delete $Result{DB};
     delete $Result{DBH};
