@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Output/HTML/DashboardRSS.pm
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +14,8 @@ use warnings;
 
 use XML::FeedPP;
 
+our $ObjectManagerDisabled = 1;
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -20,12 +23,9 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (
-        qw(Config Name ConfigObject LogObject DBObject LayoutObject ParamObject TicketObject UserID)
-        )
-    {
-        die "Got no $_!" if ( !$Self->{$_} );
+    # get needed parameters
+    for my $Needed (qw(Config Name UserID)) {
+        die "Got no $Needed!" if ( !$Self->{$Needed} );
     }
 
     return $Self;
@@ -42,7 +42,9 @@ sub Config {
 
     return (
         %{ $Self->{Config} },
-        CacheKey => 'RSS' . $Self->{Config}->{URL} . '-' . $Self->{LayoutObject}->{UserLanguage},
+        CacheKey => 'RSS'
+            . $Self->{Config}->{URL} . '-'
+            . $Kernel::OM->Get('Kernel::Output::HTML::Layout')->{UserLanguage},
     );
 }
 
@@ -52,7 +54,10 @@ sub Run {
     # Default URL
     my $FeedURL = $Self->{Config}->{URL};
 
-    my $Language = $Self->{LayoutObject}->{UserLanguage};
+    # get layout object
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
+    my $Language = $LayoutObject->{UserLanguage};
 
     # Check if URL for UserLanguage is available
     if ( $Self->{Config}->{"URL_$Language"} ) {
@@ -69,9 +74,9 @@ sub Run {
 
     # set proxy settings can't use Kernel::System::WebAgent because of used
     # XML::FeedPP to get RSS files
-    my $Proxy = $Self->{ConfigObject}->Get('WebUserAgent::Proxy');
+    my $Proxy = $Kernel::OM->Get('Kernel::Config')->Get('WebUserAgent::Proxy');
     if ($Proxy) {
-        $ENV{CGI_HTTP_PROXY} = $Proxy;
+        $ENV{CGI_HTTP_PROXY} = $Proxy;    ## no critic
     }
 
     # get content
@@ -85,27 +90,32 @@ sub Run {
 
     if ( !$Feed ) {
         my $Content = "Can't connect to $FeedURL";
+
         return $Content;
     }
 
+    # get time object
+    my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
+
     my $Count = 0;
+    ITEM:
     for my $Item ( $Feed->get_item() ) {
         $Count++;
-        last if $Count > $Self->{Config}->{Limit};
+        last ITEM if $Count > $Self->{Config}->{Limit};
         my $Time = $Item->pubDate();
         my $Ago;
         if ($Time) {
-            my $SystemTime = $Self->{TimeObject}->TimeStamp2SystemTime(
+            my $SystemTime = $TimeObject->TimeStamp2SystemTime(
                 String => $Time,
             );
-            $Ago = $Self->{TimeObject}->SystemTime() - $SystemTime;
-            $Ago = $Self->{LayoutObject}->CustomerAge(
+            $Ago = $TimeObject->SystemTime() - $SystemTime;
+            $Ago = $LayoutObject->CustomerAge(
                 Age   => $Ago,
                 Space => ' ',
             );
         }
 
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ContentSmallRSSOverviewRow',
             Data => {
                 Title => $Item->title(),
@@ -113,7 +123,7 @@ sub Run {
             },
         );
         if ($Ago) {
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'ContentSmallRSSTimeStamp',
                 Data => {
                     Ago   => $Ago,
@@ -123,7 +133,7 @@ sub Run {
             );
         }
         else {
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'ContentSmallRSS',
                 Data => {
                     Ago   => $Ago,
@@ -133,7 +143,7 @@ sub Run {
             );
         }
     }
-    my $Content = $Self->{LayoutObject}->Output(
+    my $Content = $LayoutObject->Output(
         TemplateFile => 'AgentDashboardRSSOverview',
         Data         => {
             %{ $Self->{Config} },
