@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Output/HTML/LayoutLoader.pm - provides generic HTML output
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -71,6 +72,9 @@ sub LoaderCreateAgentCSSCalls {
         || $Self->{ConfigObject}->Get('Loader::Agent::DefaultSelectedSkin')
         || 'default';
 
+    # save selected skin
+    $Self->{SkinSelected} = $SkinSelected;
+
     my $SkinHome = $Self->{ConfigObject}->Get('Home') . '/var/httpd/htdocs/skins';
     my $DoMinify = $Self->{ConfigObject}->Get('Loader::Enabled::CSS');
 
