@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Output/HTML/NotificationCustomerOnline.pm
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -60,7 +61,12 @@ sub Run {
         $Param{Message} .= "$Online{$_}";
     }
     if ( $Param{Message} ) {
-        return $Self->{LayoutObject}->Notify( Info => 'Online Customer: %s", "' . $Param{Message} );
+        return $Self->{LayoutObject}->Notify(
+            Info => $Self->{LayoutObject}->{LanguageObject}->Translate(
+                'Online Customer: %s',
+                $Param{Message},
+            ),
+        );
     }
     else {
         return '';
