@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Output/HTML/TicketMenuResponsible.pm
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -77,6 +78,7 @@ sub Run {
     if ( $Param{Config}->{Group} ) {
         my @Items = split /;/, $Param{Config}->{Group};
         my $AccessOk;
+        GROUP:
         for my $Item (@Items) {
             my ( $Permission, $Name ) = split /:/, $Item;
             if ( !$Permission || !$Name ) {
@@ -91,12 +93,12 @@ sub Run {
                 Type   => $Permission,
                 Result => 'Name',
             );
-            next if !@Groups;
+            next GROUP if !@Groups;
 
             for my $Group (@Groups) {
                 if ( $Group eq $Name ) {
                     $AccessOk = 1;
-                    last;
+                    last GROUP;
                 }
             }
         }
@@ -104,9 +106,8 @@ sub Run {
     }
 
     # check acl
-    return
-        if defined $Param{ACL}->{ $Param{Config}->{Action} }
-        && !$Param{ACL}->{ $Param{Config}->{Action} };
+    my %ACLLookup = reverse( %{ $Param{ACL} || {} } );
+    return if ( !$ACLLookup{ $Param{Config}->{Action} } );
 
     # return item
     return { %{ $Param{Config} }, %{ $Param{Ticket} }, %Param };
