@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Output/HTML/TicketOverviewPreview.pm
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,8 +12,6 @@ package Kernel::Output::HTML::TicketOverviewPreview;
 use strict;
 use warnings;
 
-use URI::Escape ();
-
 use Kernel::System::CustomerUser;
 use Kernel::System::SystemAddress;
 use Kernel::System::DynamicField;
@@ -79,11 +78,12 @@ sub ActionRow {
             $BulkFeature = 1;
         }
         else {
+            GROUP:
             for my $Group (@Groups) {
-                next if !$Self->{LayoutObject}->{"UserIsGroup[$Group]"};
+                next GROUP if !$Self->{LayoutObject}->{"UserIsGroup[$Group]"};
                 if ( $Self->{LayoutObject}->{"UserIsGroup[$Group]"} eq 'Yes' ) {
                     $BulkFeature = 1;
-                    last;
+                    last GROUP;
                 }
             }
         }
@@ -159,7 +159,7 @@ sub ActionRow {
                     Name => $Item->{Block},
                     Data => {
                         ID          => $Item->{ID},
-                        Name        => $Self->{LayoutObject}->{LanguageObject}->Get( $Item->{Name} ),
+                        Name        => $Self->{LayoutObject}->{LanguageObject}->Translate( $Item->{Name} ),
                         Link        => $Self->{LayoutObject}->{Baselink} . $Item->{Link},
                         Description => $Item->{Description},
                         Block       => $Item->{Block},
@@ -223,11 +223,12 @@ sub Run {
             $BulkFeature = 1;
         }
         else {
+            GROUP:
             for my $Group (@Groups) {
-                next if !$Self->{LayoutObject}->{"UserIsGroup[$Group]"};
+                next GROUP if !$Self->{LayoutObject}->{"UserIsGroup[$Group]"};
                 if ( $Self->{LayoutObject}->{"UserIsGroup[$Group]"} eq 'Yes' ) {
                     $BulkFeature = 1;
-                    last;
+                    last GROUP;
                 }
             }
         }
@@ -368,7 +369,7 @@ sub _Show {
     if ( !%Article ) {
         %Article = %Ticket;
         if ( !$Article{Title} ) {
-            $Article{Title} = $Self->{LayoutObject}->{LanguageObject}->Get(
+            $Article{Title} = $Self->{LayoutObject}->{LanguageObject}->Translate(
                 'This ticket has no title or subject'
             );
         }
@@ -407,21 +408,40 @@ sub _Show {
         }
     }
 
-    # get acl actions
-    $Self->{TicketObject}->TicketAcl(
-        Data          => '-',
+    # get ACL restrictions
+    my %PossibleActions;
+    my $Counter = 0;
+
+    # get all registered Actions
+    if ( ref $Self->{ConfigObject}->Get('Frontend::Module') eq 'HASH' ) {
+
+        my %Actions = %{ $Self->{ConfigObject}->Get('Frontend::Module') };
+
+        # only use those Actions that stats with AgentTicket
+        %PossibleActions = map { ++$Counter => $_ }
+            grep { substr( $_, 0, length 'AgentTicket' ) eq 'AgentTicket' }
+            sort keys %Actions;
+    }
+
+    my $ACL = $Self->{TicketObject}->TicketAcl(
+        Data          => \%PossibleActions,
         Action        => $Self->{Action},
         TicketID      => $Article{TicketID},
         ReturnType    => 'Action',
         ReturnSubType => '-',
         UserID        => $Self->{UserID},
     );
-    my %AclAction = $Self->{TicketObject}->TicketAclActionData();
+
+    my %AclAction = %PossibleActions;
+    if ($ACL) {
+        %AclAction = $Self->{TicketObject}->TicketAclActionData();
+    }
 
     # run ticket pre menu modules
     my @ActionItems;
     if ( ref $Self->{ConfigObject}->Get('Ticket::Frontend::PreMenuModule') eq 'HASH' ) {
         my %Menus = %{ $Self->{ConfigObject}->Get('Ticket::Frontend::PreMenuModule') };
+        MENU:
         for my $Menu ( sort keys %Menus ) {
 
             # load module
@@ -441,19 +461,8 @@ sub _Show {
                 Config => $Menus{$Menu},
             );
 
-            next if !$Item;
-            next if ref $Item ne 'HASH';
-            for my $Key (qw(Name Link Description)) {
-                next if !$Item->{$Key};
-                $Item->{$Key} = $Self->{LayoutObject}->Output(
-                    Template => $Item->{$Key},
-                    Data     => \%Article,
-                );
-            }
-
-            # add the return module to redirect back to the current screen afterwards
-            my $ReturnPath = URI::Escape::uri_escape( $Self->{LayoutObject}->{EnvRef}->{RequestedURL} );
-            $Item->{Link} .= ';ReturnModule=' . $ReturnPath;
+            next MENU if !$Item;
+            next MENU if ref $Item ne 'HASH';
 
             # add session id if needed
             if ( !$Self->{LayoutObject}->{SessionIDCookie} && $Item->{Link} ) {
@@ -467,14 +476,27 @@ sub _Show {
             $Item->{ID} = $Item->{Name};
             $Item->{ID} =~ s/(\s|&|;)//ig;
 
-            $Self->{LayoutObject}->Block(
-                Name => $Item->{Block} || 'DocumentMenuItem',
-                Data => $Item,
-            );
-            my $Output = $Self->{LayoutObject}->Output(
-                TemplateFile => 'AgentTicketOverviewPreview',
-                Data         => $Item,
-            );
+            my $Output;
+            if ( $Item->{Block} ) {
+                $Self->{LayoutObject}->Block(
+                    Name => $Item->{Block},
+                    Data => $Item,
+                );
+                $Output = $Self->{LayoutObject}->Output(
+                    TemplateFile => 'AgentTicketOverviewPreview',
+                    Data         => $Item,
+                );
+            }
+            else {
+                $Output = '<li id="'
+                    . $Item->{ID}
+                    . '"><a href="#" title="'
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate( $Item->{Description} )
+                    . '">'
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate( $Item->{Name} )
+                    . '</a></li>';
+            }
+
             $Output =~ s/\n+//g;
             $Output =~ s/\s+/ /g;
             $Output =~ s/<\!--.+?-->//g;
@@ -482,12 +504,12 @@ sub _Show {
             push @ActionItems, {
                 HTML        => $Output,
                 ID          => $Item->{ID},
-                Name        => $Self->{LayoutObject}->{LanguageObject}->Get( $Item->{Name} ),
+                Name        => $Self->{LayoutObject}->{LanguageObject}->Translate( $Item->{Name} ),
                 Link        => $Self->{LayoutObject}->{Baselink} . $Item->{Link},
                 Target      => $Item->{Target},
                 PopupType   => $Item->{PopupType},
                 Description => $Item->{Description},
-                Block       => $Item->{Block} || 'DocumentMenuItem',
+                Block       => $Item->{Block},
 
             };
         }
@@ -525,7 +547,7 @@ sub _Show {
                 $Class = 'AsPopup PopupType_' . $Item->{PopupType};
             }
 
-            if ( $Item->{Block} eq 'DocumentMenuItem' ) {
+            if ( !$Item->{Block} ) {
                 $Self->{LayoutObject}->Block(
                     Name => 'InlineActionRowItem',
                     Data => {
@@ -809,8 +831,8 @@ sub _Show {
     }
 
     # Dynamic fields
-    my $Counter = 0;
-    my $Class   = 'Middle';
+    $Counter = 0;
+    my $Class = 'Middle';
 
     # cycle trough the activated Dynamic Fields for this screen
     DYNAMICFIELD:
@@ -958,13 +980,14 @@ sub _Show {
         if ($PreviewArticleTypeExpanded) {
 
             my $ClassCount = 0;
+            ARTICLE_ITEM:
             for my $ArticleItem (@ArticleBody) {
-                next if !$ArticleItem;
+                next ARTICLE_ITEM if !$ArticleItem;
 
                 # check if current article type should be shown as expanded
                 if ( $ArticleItem->{ArticleType} eq $PreviewArticleTypeExpanded ) {
                     $ArticleItem->{Class} = 'Active';
-                    last;
+                    last ARTICLE_ITEM;
                 }
 
                 # otherwise display the last article in the list as expanded (default)
@@ -1009,15 +1032,6 @@ sub _Show {
                 HTMLResultMode  => 1,
                 StripEmptyLines => $Param{Config}->{StripEmptyLines},
             );
-
-            # do charset check
-            my $CharsetText = $Self->{LayoutObject}->CheckCharset(
-                %{$ArticleItem},
-                Action => 'AgentTicketZoom',
-            );
-            if ($CharsetText) {
-                $ArticleItem->{BodyNote} = $CharsetText;
-            }
         }
 
         $ArticleItem->{Subject} = $Self->{TicketObject}->TicketSubjectClean(
@@ -1072,7 +1086,7 @@ sub _Show {
                         }
                     }
                 }
-                if ( $Access && !$Param{Output} ) {
+                if ($Access) {
                     $Self->{LayoutObject}->Block(
                         Name => 'ArticlePreviewActionRow',
                         Data => {
@@ -1109,7 +1123,8 @@ sub _Show {
                         {
                             Key   => '0',
                             Value => '- '
-                                . $Self->{LayoutObject}->{LanguageObject}->Get('Reply') . ' -',
+                                . $Self->{LayoutObject}->{LanguageObject}->Translate('Reply')
+                                . ' -',
                             Selected => 1,
                         }
                     );
@@ -1135,8 +1150,9 @@ sub _Show {
 
                     # check if reply all is needed
                     my $Recipients = '';
+                    KEY:
                     for my $Key (qw(From To Cc)) {
-                        next if !$ArticleItem->{$Key};
+                        next KEY if !$ArticleItem->{$Key};
                         if ($Recipients) {
                             $Recipients .= ', ';
                         }
@@ -1149,13 +1165,14 @@ sub _Show {
                             Mode => 'Standalone',
                         );
                         my @Addresses = $EmailParser->SplitAddressLine( Line => $Recipients );
+                        ADDRESS:
                         for my $Address (@Addresses) {
                             my $Email = $EmailParser->GetEmailAddress( Email => $Address );
-                            next if !$Email;
+                            next ADDRESS if !$Email;
                             my $IsLocal = $Self->{SystemAddress}->SystemAddressIsLocalAddress(
                                 Address => $Email,
                             );
-                            next if $IsLocal;
+                            next ADDRESS if $IsLocal;
                             $RecipientCount++;
                         }
                     }
@@ -1168,12 +1185,11 @@ sub _Show {
                             {
                                 Key   => '0',
                                 Value => '- '
-                                    . $Self->{LayoutObject}->{LanguageObject}->Get('Reply All')
+                                    . $Self->{LayoutObject}->{LanguageObject}->Translate('Reply All')
                                     . ' -',
                                 Selected => 1,
                             }
                         );
-
                         $StandardResponsesStrg = $Self->{LayoutObject}->BuildSelection(
                             Name => 'ResponseID',
                             ID   => 'ResponseIDAll' . $ArticleItem->{ArticleID},
@@ -1200,15 +1216,12 @@ sub _Show {
 
     # add action items as js
     if ( @ActionItems && !$Param{Config}->{TicketActionsPerTicket} ) {
-        my $JSON = $Self->{LayoutObject}->JSONEncode(
-            Data => \@ActionItems,
-        );
 
         $Self->{LayoutObject}->Block(
             Name => 'DocumentReadyActionRowAdd',
             Data => {
                 TicketID => $Param{TicketID},
-                Data     => $JSON,
+                Data     => \@ActionItems,
             },
         );
     }
