@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Output/HTML/ToolBarTicketSearchProfile.pm
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -49,7 +50,7 @@ sub Run {
         },
         Name       => 'Profile',
         ID         => 'ToolBarSearchProfile',
-        Title      => $Self->{LayoutObject}->{LanguageObject}->Get('Search template'),
+        Title      => $Self->{LayoutObject}->{LanguageObject}->Translate('Search template'),
         SelectedID => '',
         Max        => $Param{Config}->{MaxWidth},
     );
