@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/AuthSession/FS.pm - provides session filesystem backend
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +14,13 @@ use warnings;
 
 use Storable;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::Time',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -20,17 +28,17 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for (qw(LogObject ConfigObject DBObject TimeObject MainObject EncodeObject)) {
-        $Self->{$_} = $Param{$_} || die "No $_!";
-    }
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
     # get more common params
-    $Self->{SessionSpool}         = $Self->{ConfigObject}->Get('SessionDir');
-    $Self->{SystemID}             = $Self->{ConfigObject}->Get('SystemID');
-    $Self->{AgentSessionLimit}    = $Self->{ConfigObject}->Get('AgentSessionLimit');
-    $Self->{CustomerSessionLimit} = $Self->{ConfigObject}->Get('CustomerSessionLimit');
-    $Self->{SessionActiveTime}    = $Self->{ConfigObject}->Get('SessionActiveTime') || 60 * 10;
+    $Self->{SessionSpool}                = $ConfigObject->Get('SessionDir');
+    $Self->{SystemID}                    = $ConfigObject->Get('SystemID');
+    $Self->{AgentSessionLimit}           = $ConfigObject->Get('AgentSessionLimit');
+    $Self->{AgentSessionPerUserLimit}    = $ConfigObject->Get('AgentSessionPerUserLimit') || 2;
+    $Self->{CustomerSessionLimit}        = $ConfigObject->Get('CustomerSessionLimit');
+    $Self->{CustomerSessionPerUserLimit} = $ConfigObject->Get('CustomerSessionPerUserLimit');
+    $Self->{SessionActiveTime}           = $ConfigObject->Get('SessionActiveTime') || 60 * 10;
 
     return $Self;
 }
@@ -40,7 +48,7 @@ sub CheckSessionID {
 
     # check session id
     if ( !$Param{SessionID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Got no SessionID!!'
         );
@@ -56,20 +64,23 @@ sub CheckSessionID {
 
     if ( !$Data{UserID} || !$Data{UserLogin} ) {
         $Self->{SessionIDErrorMessage} = 'Session invalid. Please log in again.';
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "SessionID: '$Param{SessionID}' is invalid!!!",
         );
         return;
     }
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # remote ip check
     if (
         $Data{UserRemoteAddr} ne $RemoteAddr
-        && $Self->{ConfigObject}->Get('SessionCheckRemoteIP')
+        && $ConfigObject->Get('SessionCheckRemoteIP')
         )
     {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "RemoteIP of '$Param{SessionID}' ($Data{UserRemoteAddr}) is "
                 . "different from registered IP ($RemoteAddr). Invalidating session!"
@@ -77,7 +88,7 @@ sub CheckSessionID {
         );
 
         # delete session id if it isn't the same remote ip?
-        if ( $Self->{ConfigObject}->Get('SessionDeleteIfNotRemoteID') ) {
+        if ( $ConfigObject->Get('SessionDeleteIfNotRemoteID') ) {
             $Self->RemoveSessionID( SessionID => $Param{SessionID} );
         }
 
@@ -85,8 +96,8 @@ sub CheckSessionID {
     }
 
     # check session idle time
-    my $TimeNow            = $Self->{TimeObject}->SystemTime();
-    my $MaxSessionIdleTime = $Self->{ConfigObject}->Get('SessionMaxIdleTime');
+    my $TimeNow            = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
+    my $MaxSessionIdleTime = $ConfigObject->Get('SessionMaxIdleTime');
 
     if ( ( $TimeNow - $MaxSessionIdleTime ) >= $Data{UserLastRequest} ) {
 
@@ -94,14 +105,14 @@ sub CheckSessionID {
 
         my $Timeout = int( ( $TimeNow - $Data{UserLastRequest} ) / ( 60 * 60 ) );
 
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message =>
                 "SessionID ($Param{SessionID}) idle timeout ($Timeout h)! Don't grant access!!!",
         );
 
         # delete session id if too old?
-        if ( $Self->{ConfigObject}->Get('SessionDeleteIfTimeToOld') ) {
+        if ( $ConfigObject->Get('SessionDeleteIfTimeToOld') ) {
             $Self->RemoveSessionID( SessionID => $Param{SessionID} );
         }
 
@@ -109,7 +120,7 @@ sub CheckSessionID {
     }
 
     # check session time
-    my $MaxSessionTime = $Self->{ConfigObject}->Get('SessionMaxTime');
+    my $MaxSessionTime = $ConfigObject->Get('SessionMaxTime');
 
     if ( ( $TimeNow - $MaxSessionTime ) >= $Data{UserSessionStart} ) {
 
@@ -117,13 +128,13 @@ sub CheckSessionID {
 
         my $Timeout = int( ( $TimeNow - $Data{UserSessionStart} ) / ( 60 * 60 ) );
 
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "SessionID ($Param{SessionID}) too old ($Timeout h)! Don't grant access!!!",
         );
 
         # delete session id if too old?
-        if ( $Self->{ConfigObject}->Get('SessionDeleteIfTimeToOld') ) {
+        if ( $ConfigObject->Get('SessionDeleteIfTimeToOld') ) {
             $Self->RemoveSessionID( SessionID => $Param{SessionID} );
         }
 
@@ -144,7 +155,7 @@ sub GetSessionIDData {
 
     # check session id
     if ( !$Param{SessionID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Got no SessionID!!'
         );
@@ -156,7 +167,7 @@ sub GetSessionIDData {
         if $Self->{Cache}->{ $Param{SessionID} };
 
     # read data
-    my $Content = $Self->{MainObject}->FileRead(
+    my $Content = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
         Directory       => $Self->{SessionSpool},
         Filename        => 'Data-' . $Param{SessionID},
         Type            => 'Local',
@@ -185,7 +196,7 @@ sub CreateSessionID {
     my ( $Self, %Param ) = @_;
 
     # get system time
-    my $TimeNow = $Self->{TimeObject}->SystemTime();
+    my $TimeNow = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
 
     # get session limit config
     my $SessionLimit;
@@ -196,15 +207,33 @@ sub CreateSessionID {
         $SessionLimit = $Self->{CustomerSessionLimit};
     }
 
-    if ($SessionLimit) {
+    # get session per user limit config
+    my $SessionPerUserLimit;
+    if ( $Param{UserType} && $Param{UserType} eq 'User' && $Self->{AgentSessionPerUserLimit} ) {
+        $SessionPerUserLimit = $Self->{AgentSessionPerUserLimit};
+    }
+    elsif (
+        $Param{UserType}
+        && $Param{UserType} eq 'Customer'
+        && $Self->{CustomerSessionPerUserLimit}
+        )
+    {
+        $SessionPerUserLimit = $Self->{CustomerSessionPerUserLimit};
+    }
+
+    # get main object
+    my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
+    if ( $SessionLimit || $SessionPerUserLimit ) {
 
         # read data
-        my @List = $Self->{MainObject}->DirectoryRead(
+        my @List = $MainObject->DirectoryRead(
             Directory => $Self->{SessionSpool},
             Filter    => 'State-' . $Self->{SystemID} . '*',
         );
 
         my $ActiveSessionCount = 0;
+        my %ActiveSessionPerUserCount;
         SESSIONID:
         for my $SessionID (@List) {
 
@@ -214,7 +243,7 @@ sub CreateSessionID {
             next SESSIONID if !$SessionID;
 
             # read state data
-            my $StateData = $Self->{MainObject}->FileRead(
+            my $StateData = $MainObject->FileRead(
                 Directory       => $Self->{SessionSpool},
                 Filename        => 'State-' . $SessionID,
                 Type            => 'Local',
@@ -227,9 +256,10 @@ sub CreateSessionID {
 
             my @SessionData = split '####', ${$StateData};
 
-            # get needed timestamps
+            # get needed data
             my $UserType        = $SessionData[0] || '';
-            my $UserLastRequest = $SessionData[2] || $TimeNow;
+            my $UserLogin       = $SessionData[1] || '';
+            my $UserLastRequest = $SessionData[3] || $TimeNow;
 
             next SESSIONID if $UserType ne $Param{UserType};
 
@@ -237,12 +267,29 @@ sub CreateSessionID {
 
             $ActiveSessionCount++;
 
+            $ActiveSessionPerUserCount{$UserLogin} || 0;
+            $ActiveSessionPerUserCount{$UserLogin}++;
+
             next SESSIONID if $ActiveSessionCount < $SessionLimit;
 
             $Self->{SessionIDErrorMessage} = 'Session limit reached! Please try again later.';
 
             return;
         }
+
+        # check session per user limit
+        if (
+            $SessionPerUserLimit
+            && $Param{UserLogin}
+            && defined $ActiveSessionPerUserCount{ $Param{UserLogin} }
+            && $ActiveSessionPerUserCount{ $Param{UserLogin} } >= $SessionPerUserLimit
+            )
+        {
+
+            $Self->{SessionIDErrorMessage} = 'Session per user limit reached!';
+
+            return;
+        }
     }
 
     # get remote address and the http user agent
@@ -250,12 +297,12 @@ sub CreateSessionID {
     my $RemoteUserAgent = $ENV{HTTP_USER_AGENT} || 'none';
 
     # create session id
-    my $SessionID = $Self->{SystemID} . $Self->{MainObject}->GenerateRandomString(
+    my $SessionID = $Self->{SystemID} . $MainObject->GenerateRandomString(
         Length => 32,
     );
 
     # create challenge token
-    my $ChallengeToken = $Self->{MainObject}->GenerateRandomString(
+    my $ChallengeToken = $MainObject->GenerateRandomString(
         Length => 32,
     );
 
@@ -277,7 +324,7 @@ sub CreateSessionID {
     my $DataContent = Storable::nfreeze( \%Data );
 
     # write data file
-    my $FileLocation = $Self->{MainObject}->FileWrite(
+    my $FileLocation = $MainObject->FileWrite(
         Directory       => $Self->{SessionSpool},
         Filename        => 'Data-' . $SessionID,
         Content         => \$DataContent,
@@ -294,13 +341,14 @@ sub CreateSessionID {
 
     # create needed state content
     my $UserType         = $Self->{Cache}->{$SessionID}->{UserType}         || '';
+    my $UserLogin        = $Self->{Cache}->{$SessionID}->{UserLogin}        || '';
     my $UserSessionStart = $Self->{Cache}->{$SessionID}->{UserSessionStart} || '';
     my $UserLastRequest  = $Self->{Cache}->{$SessionID}->{UserLastRequest}  || '';
 
-    my $StateContent = $UserType . '####' . $UserSessionStart . '####' . $UserLastRequest;
+    my $StateContent = $UserType . '####' . $UserLogin . '####' . $UserSessionStart . '####' . $UserLastRequest;
 
     # write state file
-    $Self->{MainObject}->FileWrite(
+    $MainObject->FileWrite(
         Directory       => $Self->{SessionSpool},
         Filename        => 'State-' . $SessionID,
         Content         => \$StateContent,
@@ -318,21 +366,24 @@ sub RemoveSessionID {
 
     # check session id
     if ( !$Param{SessionID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Got no SessionID!!'
         );
         return;
     }
 
+    # get main object
+    my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
     # delete file
-    my $DeleteData = $Self->{MainObject}->FileDelete(
+    my $DeleteData = $MainObject->FileDelete(
         Directory       => $Self->{SessionSpool},
         Filename        => 'Data-' . $Param{SessionID},
         Type            => 'Local',
         DisableWarnings => 1,
     );
-    my $DeleteState = $Self->{MainObject}->FileDelete(
+    my $DeleteState = $MainObject->FileDelete(
         Directory       => $Self->{SessionSpool},
         Filename        => 'State-' . $Param{SessionID},
         Type            => 'Local',
@@ -346,7 +397,7 @@ sub RemoveSessionID {
     delete $Self->{Cache}->{ $Param{SessionID} };
 
     # log event
-    $Self->{LogObject}->Log(
+    $Kernel::OM->Get('Kernel::System::Log')->Log(
         Priority => 'notice',
         Message  => "Removed SessionID $Param{SessionID}."
     );
@@ -360,7 +411,7 @@ sub UpdateSessionID {
     # check needed stuff
     for (qw(SessionID Key)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -385,7 +436,7 @@ sub GetAllSessionIDs {
     my ( $Self, %Param ) = @_;
 
     # read data
-    my @List = $Self->{MainObject}->DirectoryRead(
+    my @List = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
         Directory => $Self->{SessionSpool},
         Filter    => 'Data-' . $Self->{SystemID} . '*',
     );
@@ -403,15 +454,21 @@ sub GetAllSessionIDs {
 sub GetExpiredSessionIDs {
     my ( $Self, %Param ) = @_;
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # get config
-    my $MaxSessionTime     = $Self->{ConfigObject}->Get('SessionMaxTime');
-    my $MaxSessionIdleTime = $Self->{ConfigObject}->Get('SessionMaxIdleTime');
+    my $MaxSessionTime     = $ConfigObject->Get('SessionMaxTime');
+    my $MaxSessionIdleTime = $ConfigObject->Get('SessionMaxIdleTime');
 
     # get current time
-    my $TimeNow = $Self->{TimeObject}->SystemTime();
+    my $TimeNow = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
+
+    # get main object
+    my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
 
     # read data
-    my @List = $Self->{MainObject}->DirectoryRead(
+    my @List = $MainObject->DirectoryRead(
         Directory => $Self->{SessionSpool},
         Filter    => 'State-' . $Self->{SystemID} . '*',
     );
@@ -427,7 +484,7 @@ sub GetExpiredSessionIDs {
         next SESSIONID if !$SessionID;
 
         # read state data
-        my $StateData = $Self->{MainObject}->FileRead(
+        my $StateData = $MainObject->FileRead(
             Directory       => $Self->{SessionSpool},
             Filename        => 'State-' . $SessionID,
             Type            => 'Local',
@@ -440,9 +497,9 @@ sub GetExpiredSessionIDs {
 
         my @SessionData = split '####', ${$StateData};
 
-        # get needed timestamps
-        my $UserSessionStart = $SessionData[1] || $TimeNow;
-        my $UserLastRequest  = $SessionData[2] || $TimeNow;
+        # get needed data
+        my $UserSessionStart = $SessionData[2] || $TimeNow;
+        my $UserLastRequest  = $SessionData[3] || $TimeNow;
 
         # time calculation
         my $ValidTime     = $UserSessionStart + $MaxSessionTime - $TimeNow;
@@ -486,6 +543,9 @@ sub DESTROY {
 
     return 1 if !$Self->{Cache};
 
+    # get main object
+    my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
     SESSIONID:
     for my $SessionID ( sort keys %{ $Self->{Cache} } ) {
 
@@ -504,7 +564,7 @@ sub DESTROY {
         my $DataContent = Storable::nfreeze( \%SessionData );
 
         # write data file
-        $Self->{MainObject}->FileWrite(
+        $MainObject->FileWrite(
             Directory       => $Self->{SessionSpool},
             Filename        => 'Data-' . $SessionID,
             Content         => \$DataContent,
@@ -516,13 +576,17 @@ sub DESTROY {
 
         # create needed state content
         my $UserType         = $Self->{Cache}->{$SessionID}->{UserType}         || '';
+        my $UserLogin        = $Self->{Cache}->{$SessionID}->{UserLogin}        || '';
         my $UserSessionStart = $Self->{Cache}->{$SessionID}->{UserSessionStart} || '';
         my $UserLastRequest  = $Self->{Cache}->{$SessionID}->{UserLastRequest}  || '';
 
-        my $StateContent = $UserType . '####' . $UserSessionStart . '####' . $UserLastRequest;
+        my $StateContent = $UserType . '####'
+            . $UserLogin . '####'
+            . $UserSessionStart . '####'
+            . $UserLastRequest;
 
         # write state file
-        $Self->{MainObject}->FileWrite(
+        $MainObject->FileWrite(
             Directory       => $Self->{SessionSpool},
             Filename        => 'State-' . $SessionID,
             Content         => \$StateContent,
