@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/CustomerAuth.pm - provides the authentication
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,7 +12,14 @@ package Kernel::System::CustomerAuth;
 use strict;
 use warnings;
 
-use Kernel::System::CustomerUser;
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::CustomerUser',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::SystemMaintenance',
+    'Kernel::System::Time',
+);
 
 =head1 NAME
 
@@ -29,48 +37,11 @@ The authentication module for the customer interface.
 
 =item new()
 
-create an object
+create an object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-    use Kernel::System::Time;
-    use Kernel::System::DB;
-    use Kernel::System::CustomerAuth;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $AuthObject = Kernel::System::CustomerAuth->new(
-        EncodeObject => $EncodeObject,
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-        DBObject     => $DBObject,
-        TimeObject   => $TimeObject,
-        MainObject   => $MainObject,
-        EncodeObject => $EncodeObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $CustomerUserObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
 
 =cut
 
@@ -81,25 +52,25 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for (qw(LogObject ConfigObject DBObject MainObject EncodeObject TimeObject)) {
-        $Self->{$_} = $Param{$_} || die "No $_!";
-    }
-
-    # get customer user object to validate customers
-    $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new( %{$Self} );
+    # get needed objects
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+    my $MainObject   = $Kernel::OM->Get('Kernel::System::Main');
 
     # load generator auth module
+    SOURCE:
     for my $Count ( '', 1 .. 10 ) {
-        my $GenericModule = $Self->{ConfigObject}->Get("Customer::AuthModule$Count");
-        next if !$GenericModule;
+        my $GenericModule = $ConfigObject->Get("Customer::AuthModule$Count");
+        next SOURCE if !$GenericModule;
 
-        if ( !$Self->{MainObject}->Require($GenericModule) ) {
-            $Self->{MainObject}->Die("Can't load backend module $GenericModule! $@");
+        if ( !$MainObject->Require($GenericModule) ) {
+            $MainObject->Die("Can't load backend module $GenericModule! $@");
         }
         $Self->{"Backend$Count"} = $GenericModule->new( %{$Self}, Count => $Count );
     }
 
+    # Initialize last error message
+    $Self->{LastErrorMessage} = '';
+
     return $Self;
 }
 
@@ -135,34 +106,39 @@ The authentication function.
 sub Auth {
     my ( $Self, %Param ) = @_;
 
+    # get customer user object
+    my $ConfigObject       = $Kernel::OM->Get('Kernel::Config');
+    my $CustomerUserObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
+
     # use all 11 backends and return on first auth
     my $User;
+    COUNT:
     for ( '', 1 .. 10 ) {
 
         # next on no config setting
-        next if !$Self->{"Backend$_"};
+        next COUNT if !$Self->{"Backend$_"};
 
         # check auth backend
         $User = $Self->{"Backend$_"}->Auth(%Param);
 
         # remember auth backend
         if ($User) {
-            $Self->{CustomerUserObject}->SetPreferences(
+            $CustomerUserObject->SetPreferences(
                 Key    => 'UserAuthBackend',
                 Value  => $_,
                 UserID => $User,
             );
-            last;
+            last COUNT;
         }
     }
 
     # check if record exists
     if ( !$User ) {
-        my %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet( User => $Param{User} );
+        my %CustomerData = $CustomerUserObject->CustomerUserDataGet( User => $Param{User} );
         if (%CustomerData) {
             my $Count = $CustomerData{UserLoginFailed} || 0;
             $Count++;
-            $Self->{CustomerUserObject}->SetPreferences(
+            $CustomerUserObject->SetPreferences(
                 Key    => 'UserLoginFailed',
                 Value  => $Count,
                 UserID => $CustomerData{UserLogin},
@@ -172,9 +148,9 @@ sub Auth {
     }
 
     # check if user is valid
-    my %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet( User => $User );
+    my %CustomerData = $CustomerUserObject->CustomerUserDataGet( User => $User );
     if ( defined $CustomerData{ValidID} && $CustomerData{ValidID} ne 1 ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "CustomerUser: '$User' is set to invalid, can't login!",
         );
@@ -184,22 +160,54 @@ sub Auth {
     return $User if !%CustomerData;
 
     # reset failed logins
-    $Self->{CustomerUserObject}->SetPreferences(
+    $CustomerUserObject->SetPreferences(
         Key    => 'UserLoginFailed',
         Value  => 0,
         UserID => $CustomerData{UserLogin},
     );
 
+    # on system maintenance customers
+    # shouldn't be allowed get into the system
+    my $ActiveMaintenance = $Kernel::OM->Get('Kernel::System::SystemMaintenance')->SystemMaintenanceIsActive();
+
+    # check if system maintenance is active
+    if ($ActiveMaintenance) {
+
+        $Self->{LastErrorMessage} =
+            $ConfigObject->Get('SystemMaintenance::IsActiveDefaultLoginErrorMessage')
+            || "It is currently not possible to login due to a scheduled system maintenance.";
+
+        return;
+    }
+
     # last login preferences update
-    $Self->{CustomerUserObject}->SetPreferences(
+    $CustomerUserObject->SetPreferences(
         Key    => 'UserLastLogin',
-        Value  => $Self->{TimeObject}->SystemTime(),
+        Value  => $Kernel::OM->Get('Kernel::System::Time')->SystemTime(),
         UserID => $CustomerData{UserLogin},
     );
 
     return $User;
 }
 
+=item GetLastErrorMessage()
+
+Retrieve $Self->{LastErrorMessage} content.
+
+    my $AuthErrorMessage = $AuthObject->GetLastErrorMessage();
+
+    Result:
+
+        $AuthErrorMessage = "An error string message.";
+
+=cut
+
+sub GetLastErrorMessage {
+    my ( $Self, %Param ) = @_;
+
+    return $Self->{LastErrorMessage};
+}
+
 1;
 
 =back
