@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/CustomerAuth/DB.pm - provides the db authentication
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,9 +12,17 @@ package Kernel::System::CustomerAuth::DB;
 use strict;
 use warnings;
 
-use Crypt::PasswdMD5 qw(unix_md5_crypt);
+use Crypt::PasswdMD5 qw(unix_md5_crypt apache_md5_crypt);
 use Digest::SHA;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::DB',
+    'Kernel::System::Encode',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -21,41 +30,38 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for (qw(LogObject ConfigObject DBObject MainObject EncodeObject)) {
-        $Self->{$_} = $Param{$_} || die "No $_!";
-    }
+    # get database object
+    $Self->{DBObject} = $Kernel::OM->Get('Kernel::System::DB');
 
     # Debug 0=off 1=on
     $Self->{Debug} = 0;
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # config options
-    $Self->{Table} = $Self->{ConfigObject}->Get( 'Customer::AuthModule::DB::Table' . $Param{Count} )
+    $Self->{Table} = $ConfigObject->Get( 'Customer::AuthModule::DB::Table' . $Param{Count} )
         || die "Need CustomerAuthModule::DB::Table$Param{Count} in Kernel/Config.pm!";
-    $Self->{Key} = $Self->{ConfigObject}->Get( 'Customer::AuthModule::DB::CustomerKey' . $Param{Count} )
+    $Self->{Key} = $ConfigObject->Get( 'Customer::AuthModule::DB::CustomerKey' . $Param{Count} )
         || die "Need CustomerAuthModule::DB::CustomerKey$Param{Count} in Kernel/Config.pm!";
-    $Self->{Pw} = $Self->{ConfigObject}->Get( 'Customer::AuthModule::DB::CustomerPassword' . $Param{Count} )
+    $Self->{Pw} = $ConfigObject->Get( 'Customer::AuthModule::DB::CustomerPassword' . $Param{Count} )
         || die "Need CustomerAuthModule::DB::CustomerPw$Param{Count} in Kernel/Config.pm!";
-    $Self->{CryptType} = $Self->{ConfigObject}->Get( 'Customer::AuthModule::DB::CryptType' . $Param{Count} )
+    $Self->{CryptType} = $ConfigObject->Get( 'Customer::AuthModule::DB::CryptType' . $Param{Count} )
         || '';
 
-    if ( $Self->{ConfigObject}->Get( 'Customer::AuthModule::DB::DSN' . $Param{Count} ) ) {
+    if ( $ConfigObject->Get( 'Customer::AuthModule::DB::DSN' . $Param{Count} ) ) {
         $Self->{DBObject} = Kernel::System::DB->new(
-            LogObject    => $Param{LogObject},
-            ConfigObject => $Param{ConfigObject},
-            MainObject   => $Param{MainObject},
-            EncodeObject => $Param{EncodeObject},
             DatabaseDSN =>
-                $Self->{ConfigObject}->Get( 'Customer::AuthModule::DB::DSN' . $Param{Count} ),
+                $ConfigObject->Get( 'Customer::AuthModule::DB::DSN' . $Param{Count} ),
             DatabaseUser =>
-                $Self->{ConfigObject}->Get( 'Customer::AuthModule::DB::User' . $Param{Count} ),
+                $ConfigObject->Get( 'Customer::AuthModule::DB::User' . $Param{Count} ),
             DatabasePw =>
-                $Self->{ConfigObject}->Get( 'Customer::AuthModule::DB::Password' . $Param{Count} ),
-            Type => $Self->{ConfigObject}->Get( 'Customer::AuthModule::DB::Type' . $Param{Count} )
+                $ConfigObject->Get( 'Customer::AuthModule::DB::Password' . $Param{Count} ),
+            Type => $ConfigObject->Get( 'Customer::AuthModule::DB::Type' . $Param{Count} )
                 || '',
             )
             || die "Can't connect to "
-            . $Self->{ConfigObject}->Get( 'Customer::AuthModule::DB::DSN' . $Param{Count} );
+            . $ConfigObject->Get( 'Customer::AuthModule::DB::DSN' . $Param{Count} );
 
         # remember that we have the DBObject not from parent call
         $Self->{NotParentDBObject} = 1;
@@ -69,7 +75,7 @@ sub GetOption {
 
     # check needed stuff
     if ( !$Param{What} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Need What!"
         );
@@ -90,7 +96,7 @@ sub Auth {
 
     # check needed stuff
     if ( !$Param{User} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Need User!"
         );
@@ -105,9 +111,14 @@ sub Auth {
     my $GetPw      = '';
 
     # sql query
-    my $SQL = "SELECT $Self->{Pw}, $Self->{Key} FROM $Self->{Table} WHERE "
-        . " $Self->{Key} = '" . $Self->{DBObject}->Quote($User) . "'";
-    $Self->{DBObject}->Prepare( SQL => $SQL );
+    $Self->{DBObject}->Prepare(
+        SQL => "
+            SELECT $Self->{Pw}, $Self->{Key} FROM $Self->{Table} WHERE
+            $Self->{Key} = ?
+            ",
+        Bind => [ \$Param{User} ],
+    );
+
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $GetPw  = $Row[0];
         $UserID = $Row[1];
@@ -115,7 +126,7 @@ sub Auth {
 
     # check if user exists in auth table
     if ( !$UserID ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "CustomerUser: No auth record in '$Self->{Table}' for '$User' "
                 . "(REMOTE_ADDR: $RemoteAddr)",
@@ -123,6 +134,9 @@ sub Auth {
         return;
     }
 
+    # get encode object
+    my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
+
     # crypt given pw
     my $CryptedPw = '';
     my $Salt      = $GetPw;
@@ -138,14 +152,20 @@ sub Auth {
         if ( $GetPw =~ m{\A \$.+? \$.+? \$.* \z}xms ) {
 
             # strip Salt
-            $Salt =~ s/^\$.+?\$(.+?)\$.*$/$1/;
+            $Salt =~ s/^(\$.+?\$)(.+?)\$.*$/$2/;
+            my $Magic = $1;
 
             # encode output, needed by unix_md5_crypt() only non utf8 signs
-            $Self->{EncodeObject}->EncodeOutput( \$Pw );
-            $Self->{EncodeObject}->EncodeOutput( \$Salt );
+            $EncodeObject->EncodeOutput( \$Pw );
+            $EncodeObject->EncodeOutput( \$Salt );
 
-            $CryptedPw = unix_md5_crypt( $Pw, $Salt );
-            $Self->{EncodeObject}->EncodeInput( \$CryptedPw );
+            if ( $Magic eq '$apr1$' ) {
+                $CryptedPw = apache_md5_crypt( $Pw, $Salt );
+            }
+            else {
+                $CryptedPw = unix_md5_crypt( $Pw, $Salt );
+            }
+            $EncodeObject->EncodeInput( \$CryptedPw );
         }
 
         # sha256 pw
@@ -154,18 +174,19 @@ sub Auth {
             my $SHAObject = Digest::SHA->new('sha256');
 
             # encode output, needed by sha256_hex() only non utf8 signs
-            $Self->{EncodeObject}->EncodeOutput( \$Pw );
+            $EncodeObject->EncodeOutput( \$Pw );
 
             $SHAObject->add($Pw);
             $CryptedPw = $SHAObject->hexdigest();
-            $Self->{EncodeObject}->EncodeInput( \$CryptedPw );
+            $EncodeObject->EncodeInput( \$CryptedPw );
         }
 
         elsif ( $GetPw =~ m{^BCRYPT:} ) {
 
             # require module, log errors if module was not found
-            if ( !$Self->{MainObject}->Require('Crypt::Eksblowfish::Bcrypt') ) {
-                $Self->{LogObject}->Log(
+            if ( !$Kernel::OM->Get('Kernel::System::Main')->Require('Crypt::Eksblowfish::Bcrypt') )
+            {
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'error',
                     Message =>
                         "User: '$User' tried to authenticate with bcrypt but 'Crypt::Eksblowfish::Bcrypt' is not installed!",
@@ -177,7 +198,7 @@ sub Auth {
             my ( $Cost, $Salt, $Base64Hash ) = $GetPw =~ m{^BCRYPT:(\d+):(.{16}):(.*)$}xms;
 
             # remove UTF8 flag, required by Crypt::Eksblowfish::Bcrypt
-            $Self->{EncodeObject}->EncodeOutput( \$Pw );
+            $EncodeObject->EncodeOutput( \$Pw );
 
             # calculate password hash with the same cost and hash settings
             my $Octets = Crypt::Eksblowfish::Bcrypt::bcrypt_hash(
@@ -198,11 +219,11 @@ sub Auth {
             my $SHAObject = Digest::SHA->new('sha1');
 
             # encode output, needed by sha1_hex() only non utf8 signs
-            $Self->{EncodeObject}->EncodeOutput( \$Pw );
+            $EncodeObject->EncodeOutput( \$Pw );
 
             $SHAObject->add($Pw);
             $CryptedPw = $SHAObject->hexdigest();
-            $Self->{EncodeObject}->EncodeInput( \$CryptedPw );
+            $EncodeObject->EncodeInput( \$CryptedPw );
         }
     }
 
@@ -214,17 +235,17 @@ sub Auth {
             $Salt =~ s/^(..).*/$1/;
         }
 
-        $Self->{EncodeObject}->EncodeOutput( \$Pw );
-        $Self->{EncodeObject}->EncodeOutput( \$Salt );
+        $EncodeObject->EncodeOutput( \$Pw );
+        $EncodeObject->EncodeOutput( \$Salt );
 
         # encode output, needed by crypt() only non utf8 signs
         $CryptedPw = crypt( $Pw, $Salt );
-        $Self->{EncodeObject}->EncodeInput( \$CryptedPw );
+        $EncodeObject->EncodeInput( \$CryptedPw );
     }
 
     # just in case!
     if ( $Self->{Debug} > 0 ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "CustomerUser: '$User' tried to authenticate with Pw: '$Pw' "
                 . "($UserID/$CryptedPw/$GetPw/$Salt/$RemoteAddr)",
@@ -233,7 +254,7 @@ sub Auth {
 
     # just a note
     if ( !$Pw ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message =>
                 "CustomerUser: $User authentication without Pw!!! (REMOTE_ADDR: $RemoteAddr)",
@@ -243,7 +264,7 @@ sub Auth {
 
     # login note
     elsif ( ( $GetPw && $User && $UserID ) && $CryptedPw eq $GetPw ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "CustomerUser: $User Authentication ok (REMOTE_ADDR: $RemoteAddr).",
         );
@@ -252,7 +273,7 @@ sub Auth {
 
     # just a note
     elsif ( $UserID && $GetPw ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message =>
                 "CustomerUser: $User Authentication with wrong Pw!!! (REMOTE_ADDR: $RemoteAddr)"
@@ -262,7 +283,7 @@ sub Auth {
 
     # just a note
     else {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message =>
                 "CustomerUser: $User doesn't exist or is invalid!!! (REMOTE_ADDR: $RemoteAddr)"
