@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/CustomerCompany/Event/CustomerUserUpdate.pm - update customer users if company changes
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,7 +12,10 @@ package Kernel::System::CustomerCompany::Event::CustomerUserUpdate;
 use strict;
 use warnings;
 
-use Kernel::System::CustomerUser;
+our @ObjectDependencies = (
+    'Kernel::System::CustomerUser',
+    'Kernel::System::Log',
+);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -20,14 +24,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (
-        qw( ConfigObject EncodeObject LogObject MainObject DBObject)
-        )
-    {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
-
     return $Self;
 }
 
@@ -37,7 +33,7 @@ sub Run {
     # check needed stuff
     for (qw( Data Event Config UserID )) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -46,7 +42,7 @@ sub Run {
     }
     for (qw( CustomerID OldCustomerID )) {
         if ( !$Param{Data}->{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_ in Data!"
             );
@@ -56,21 +52,22 @@ sub Run {
 
     return 1 if $Param{Data}->{CustomerID} eq $Param{Data}->{OldCustomerID};
 
-    $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new( %{$Self} );
+    # get customer user object
+    my $CustomerUserObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
 
-    my %CustomerUsers = $Self->{CustomerUserObject}->CustomerSearch(
+    my %CustomerUsers = $CustomerUserObject->CustomerSearch(
         CustomerID => $Param{Data}->{OldCustomerID},
         Valid      => 0,
     );
 
     for my $CustomerUserLogin ( sort keys %CustomerUsers ) {
-        my %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+        my %CustomerData = $CustomerUserObject->CustomerUserDataGet(
             User => $CustomerUserLogin,
         );
 
         # we do not need to 'change' the password (this would re-hash it!)
         delete $CustomerData{UserPassword};
-        $Self->{CustomerUserObject}->CustomerUserUpdate(
+        $CustomerUserObject->CustomerUserUpdate(
             %CustomerData,
             ID             => $CustomerUserLogin,
             UserCustomerID => $Param{Data}->{CustomerID},
