@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/CustomerUser/Event/TicketUpdate.pm - update tickets if company changes
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,8 +12,10 @@ package Kernel::System::CustomerUser::Event::TicketUpdate;
 use strict;
 use warnings;
 
-use Kernel::System::Time;
-use Kernel::System::Ticket;
+our @ObjectDependencies = (
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -21,14 +24,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (
-        qw( ConfigObject EncodeObject LogObject MainObject DBObject )
-        )
-    {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
-
     return $Self;
 }
 
@@ -38,7 +33,7 @@ sub Run {
     # check needed stuff
     for (qw( Data Event Config UserID )) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -47,7 +42,7 @@ sub Run {
     }
     for (qw( UserLogin NewData OldData )) {
         if ( !$Param{Data}->{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_ in Data!"
             );
@@ -62,10 +57,11 @@ sub Run {
         )
     {
 
-        # create ticket object and perform search
-        $Self->{TimeObject}   = Kernel::System::Time->new( %{$Self} );
-        $Self->{TicketObject} = Kernel::System::Ticket->new( %{$Self} );
-        my @Tickets = $Self->{TicketObject}->TicketSearch(
+        # get ticket object
+        my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
+        # perform search
+        my @Tickets = $TicketObject->TicketSearch(
             Result            => 'ARRAY',
             Limit             => 100_000,
             CustomerUserLogin => $Param{Data}->{OldData}->{UserLogin},
@@ -76,7 +72,7 @@ sub Run {
 
         # update the customer ID and login of tickets
         for my $TicketID (@Tickets) {
-            $Self->{TicketObject}->TicketCustomerSet(
+            $TicketObject->TicketCustomerSet(
                 No       => $Param{Data}->{NewData}->{UserCustomerID},
                 User     => $Param{Data}->{NewData}->{UserLogin},
                 TicketID => $TicketID,
