@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Email/SMTPTLS.pm - email send backend for SMTP/TLS
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,13 +16,17 @@ use Net::SSLGlue::SMTP;
 
 use base qw(Kernel::System::Email::SMTP);
 
+our @ObjectDependencies = (
+    'Kernel::System::Log',
+);
+
 sub _Connect {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
     for (qw(MailHost FQDN)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -37,10 +42,13 @@ sub _Connect {
         Timeout => 30,
         Debug   => $Param{SMTPDebug},
     );
+
     return if !$SMTP;
+
     $SMTP->starttls(
         SSL_verify_mode => 0,
     );
+
     return $SMTP;
 }
 
