@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/MailAccount/POP3TLS.pm - lib for pop3/tls accounts
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,13 +16,17 @@ use Net::SSLGlue::POP3;
 
 use base qw(Kernel::System::MailAccount::POP3);
 
+our @ObjectDependencies = (
+    'Kernel::System::Log',
+);
+
 sub Connect {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
     for (qw(Login Password Host Timeout Debug)) {
         if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
