@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/PostMaster/Filter/NewTicketReject.pm - sub part of PostMaster.pm
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,8 +12,12 @@ package Kernel::System::PostMaster::Filter::NewTicketReject;
 use strict;
 use warnings;
 
-use Kernel::System::Ticket;
-use Kernel::System::Email;
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Email',
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -23,13 +28,6 @@ sub new {
 
     $Self->{Debug} = $Param{Debug} || 0;
 
-    # get needed objects
-    for (qw(ConfigObject LogObject DBObject MainObject TimeObject EncodeObject TicketObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
-
-    $Self->{EmailObject} = Kernel::System::Email->new( %{$Self} );
-
     return $Self;
 }
 
@@ -39,7 +37,7 @@ sub Run {
     # check needed stuff
     for (qw(JobConfig GetParam)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -65,10 +63,11 @@ sub Run {
     my $Matched    = '';
     my $MatchedNot = 0;
     for ( sort keys %Match ) {
+
         if ( $Param{GetParam}->{$_} && $Param{GetParam}->{$_} =~ /$Match{$_}/i ) {
             $Matched = $1 || '1';
             if ( $Self->{Debug} > 1 ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'debug',
                     Message  => "'$Param{GetParam}->{$_}' =~ /$Match{$_}/i matched!",
                 );
@@ -77,7 +76,7 @@ sub Run {
         else {
             $MatchedNot = 1;
             if ( $Self->{Debug} > 1 ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'debug',
                     Message  => "'$Param{GetParam}->{$_}' =~ /$Match{$_}/i matched NOT!",
                 );
@@ -86,31 +85,39 @@ sub Run {
     }
     if ( $Matched && !$MatchedNot ) {
 
+        # get ticket object
+        my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
         # check if new ticket
-        my $Tn = $Self->{TicketObject}->GetTNByString( $Param{GetParam}->{Subject} );
-        return 1 if $Tn && $Self->{TicketObject}->TicketCheckNumber( Tn => $Tn );
+        my $Tn = $TicketObject->GetTNByString( $Param{GetParam}->{Subject} );
+
+        return 1 if $Tn && $TicketObject->TicketCheckNumber( Tn => $Tn );
 
         # set attributes if ticket is created
         for ( sort keys %Set ) {
             $Param{GetParam}->{$_} = $Set{$_};
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'notice',
                 Message =>
                     "Set param '$_' to '$Set{$_}' (Message-ID: $Param{GetParam}->{'Message-ID'}) ",
             );
         }
 
+        # get config object
+        my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
         # send bounce mail
-        my $Subject = $Self->{ConfigObject}->Get(
+        my $Subject = $ConfigObject->Get(
             'PostMaster::PreFilterModule::NewTicketReject::Subject'
         );
-        my $Body = $Self->{ConfigObject}->Get(
+        my $Body = $ConfigObject->Get(
             'PostMaster::PreFilterModule::NewTicketReject::Body'
         );
-        my $Sender = $Self->{ConfigObject}->Get(
+        my $Sender = $ConfigObject->Get(
             'PostMaster::PreFilterModule::NewTicketReject::Sender'
         ) || '';
-        $Self->{EmailObject}->Send(
+
+        $Kernel::OM->Get('Kernel::System::Email')->Send(
             From       => $Sender,
             To         => $Param{GetParam}->{From},
             Subject    => $Subject,
@@ -126,12 +133,13 @@ sub Run {
                 }
             ],
         );
-        $Self->{LogObject}->Log(
+
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "Send reject mail to '$Param{GetParam}->{From}'!",
         );
-
     }
+
     return 1;
 }
 
