@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Service.pm - all service function
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,10 +12,17 @@ package Kernel::System::Service;
 use strict;
 use warnings;
 
-use Kernel::System::CheckItem;
-use Kernel::System::Valid;
-use Kernel::System::CacheInternal;
-use Kernel::System::VariableCheck qw(:all);
+use Kernel::System::VariableCheck (qw(:all));
+
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Cache',
+    'Kernel::System::CheckItem',
+    'Kernel::System::DB',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::Valid',
+);
 
 =head1 NAME
 
@@ -34,39 +42,9 @@ All service functions.
 
 create an object
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::Service;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $ServiceObject = Kernel::System::Service->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        DBObject     => $DBObject,
-        MainObject   => $MainObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $ServiceObject = $Kernel::OM->Get('Kernel::System::Service');
 
 =cut
 
@@ -77,23 +55,15 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for my $Object (qw(DBObject ConfigObject LogObject EncodeObject MainObject)) {
-        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
-    }
-    $Self->{CheckItemObject} = Kernel::System::CheckItem->new( %{$Self} );
-    $Self->{ValidObject}     = Kernel::System::Valid->new( %{$Self} );
+    $Self->{DBObject} = $Kernel::OM->Get('Kernel::System::DB');
 
-    $Self->{CacheInternalObject} = Kernel::System::CacheInternal->new(
-        %{$Self},
-        Type => 'Service',
-        TTL  => 60 * 60 * 24 * 20,
-    );
+    $Self->{CacheType} = 'Service';
+    $Self->{CacheTTL}  = 60 * 60 * 24 * 20;
 
     # load generator preferences module
-    my $GeneratorModule = $Self->{ConfigObject}->Get('Service::PreferencesModule')
+    my $GeneratorModule = $Kernel::OM->Get('Kernel::Config')->Get('Service::PreferencesModule')
         || 'Kernel::System::Service::PreferencesDB';
-    if ( $Self->{MainObject}->Require($GeneratorModule) ) {
+    if ( $Kernel::OM->Get('Kernel::System::Main')->Require($GeneratorModule) ) {
         $Self->{PreferencesObject} = $GeneratorModule->new( %{$Self} );
     }
 
@@ -116,7 +86,7 @@ sub ServiceList {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need UserID!',
         );
@@ -131,11 +101,14 @@ sub ServiceList {
     # read cache
     my $CacheKey = 'ServiceList::Valid::' . $Param{Valid};
 
-    if ( defined $Param{KeepChildren} && $Param{KeepChildren} eq '1' ) {
+    if ( $Param{Valid} && defined $Param{KeepChildren} && $Param{KeepChildren} eq '1' ) {
         $CacheKey .= '::KeepChildren::' . $Param{KeepChildren};
     }
 
-    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+    my $Cache = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
+    );
     return %{$Cache} if ref $Cache eq 'HASH';
 
     # ask database
@@ -152,15 +125,17 @@ sub ServiceList {
     }
 
     if ( !$Param{Valid} ) {
-        $Self->{CacheInternalObject}->Set(
+        $Kernel::OM->Get('Kernel::System::Cache')->Set(
+            Type  => $Self->{CacheType},
+            TTL   => $Self->{CacheTTL},
             Key   => $CacheKey,
-            Value => \%ServiceList
+            Value => \%ServiceList,
         );
         return %ServiceList if !$Param{Valid};
     }
 
     # get valid ids
-    my @ValidIDs = $Self->{ValidObject}->ValidIDsGet();
+    my @ValidIDs = $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet();
 
     # duplicate service list
     my %ServiceListTmp = %ServiceList;
@@ -183,7 +158,7 @@ sub ServiceList {
         delete $ServiceList{$ServiceID};
     }
 
-    # delete invalid services and childs
+    # delete invalid services and children
     if ( !defined $Param{KeepChildren} || !$Param{KeepChildren} ) {
         for my $ServiceID ( sort keys %ServiceList ) {
 
@@ -199,9 +174,11 @@ sub ServiceList {
     }
 
     # set cache
-    $Self->{CacheInternalObject}->Set(
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+        Type  => $Self->{CacheType},
+        TTL   => $Self->{CacheTTL},
         Key   => $CacheKey,
-        Value => \%ServiceList
+        Value => \%ServiceList,
     );
 
     return %ServiceList;
@@ -253,7 +230,7 @@ sub ServiceListGet {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need UserID!',
         );
@@ -267,7 +244,10 @@ sub ServiceListGet {
 
     # check cached results
     my $CacheKey = 'Cache::ServiceListGet::Valid::' . $Param{Valid};
-    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+    my $Cache    = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
+    );
     return $Cache if defined $Cache;
 
     # create SQL query
@@ -275,7 +255,8 @@ sub ServiceListGet {
         . 'FROM service';
 
     if ( $Param{Valid} ) {
-        $SQL .= ' WHERE valid_id IN (' . join ', ', $Self->{ValidObject}->ValidIDsGet() . ')';
+        $SQL .= ' WHERE valid_id IN (' . join ', ',
+            $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet() . ')';
     }
 
     $SQL .= ' ORDER BY name';
@@ -330,7 +311,9 @@ sub ServiceListGet {
     if (@ServiceList) {
 
         # set cache
-        $Self->{CacheInternalObject}->Set(
+        $Kernel::OM->Get('Kernel::System::Cache')->Set(
+            Type  => $Self->{CacheType},
+            TTL   => $Self->{CacheTTL},
             Key   => $CacheKey,
             Value => \@ServiceList,
         );
@@ -372,7 +355,7 @@ sub ServiceGet {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Need UserID!",
         );
@@ -381,7 +364,7 @@ sub ServiceGet {
 
     # either ServiceID or Name must be passed
     if ( !$Param{ServiceID} && !$Param{Name} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need ServiceID or Name!',
         );
@@ -390,7 +373,7 @@ sub ServiceGet {
 
     # check that not both ServiceID and Name are given
     if ( $Param{ServiceID} && $Param{Name} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need either ServiceID OR Name - not both!',
         );
@@ -406,7 +389,10 @@ sub ServiceGet {
 
     # check cached results
     my $CacheKey = 'Cache::ServiceGet::' . $Param{ServiceID};
-    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+    my $Cache    = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
+    );
     return %{$Cache} if ref $Cache eq 'HASH';
 
     # get service from db
@@ -433,7 +419,7 @@ sub ServiceGet {
 
     # check service
     if ( !$ServiceData{ServiceID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "No such ServiceID ($Param{ServiceID})!",
         );
@@ -463,7 +449,9 @@ sub ServiceGet {
     }
 
     # set cache
-    $Self->{CacheInternalObject}->Set(
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+        Type  => $Self->{CacheType},
+        TTL   => $Self->{CacheTTL},
         Key   => $CacheKey,
         Value => \%ServiceData,
     );
@@ -492,7 +480,7 @@ sub ServiceLookup {
 
     # check needed stuff
     if ( !$Param{ServiceID} && !$Param{Name} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need ServiceID or Name!',
         );
@@ -503,7 +491,10 @@ sub ServiceLookup {
 
         # check cache
         my $CacheKey = 'Cache::ServiceLookup::ID::' . $Param{ServiceID};
-        my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+        my $Cache    = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+            Type => $Self->{CacheType},
+            Key  => $CacheKey,
+        );
         return $Cache if defined $Cache;
 
         # lookup
@@ -518,7 +509,9 @@ sub ServiceLookup {
             $Result = $Row[0];
         }
 
-        $Self->{CacheInternalObject}->Set(
+        $Kernel::OM->Get('Kernel::System::Cache')->Set(
+            Type  => $Self->{CacheType},
+            TTL   => $Self->{CacheTTL},
             Key   => $CacheKey,
             Value => $Result,
         );
@@ -529,7 +522,10 @@ sub ServiceLookup {
 
         # check cache
         my $CacheKey = 'Cache::ServiceLookup::Name::' . $Param{Name};
-        my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+        my $Cache    = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+            Type => $Self->{CacheType},
+            Key  => $CacheKey,
+        );
         return $Cache if defined $Cache;
 
         # lookup
@@ -544,7 +540,9 @@ sub ServiceLookup {
             $Result = $Row[0];
         }
 
-        $Self->{CacheInternalObject}->Set(
+        $Kernel::OM->Get('Kernel::System::Cache')->Set(
+            Type  => $Self->{CacheType},
+            TTL   => $Self->{CacheTTL},
             Key   => $CacheKey,
             Value => $Result,
         );
@@ -573,7 +571,7 @@ sub ServiceAdd {
     # check needed stuff
     for my $Argument (qw(Name ValidID UserID)) {
         if ( !$Param{$Argument} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Argument!",
             );
@@ -586,7 +584,7 @@ sub ServiceAdd {
 
     # cleanup given params
     for my $Argument (qw(Name Comment)) {
-        $Self->{CheckItemObject}->StringClean(
+        $Kernel::OM->Get('Kernel::System::CheckItem')->StringClean(
             StringRef         => \$Param{$Argument},
             RemoveAllNewlines => 1,
             RemoveAllTabs     => 1,
@@ -595,7 +593,7 @@ sub ServiceAdd {
 
     # check service name
     if ( $Param{Name} =~ m{ :: }xms ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't add service! Invalid Service name '$Param{Name}'!",
         );
@@ -628,7 +626,7 @@ sub ServiceAdd {
 
     # add service to database
     if ($Exists) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Can\'t add service! Service with same name and parent already exists.'
         );
@@ -657,7 +655,9 @@ sub ServiceAdd {
     }
 
     # reset cache
-    $Self->{CacheInternalObject}->CleanUp();
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+        Type => $Self->{CacheType},
+    );
 
     return $ServiceID;
 }
@@ -683,7 +683,7 @@ sub ServiceUpdate {
     # check needed stuff
     for my $Argument (qw(ServiceID Name ValidID UserID)) {
         if ( !$Param{$Argument} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Argument!",
             );
@@ -696,7 +696,7 @@ sub ServiceUpdate {
 
     # cleanup given params
     for my $Argument (qw(Name Comment)) {
-        $Self->{CheckItemObject}->StringClean(
+        $Kernel::OM->Get('Kernel::System::CheckItem')->StringClean(
             StringRef         => \$Param{$Argument},
             RemoveAllNewlines => 1,
             RemoveAllTabs     => 1,
@@ -705,7 +705,7 @@ sub ServiceUpdate {
 
     # check service name
     if ( $Param{Name} =~ m{ :: }xms ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't update service! Invalid Service name '$Param{Name}'!",
         );
@@ -718,7 +718,7 @@ sub ServiceUpdate {
     );
 
     if ( !$OldServiceName ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't update service! Service '$Param{ServiceID}' does not exist.",
         );
@@ -742,7 +742,7 @@ sub ServiceUpdate {
 
         # check, if selected parent was a child of this service
         if ( $Param{FullName} =~ m{ \A ( \Q$OldServiceName\E ) :: }xms ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => 'Can\'t update service! Invalid parent was selected.'
             );
@@ -765,7 +765,7 @@ sub ServiceUpdate {
 
     # update service
     if ($Exists) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Can\'t update service! Service with same name and parent already exists.'
         );
@@ -783,12 +783,14 @@ sub ServiceUpdate {
         ],
     );
 
+    my $LikeService = $Self->{DBObject}->Quote( $OldServiceName, 'Like' ) . '::%';
+
     # find all childs
     $Self->{DBObject}->Prepare(
-        SQL => "SELECT id, name FROM service WHERE name LIKE '"
-            . $Self->{DBObject}->Quote( $OldServiceName, 'Like' )
-            . "::%'",
+        SQL  => "SELECT id, name FROM service WHERE name LIKE ?",
+        Bind => [ \$LikeService ],
     );
+
     my @Childs;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         my %Child;
@@ -807,7 +809,9 @@ sub ServiceUpdate {
     }
 
     # reset cache
-    $Self->{CacheInternalObject}->CleanUp();
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+        Type => $Self->{CacheType},
+    );
 
     return 1;
 }
@@ -829,7 +833,7 @@ sub ServiceSearch {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need UserID!',
         );
@@ -840,7 +844,10 @@ sub ServiceSearch {
     $Param{Limit} ||= 1000;
 
     # create sql query
-    my $SQL = "SELECT id FROM service WHERE valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} )";
+    my $SQL
+        = "SELECT id FROM service WHERE valid_id IN ( ${\(join ', ', $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet())} )";
+
+    my @Bind;
 
     if ( $Param{Name} ) {
 
@@ -850,14 +857,19 @@ sub ServiceSearch {
         # replace * with % and clean the string
         $Param{Name} =~ s{ \*+ }{%}xmsg;
         $Param{Name} =~ s{ %+ }{%}xmsg;
+        my $LikeString = '%' . $Param{Name} . '%';
+        push @Bind, \$LikeString;
 
-        $SQL .= " AND name LIKE '$Param{Name}' ";
+        $SQL .= " AND name LIKE ?";
     }
 
     $SQL .= ' ORDER BY name';
 
     # search service in db
-    $Self->{DBObject}->Prepare( SQL => $SQL );
+    $Self->{DBObject}->Prepare(
+        SQL  => $SQL,
+        Bind => \@Bind,
+    );
 
     my @ServiceList;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
@@ -901,7 +913,7 @@ sub CustomerUserServiceMemberList {
 
     # check needed stuff
     if ( !$Param{Result} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need Result!',
         );
@@ -917,7 +929,8 @@ sub CustomerUserServiceMemberList {
     }
 
     # get options for default services for unknown customers
-    my $DefaultServiceUnknownCustomer = $Self->{ConfigObject}->Get('Ticket::Service::Default::UnknownCustomer');
+    my $DefaultServiceUnknownCustomer
+        = $Kernel::OM->Get('Kernel::Config')->Get('Ticket::Service::Default::UnknownCustomer');
     if (
         $DefaultServiceUnknownCustomer
         && $Param{DefaultServices}
@@ -930,7 +943,7 @@ sub CustomerUserServiceMemberList {
 
     # check more needed stuff
     if ( !$Param{ServiceID} && !$Param{CustomerUserLogin} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need ServiceID or CustomerUserLogin!',
         );
@@ -948,7 +961,10 @@ sub CustomerUserServiceMemberList {
     }
 
     # check cache
-    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+    my $Cache = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
+    );
     if ( $Param{Result} eq 'HASH' ) {
         return %{$Cache} if ref $Cache eq 'HASH';
     }
@@ -971,7 +987,7 @@ sub CustomerUserServiceMemberList {
         . ' FROM '
         . ' service_customer_user scu, service s'
         . ' WHERE '
-        . " s.valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} ) AND "
+        . " s.valid_id IN ( ${\(join ', ', $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet())} ) AND "
         . ' s.id = scu.service_id AND ';
 
     if ( $Param{ServiceID} ) {
@@ -1010,9 +1026,11 @@ sub CustomerUserServiceMemberList {
 
     # return result
     if ( $Param{Result} eq 'HASH' ) {
-        $Self->{CacheInternalObject}->Set(
+        $Kernel::OM->Get('Kernel::System::Cache')->Set(
+            Type  => $Self->{CacheType},
+            TTL   => $Self->{CacheTTL},
             Key   => $CacheKey,
-            Value => \%Data
+            Value => \%Data,
         );
         return %Data;
     }
@@ -1022,9 +1040,11 @@ sub CustomerUserServiceMemberList {
     else {
         @Data = keys %Data;
     }
-    $Self->{CacheInternalObject}->Set(
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+        Type  => $Self->{CacheType},
+        TTL   => $Self->{CacheTTL},
         Key   => $CacheKey,
-        Value => \@Data
+        Value => \@Data,
     );
     return @Data;
 }
@@ -1050,7 +1070,7 @@ sub CustomerUserServiceMemberAdd {
     # check needed stuff
     for my $Argument (qw(CustomerUserLogin ServiceID UserID)) {
         if ( !$Param{$Argument} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Argument!",
             );
@@ -1066,7 +1086,9 @@ sub CustomerUserServiceMemberAdd {
 
     # return if relation is not active
     if ( !$Param{Active} ) {
-        $Self->{CacheInternalObject}->CleanUp();
+        $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+            Type => $Self->{CacheType},
+        );
         return;
     }
 
@@ -1078,7 +1100,9 @@ sub CustomerUserServiceMemberAdd {
         Bind => [ \$Param{CustomerUserLogin}, \$Param{ServiceID}, \$Param{UserID} ]
     );
 
-    $Self->{CacheInternalObject}->CleanUp();
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+        Type => $Self->{CacheType},
+    );
     return $Success;
 }
 
@@ -1100,7 +1124,9 @@ sub ServicePreferencesSet {
 
     $Self->{PreferencesObject}->ServicePreferencesSet(@_);
 
-    $Self->{CacheInternalObject}->CleanUp();
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+        Type => $Self->{CacheType},
+    );
     return 1;
 }
 
@@ -1143,7 +1169,7 @@ sub ServiceParentsGet {
     # check needed stuff
     for my $Needed (qw(UserID ServiceID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => 'Need $Needed!',
             );
@@ -1153,7 +1179,10 @@ sub ServiceParentsGet {
 
     # read cache
     my $CacheKey = 'ServiceParentsGet::' . $Param{ServiceID};
-    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+    my $Cache    = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
+    );
     return $Cache if ref $Cache;
 
     # get the list of services
@@ -1197,14 +1226,71 @@ sub ServiceParentsGet {
     my @Data = reverse @ServiceParents;
 
     # set cache
-    $Self->{CacheInternalObject}->Set(
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+        Type  => $Self->{CacheType},
+        TTL   => $Self->{CacheTTL},
         Key   => $CacheKey,
-        Value => \@Data
+        Value => \@Data,
     );
 
     return \@Data;
 }
 
+=item GetAllCustomServices()
+
+get all custom services of one user
+
+    my @Services = $ServiceObject->GetAllCustomServices( UserID => 123 );
+
+=cut
+
+sub GetAllCustomServices {
+    my ( $Self, %Param ) = @_;
+
+    # check needed stuff
+    if ( !$Param{UserID} ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Need UserID!'
+        );
+        return;
+    }
+
+    # check cache
+    my $CacheKey = 'GetAllCustomServices::' . $Param{UserID};
+    my $Cache    = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
+    );
+
+    return @{$Cache} if $Cache;
+
+    # search all custom services
+    return if !$Self->{DBObject}->Prepare(
+        SQL => '
+            SELECT service_id
+            FROM personal_services
+            WHERE user_id = ?',
+        Bind => [ \$Param{UserID} ],
+    );
+
+    # fetch the result
+    my @ServiceIDs;
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        push @ServiceIDs, $Row[0];
+    }
+
+    # set cache
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+        Type  => $Self->{CacheType},
+        TTL   => $Self->{CacheTTL},
+        Key   => $CacheKey,
+        Value => \@ServiceIDs,
+    );
+
+    return @ServiceIDs;
+}
+
 1;
 
 =back
