@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/StandardTemplate.pm - lib for std templates
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,8 +12,12 @@ package Kernel::System::StandardTemplate;
 use strict;
 use warnings;
 
-use Kernel::System::Valid;
-use Kernel::System::CacheInternal;
+our @ObjectDependencies = (
+    'Kernel::System::Cache',
+    'Kernel::System::DB',
+    'Kernel::System::Log',
+    'Kernel::System::Valid',
+);
 
 =head1 NAME
 
@@ -32,38 +37,9 @@ All std template functions. E. g. to add std template or other functions.
 
 create an object
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::StandardTemplate;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $StandardTemplateObject = Kernel::System::StandardTemplate->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-        DBObject     => $DBObject,
-        MainObject   => $MainObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $StandardTemplateObject = $Kernel::OM->Get('Kernel::System::StandardTemplate');
 
 =cut
 
@@ -74,24 +50,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (qw(ConfigObject LogObject DBObject EncodeObject MainObject)) {
-        if ( $Param{$_} ) {
-            $Self->{$_} = $Param{$_};
-        }
-        else {
-            die "Got no $_!";
-        }
-    }
-
-    # create additional objects
-    $Self->{CacheInternalObject} = Kernel::System::CacheInternal->new(
-        %{$Self},
-        Type => 'StandardTemplate',
-        TTL  => 60 * 60 * 24 * 20,
-    );
-    $Self->{ValidObject} = Kernel::System::Valid->new( %{$Self} );
-
     return $Self;
 }
 
@@ -116,7 +74,7 @@ sub StandardTemplateAdd {
     # check needed stuff
     for (qw(Name ValidID Template ContentType UserID TemplateType)) {
         if ( !defined( $Param{$_} ) ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -124,17 +82,20 @@ sub StandardTemplateAdd {
         }
     }
 
-    # check if a standard template with this name already exits
+    # check if a standard template with this name already exists
     if ( $Self->NameExistsCheck( Name => $Param{Name} ) ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "A standard template with name '$Param{Name}' already exists!"
         );
         return;
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # sql
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL => '
             INSERT INTO standard_template (name, valid_id, comments, text,
                 content_type, create_time, create_by, change_time, change_by, template_type)
@@ -144,17 +105,21 @@ sub StandardTemplateAdd {
             \$Param{ContentType}, \$Param{UserID},  \$Param{UserID},  \$Param{TemplateType},
         ],
     );
-    my $ID;
-    return if !$Self->{DBObject}->Prepare(
+
+    return if !$DBObject->Prepare(
         SQL  => 'SELECT id FROM standard_template WHERE name = ? AND change_by = ?',
         Bind => [ \$Param{Name}, \$Param{UserID}, ],
     );
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+
+    my $ID;
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $ID = $Row[0];
     }
 
     # clear queue cache, due to Queue <-> Template relations
-    $Self->{CacheInternalObject}->CleanUp( OtherType => 'Queue' );
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+        Type => 'Queue',
+    );
 
     return $ID;
 }
@@ -190,15 +155,18 @@ sub StandardTemplateGet {
 
     # check needed stuff
     if ( !$Param{ID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need ID!'
         );
         return;
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # sql
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL => '
             SELECT name, valid_id, comments, text, content_type, create_time, create_by,
                 change_time, change_by ,template_type
@@ -206,8 +174,9 @@ sub StandardTemplateGet {
             WHERE id = ?',
         Bind => [ \$Param{ID} ],
     );
+
     my %Data;
-    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Data = $DBObject->FetchrowArray() ) {
         %Data = (
             ID           => $Param{ID},
             Name         => $Data[0],
@@ -222,6 +191,7 @@ sub StandardTemplateGet {
             TemplateType => $Data[9],
         );
     }
+
     return %Data;
 }
 
@@ -240,33 +210,38 @@ sub StandardTemplateDelete {
 
     # check needed stuff
     if ( !$Param{ID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need ID!'
         );
         return;
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # delete queue<->std template relation
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL  => 'DELETE FROM queue_standard_template WHERE standard_template_id = ?',
         Bind => [ \$Param{ID} ],
     );
 
     # delete attachment<->std template relation
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL  => 'DELETE FROM standard_template_attachment WHERE standard_template_id = ?',
         Bind => [ \$Param{ID} ],
     );
 
     # sql
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL  => 'DELETE FROM standard_template WHERE id = ?',
         Bind => [ \$Param{ID} ],
     );
 
     # clear queue cache, due to Queue <-> Template relations
-    $Self->{CacheInternalObject}->CleanUp( OtherType => 'Queue' );
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+        Type => 'Queue',
+    );
 
     return 1;
 }
@@ -293,7 +268,7 @@ sub StandardTemplateUpdate {
     # check needed stuff
     for (qw(ID Name ValidID TemplateType ContentType UserID TemplateType)) {
         if ( !defined( $Param{$_} ) ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -301,7 +276,7 @@ sub StandardTemplateUpdate {
         }
     }
 
-    # check if a standard template with this name already exits
+    # check if a standard template with this name already exists
     if (
         $Self->NameExistsCheck(
             Name => $Param{Name},
@@ -309,7 +284,7 @@ sub StandardTemplateUpdate {
         )
         )
     {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "A standard template with name '$Param{Name}' already exists!"
         );
@@ -317,7 +292,7 @@ sub StandardTemplateUpdate {
     }
 
     # sql
-    return if !$Self->{DBObject}->Do(
+    return if !$Kernel::OM->Get('Kernel::System::DB')->Do(
         SQL => '
             UPDATE standard_template
             SET name = ?, text = ?, content_type = ?, comments = ?, valid_id = ?,
@@ -330,7 +305,9 @@ sub StandardTemplateUpdate {
     );
 
     # clear queue cache, due to Queue <-> Template relations
-    $Self->{CacheInternalObject}->CleanUp( OtherType => 'Queue' );
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+        Type => 'Queue',
+    );
 
     return 1;
 }
@@ -356,7 +333,7 @@ sub StandardTemplateLookup {
 
     # check needed stuff
     if ( !$Param{StandardTemplate} && !$Param{StandardTemplateID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Got no StandardTemplate or StandardTemplateID!'
         );
@@ -386,11 +363,16 @@ sub StandardTemplateLookup {
         $SQL    = 'SELECT name FROM standard_template WHERE id = ?';
         @Bind   = ( \$Param{StandardTemplateID} );
     }
-    return if !$Self->{DBObject}->Prepare(
+
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL  => $SQL,
-        Bind => \@Bind
+        Bind => \@Bind,
     );
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+
+    while ( my @Row = $DBObject->FetchrowArray() ) {
 
         # store result
         $Self->{"StandardTemplate$Suffix"} = $Row[0];
@@ -398,7 +380,7 @@ sub StandardTemplateLookup {
 
     # check if data exists
     if ( !exists $Self->{"StandardTemplate$Suffix"} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Found no \$$Suffix!"
         );
@@ -459,7 +441,8 @@ sub StandardTemplateList {
         FROM standard_template';
 
     if ($Valid) {
-        $SQL .= ' WHERE valid_id IN (' . join ', ', $Self->{ValidObject}->ValidIDsGet() . ')';
+        $SQL .= ' WHERE valid_id IN (' . join ', ',
+            $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet() . ')';
     }
 
     my @Bind;
@@ -474,48 +457,54 @@ sub StandardTemplateList {
         push @Bind, \$Param{Type};
     }
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL  => $SQL,
         Bind => \@Bind,
     );
+
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $Data{ $Row[0] } = $Row[1];
     }
+
     return %Data;
 }
 
 =item NameExistsCheck()
 
-return 1 if another standard template with this name already exits
+    return 1 if another standard template with this name already exists
 
-    $Exist = $StandardTemplateObject->NameExistsCheck(
-        Name => 'Some::Template',
-        ID   => 1, # optional
-    );
+        $Exist = $StandardTemplateObject->NameExistsCheck(
+            Name => 'Some::Template',
+            ID => 1, # optional
+        );
 
 =cut
 
 sub NameExistsCheck {
     my ( $Self, %Param ) = @_;
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL  => 'SELECT id FROM standard_template WHERE name = ?',
         Bind => [ \$Param{Name} ],
     );
 
     # fetch the result
     my $Flag;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( !$Param{ID} || $Param{ID} ne $Row[0] ) {
             $Flag = 1;
         }
     }
-
     if ($Flag) {
         return 1;
     }
-
     return 0;
 }
 
