@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Stats/Static/StateAction.pm - static stat for ticket history
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,6 +15,12 @@ use warnings;
 
 use Time::Piece;
 
+our @ObjectDependencies = (
+    'Kernel::Language',
+    'Kernel::System::DB',
+    'Kernel::System::Time',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -21,11 +28,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for (qw(ConfigObject LogObject DBObject MainObject TimeObject EncodeObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
-
     return $Self;
 }
 
@@ -42,9 +44,12 @@ sub GetObjectBehaviours {
 sub Param {
     my $Self = shift;
 
+    # get time object
+    my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
+
     # get current time
-    my ( $s, $m, $h, $D, $M, $Y ) = $Self->{TimeObject}->SystemTime2Date(
-        SystemTime => $Self->{TimeObject}->SystemTime(),
+    my ( $s, $m, $h, $D, $M, $Y ) = $TimeObject->SystemTime2Date(
+        SystemTime => $TimeObject->SystemTime(),
     );
 
     # get one month before
@@ -79,13 +84,8 @@ sub Param {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $LanguageObject = Kernel::Language->new(
-        MainObject   => $Self->{MainObject},
-        ConfigObject => $Self->{ConfigObject},
-        EncodeObject => $Self->{EncodeObject},
-        LogObject    => $Self->{LogObject},
-        UserLanguage => $Param{UserLanguage},
-    );
+    # get language object
+    my $LanguageObject = $Kernel::OM->Get('Kernel::Language');
 
     my $Year  = $Param{Year};
     my $Month = $Param{Month};
@@ -93,7 +93,7 @@ sub Run {
     my %States = $Self->_GetHistoryTypes();
     my @PossibleStates;
     for my $StateID ( sort { $States{$a} cmp $States{$b} } keys %States ) {
-        $States{$StateID} = $LanguageObject->Get( $States{$StateID} );
+        $States{$StateID} = $LanguageObject->Translate( $States{$StateID} );
         $States{$StateID} =~ s/^(.{18}).*$/$1\.\.\./;
         push @PossibleStates, $States{$StateID};
     }
@@ -102,7 +102,7 @@ sub Run {
 
     # first take epoch for 12:00 on the 1st of given month
     # create Time::Piece object for this time
-    my $SystemTime = $Self->{TimeObject}->Date2SystemTime(
+    my $SystemTime = $Kernel::OM->Get('Kernel::System::Time')->Date2SystemTime(
         Year   => $Param{Year},
         Month  => $Param{Month},
         Day    => 1,
@@ -110,6 +110,7 @@ sub Run {
         Minute => 0,
         Second => 0,
     );
+
     my $TimePiece = localtime($SystemTime);    ## no critic
 
     my @Data;
@@ -120,7 +121,7 @@ sub Run {
     while ( $TimePiece->mon() == $Param{Month} ) {
 
         # x-label is of format 'Mon 1, Tue 2,' etc
-        my $Text = $LanguageObject->Get( $TimePiece->wdayname() ) . ' ' . $TimePiece->mday();
+        my $Text = $LanguageObject->Translate( $TimePiece->wdayname() ) . ' ' . $TimePiece->mday();
 
         push @Days, $Text;
         my @Row = ();
@@ -149,17 +150,18 @@ sub Run {
     }
 
     my $Title = "$Year-$Month";
-    return ( [$Title], [ $LanguageObject->Get('Days'), @Days ], @Data );
+    return ( [$Title], [ $LanguageObject->Translate('Days'), @Days ], @Data );
 }
 
 sub _GetHistoryTypes {
     my $Self = shift;
 
-    my $SQL = 'SELECT id, name FROM ticket_history_type WHERE valid_id = 1';
-    $Self->{DBObject}->Prepare( SQL => $SQL );
+    my $SQL      = 'SELECT id, name FROM ticket_history_type WHERE valid_id = 1';
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+    $DBObject->Prepare( SQL => $SQL );
 
     my %Stats;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $Stats{ $Row[0] } = $Row[1];
     }
 
@@ -174,13 +176,14 @@ sub _GetDBDataPerDay {
     my $SQL   = 'SELECT count(*) FROM ticket_history '
         . 'WHERE history_type_id = ? AND create_time >= ? AND create_time <= ?';
 
-    $Self->{DBObject}->Prepare(
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+    $DBObject->Prepare(
         SQL  => $SQL,
         Bind => [ \$Param{StateID}, \$Start, \$End ]
     );
 
     my $DayData = 0;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $DayData = $Row[0];
     }
     return $DayData;
