@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/SupportDataCollector.pm - system data collector
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,14 +14,17 @@ use warnings;
 
 use File::Basename;
 
-use Kernel::System::Cache;
-use Kernel::System::Environment;
-use Kernel::System::JSON;
-use Kernel::System::SystemData;
-use Kernel::System::Ticket;
-use Kernel::System::VariableCheck qw(:all);
 use Kernel::System::WebUserAgent;
-use Kernel::System::XML;
+
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Cache',
+    'Kernel::System::Encode',
+    'Kernel::System::JSON',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::SystemData',
+);
 
 =head1 NAME
 
@@ -36,41 +40,12 @@ All stats functions.
 
 =item new()
 
-create an object
+create an object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::SupportDataCollector;
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $SupportDataCollectorObject = $Kernel::OM->Get('Kernel::System::SupportDataCollector');
 
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $StatsObject = Kernel::System::SupportDataCollector->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        DBObject     => $DBObject,
-        MainObject   => $MainObject,
-    );
 
 =cut
 
@@ -81,21 +56,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check object list for completeness
-    for my $Object (
-        qw( ConfigObject LogObject MainObject DBObject EncodeObject TimeObject )
-        )
-    {
-        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
-    }
-
-    $Self->{CacheObject}       = Kernel::System::Cache->new( %{$Self} );
-    $Self->{EnvironmentObject} = Kernel::System::Environment->new( %{$Self} );
-    $Self->{JSONObject}        = Kernel::System::JSON->new( %{$Self} );
-    $Self->{SystemDataObject}  = Kernel::System::SystemData->new( %{$Self} );
-    $Self->{TicketObject}      = Kernel::System::Ticket->new( %{$Self} );
-    $Self->{XMLObject}         = Kernel::System::XML->new( %{$Self} );
-
     return $Self;
 }
 
@@ -104,7 +64,7 @@ sub new {
 collect system data
 
     my %Result = $SupportDataCollectorObject->Collect(
-        UseCache   => 1,    # optional, (to get data from cache if any)
+        UseCache   => 1,    # (optional) to get data from cache if any
         WebTimeout => 60,   # (optional)
     );
 
@@ -148,7 +108,7 @@ sub Collect {
     my $CacheKey = 'DataCollect';
 
     if ( $Param{UseCache} ) {
-        my $Cache = $Self->{CacheObject}->Get(
+        my $Cache = $Kernel::OM->Get('Kernel::System::Cache')->Get(
             Type => 'SupportDataCollector',
             Key  => $CacheKey,
         );
@@ -158,38 +118,36 @@ sub Collect {
     # Data must be collected in a web request context to be able to collect webserver data.
     #   If called from CLI, make a web request to collect the data.
     if ( !$ENV{GATEWAY_INTERFACE} ) {
-        return $Self->CollectByWebRequest();
+        return $Self->CollectByWebRequest( WebTimeout => $Param{WebTimeout} );
     }
 
-    # Get the disabled plugins from the config to generate a lookup hash, which can be used to skip these plugins.
-    my $PluginDisabled = $Self->{ConfigObject}->Get('SupportDataCollector::DisablePlugins') || [];
-    my %LookupPluginDisabled = map { $_ => 1 } @{$PluginDisabled};
-
-    # Get the identifier filter blacklist from the config to generate a lookup hash, which can be used
-    # to filter these identifier.
-    my $IdentifierFilterBlacklist = $Self->{ConfigObject}->Get('SupportDataCollector::IdentifierFilterBlacklist') || [];
-    my %LookupIdentifierFilterBlacklist = map { $_ => 1 } @{$IdentifierFilterBlacklist};
-
     # Look for all plugins in the FS
-    my @PluginFiles = $Self->{MainObject}->DirectoryRead(
+    my @PluginFiles = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
         Directory => dirname(__FILE__) . "/SupportDataCollector/Plugin",
         Filter    => "*.pm",
         Recursive => 1,
     );
 
+    # Look for all asynchronous plugins in the FS
+    my @PluginAsynchronousFiles = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
+        Directory => dirname(__FILE__) . "/SupportDataCollector/PluginAsynchronous",
+        Filter    => "*.pm",
+        Recursive => 1,
+    );
+
+    # merge the both plugins types together
+    my @PluginFilesAll = ( @PluginFiles, @PluginAsynchronousFiles );
+
     my @Result;
 
-    # Execute all plug-ins
-    PLUGINFILE:
-    for my $PluginFile (@PluginFiles) {
+    # Execute all Plugins
+    for my $PluginFile (@PluginFilesAll) {
 
         # Convert file name => package name
         $PluginFile =~ s{^.*(Kernel/System.*)[.]pm$}{$1}xmsg;
         $PluginFile =~ s{/+}{::}xmsg;
 
-        next PLUGINFILE if $LookupPluginDisabled{$PluginFile};
-
-        if ( !$Self->{MainObject}->Require($PluginFile) ) {
+        if ( !$Kernel::OM->Get('Kernel::System::Main')->Require($PluginFile) ) {
             return (
                 Success      => 0,
                 ErrorMessage => "Could not load $PluginFile!",
@@ -210,9 +168,8 @@ sub Collect {
         push @Result, @{ $PluginResult{Result} // [] };
     }
 
-    # Remove the disabled plugins after the execution, because some plugins returns
-    #   more information with a own identifier.
-    @Result = grep { !$LookupPluginDisabled{ $_->{Identifier} } } @Result;
+    # sort the results from the plugins by the short identifier
+    @Result = sort { $a->{ShortIdentifier} cmp $b->{ShortIdentifier} } @Result;
 
     my %ReturnData = (
         Success => 1,
@@ -220,7 +177,7 @@ sub Collect {
     );
 
     # set cache
-    $Self->{CacheObject}->Set(
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
         Type  => 'SupportDataCollector',
         Key   => $CacheKey,
         Value => \%ReturnData,
@@ -235,57 +192,53 @@ sub CollectByWebRequest {
 
     # Create a challenge token to authenticate this request without customer/agent login.
     #   PublicSupportDataCollector requires this ChallengeToken.
-    my $ChallengeToken = $Self->{MainObject}->GenerateRandomString(
+    my $ChallengeToken = $Kernel::OM->Get('Kernel::System::Main')->GenerateRandomString(
         Length     => 32,
         Dictionary => [ 0 .. 9, 'a' .. 'f' ],    # hexadecimal
     );
 
-    if ( $Self->{SystemDataObject}->SystemDataGet( Key => 'SupportDataCollector::ChallengeToken' ) )
+    if (
+        $Kernel::OM->Get('Kernel::System::SystemData')->SystemDataGet( Key => 'SupportDataCollector::ChallengeToken' )
+        )
     {
-        $Self->{SystemDataObject}->SystemDataUpdate(
+        $Kernel::OM->Get('Kernel::System::SystemData')->SystemDataUpdate(
             Key    => 'SupportDataCollector::ChallengeToken',
             Value  => $ChallengeToken,
             UserID => 1,
         );
     }
     else {
-        $Self->{SystemDataObject}->SystemDataAdd(
+        $Kernel::OM->Get('Kernel::System::SystemData')->SystemDataAdd(
             Key    => 'SupportDataCollector::ChallengeToken',
             Value  => $ChallengeToken,
             UserID => 1,
         );
     }
 
-    my $Host = $Self->{ConfigObject}->Get('SupportDataCollector::HTTPHostname');
+    my $Host;
+    my $FQDN = $Kernel::OM->Get('Kernel::Config')->Get('FQDN');
 
-    # Determine hostname
-    if ( !$Host ) {
-
-        my $FQDN = $Self->{ConfigObject}->Get('FQDN');
-
-        if ( $FQDN ne 'yourhost.example.com' && gethostbyname($FQDN) ) {
-            $Host = $FQDN;
-        }
-
-        if ( !$Host && gethostbyname('localhost') ) {
-            $Host = 'localhost';
-        }
-
-        $Host ||= '127.0.0.1';
+    if ( $FQDN ne 'yourhost.example.com' && gethostbyname($FQDN) ) {
+        $Host = $FQDN;
     }
 
+    if ( !$Host && gethostbyname('localhost') ) {
+        $Host = 'localhost';
+    }
+
+    $Host ||= '127.0.0.1';
+
     # prepare webservice config
     my $URL =
-        $Self->{ConfigObject}->Get('HttpType')
+        $Kernel::OM->Get('Kernel::Config')->Get('HttpType')
         . '://'
         . $Host
         . '/'
-        . $Self->{ConfigObject}->Get('ScriptAlias')
+        . $Kernel::OM->Get('Kernel::Config')->Get('ScriptAlias')
         . 'public.pl';
 
     # create webuseragent object
     my $WebUserAgentObject = Kernel::System::WebUserAgent->new(
-        %{$Self},
         Timeout => $Param{WebTimeout} || 20,
     );
 
@@ -306,7 +259,7 @@ sub CollectByWebRequest {
     # test if the web response was successful
     if ( $Response{Status} ne '200 OK' ) {
         $Result{ErrorMessage} = "Can't connect to server - $Response{Status}";
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "SupportDataCollector - $Result{ErrorMessage}",
         );
@@ -317,7 +270,7 @@ sub CollectByWebRequest {
     # check if we have content as a scalar ref
     if ( !$Response{Content} || ref $Response{Content} ne 'SCALAR' ) {
         $Result{ErrorMessage} = 'No content received.';
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "SupportDataCollector - $Result{ErrorMessage}",
         );
@@ -325,12 +278,12 @@ sub CollectByWebRequest {
     }
 
     # convert internal used charset
-    $Self->{EncodeObject}->EncodeInput( $Response{Content} );
+    $Kernel::OM->Get('Kernel::System::Encode')->EncodeInput( $Response{Content} );
 
     # Discard HTML responses (error pages etc.).
     if ( substr( ${ $Response{Content} }, 0, 1 ) eq '<' ) {
         $Result{ErrorMessage} = 'Response looks like HTML instead of JSON.';
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "SupportDataCollector - $Result{ErrorMessage}",
         );
@@ -338,12 +291,12 @@ sub CollectByWebRequest {
     }
 
     # decode JSON data
-    my $ResponseData = $Self->{JSONObject}->Decode(
+    my $ResponseData = $Kernel::OM->Get('Kernel::System::JSON')->Decode(
         Data => ${ $Response{Content} },
     );
     if ( !$ResponseData || ref $ResponseData ne 'HASH' ) {
         $Result{ErrorMessage} = "Can't decode JSON: '" . ${ $Response{Content} } . "'!";
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "SupportDataCollector - $Result{ErrorMessage}",
         );
@@ -351,7 +304,7 @@ sub CollectByWebRequest {
     }
 
     # set cache
-    $Self->{CacheObject}->Set(
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
         Type  => 'SupportDataCollect',
         Key   => 'DataCollect',
         Value => $ResponseData,
@@ -361,6 +314,94 @@ sub CollectByWebRequest {
     return %{$ResponseData};
 }
 
+=item CollectAsynchronous()
+
+collect asynchronous data (the asynchronous plugin decide at which place the data will be saved)
+
+    my $Success = $SupportDataCollectorObject->CollectAsynchronous();
+
+=cut
+
+sub CollectAsynchronous {
+    my ( $Self, %Param ) = @_;
+
+    # Look for all plugins in the FS
+    my @PluginFiles = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
+        Directory => dirname(__FILE__) . "/SupportDataCollector/PluginAsynchronous",
+        Filter    => "*.pm",
+        Recursive => 1,
+    );
+
+    # Execute all Plugins
+    for my $PluginFile (@PluginFiles) {
+
+        # Convert file name => package name
+        $PluginFile =~ s{^.*(Kernel/System.*)[.]pm$}{$1}xmsg;
+        $PluginFile =~ s{/+}{::}xmsg;
+
+        if ( !$Kernel::OM->Get('Kernel::System::Main')->Require($PluginFile) ) {
+            return (
+                Success      => 0,
+                ErrorMessage => "Could not load $PluginFile!",
+            );
+        }
+        my $PluginObject = $PluginFile->new( %{$Self} );
+
+        my $Success = $PluginObject->RunAsynchronous();
+
+        if ( !$Success ) {
+            return (
+                Success      => 0,
+                ErrorMessage => "Error during asynchrone execution of $PluginFile.",
+            );
+        }
+    }
+
+    return 1;
+}
+
+=item CleanupAsynchronous()
+
+cleanup asynchronous data (the asynchronous plugin decide for themselve)
+
+    my $Success = $SupportDataCollectorObject->CleanupAsynchronous();
+
+=cut
+
+sub CleanupAsynchronous {
+    my ( $Self, %Param ) = @_;
+
+    # Look for all plugins in the FS
+    my @PluginFiles = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
+        Directory => dirname(__FILE__) . "/SupportDataCollector/PluginAsynchronous",
+        Filter    => "*.pm",
+        Recursive => 1,
+    );
+
+    # Execute all Plugins
+    PLUGINFILE:
+    for my $PluginFile (@PluginFiles) {
+
+        # Convert file name => package name
+        $PluginFile =~ s{^.*(Kernel/System.*)[.]pm$}{$1}xmsg;
+        $PluginFile =~ s{/+}{::}xmsg;
+
+        if ( !$Kernel::OM->Get('Kernel::System::Main')->Require($PluginFile) ) {
+            return (
+                Success      => 0,
+                ErrorMessage => "Could not load $PluginFile!",
+            );
+        }
+        my $PluginObject = $PluginFile->new( %{$Self} );
+
+        next PLUGINFILE if !$PluginFile->can('CleanupAsynchronous');
+
+        $PluginObject->CleanupAsynchronous();
+    }
+
+    return 1;
+}
+
 =back
 
 =head1 TERMS AND CONDITIONS
