@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/SupportDataCollector/Plugin/Database/mysql/MaxAllowedPacket.pm - system data collector plugin
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +14,10 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+our @ObjectDependencies = (
+    'Kernel::System::DB',
+);
+
 sub GetDisplayPath {
     return 'Database';
 }
@@ -20,12 +25,15 @@ sub GetDisplayPath {
 sub Run {
     my $Self = shift;
 
-    if ( $Self->{DBObject}->GetDatabaseFunction('Type') ne 'mysql' ) {
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    if ( $DBObject->GetDatabaseFunction('Type') ne 'mysql' ) {
         return $Self->GetResults();
     }
 
-    $Self->{DBObject}->Prepare( SQL => "show variables like 'max_allowed_packet'" );
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    $DBObject->Prepare( SQL => "show variables like 'max_allowed_packet'" );
+    while ( my @Row = $DBObject->FetchrowArray() ) {
 
         if (
             !$Row[1]
@@ -34,7 +42,7 @@ sub Run {
         {
             $Self->AddResultProblem(
                 Label => 'Maximum Query Size',
-                Value => $Row[1],
+                Value => $Row[1] / 1024 / 1024 . ' MB',
                 Message =>
                     "The setting 'max_allowed_packet' must be higher than 20 MB.",
             );
@@ -42,7 +50,7 @@ sub Run {
         else {
             $Self->AddResultOk(
                 Label => 'Maximum Query Size',
-                Value => $Row[1],
+                Value => $Row[1] / 1024 / 1024 . ' MB',
             );
         }
     }
