@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/SupportDataCollector/Plugin/Database/mysql/Size.pm - system data collector plugin
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +14,10 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+our @ObjectDependencies = (
+    'Kernel::System::DB',
+);
+
 sub GetDisplayPath {
     return 'Database';
 }
@@ -20,31 +25,34 @@ sub GetDisplayPath {
 sub Run {
     my $Self = shift;
 
-    if ( $Self->{DBObject}->GetDatabaseFunction('Type') ne 'mysql' ) {
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    if ( $DBObject->GetDatabaseFunction('Type') ne 'mysql' ) {
         return $Self->GetResults();
     }
 
     my $DBName;
 
-    $Self->{DBObject}->Prepare(
+    $DBObject->Prepare(
         SQL   => "SELECT DATABASE()",
         Limit => 1,
     );
 
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             $DBName = $Row[0];
         }
     }
 
-    $Self->{DBObject}->Prepare(
+    $DBObject->Prepare(
         SQL => "SELECT ROUND((SUM(data_length + index_length) / 1024 / 1024 / 1024),3) "
             . "FROM information_schema.TABLES WHERE table_schema = ? GROUP BY table_schema",
         Bind  => [ \$DBName ],
         Limit => 1,
     );
 
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] ) {
             $Self->AddResultInformation(
                 Label => 'Database Size',
