@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/SupportDataCollector/Plugin/OTRS/ConfigSettings.pm - system data collector plugin
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +14,10 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+);
+
 sub GetDisplayPath {
     return 'OTRS/Config Settings';
 }
@@ -36,8 +41,12 @@ sub Run {
         Frontend::RichText
     );
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     for my $Setting (@Settings) {
-        my $ConfigValue = $Self->{ConfigObject}->Get($Setting);
+
+        my $ConfigValue = $ConfigObject->Get($Setting);
 
         if ( defined $ConfigValue ) {
             $Self->AddResultInformation(
