@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/SupportDataCollector/Plugin/OTRS/Ticket/StaticDBOrphanedRecords.pm - system data collector plugin
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +14,11 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::DB',
+);
+
 sub GetDisplayPath {
     return 'OTRS';
 }
@@ -20,14 +26,17 @@ sub GetDisplayPath {
 sub Run {
     my $Self = shift;
 
-    my $Module = $Self->{ConfigObject}->Get('Ticket::IndexModule');
+    my $Module = $Kernel::OM->Get('Kernel::Config')->Get('Ticket::IndexModule');
+
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
 
     if ( $Module !~ /StaticDB/ ) {
 
         my ( $OrphanedTicketLockIndex, $OrphanedTicketIndex );
 
-        $Self->{DBObject}->Prepare( SQL => 'SELECT count(*) from ticket_lock_index' );
-        while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        $DBObject->Prepare( SQL => 'SELECT count(*) from ticket_lock_index' );
+        while ( my @Row = $DBObject->FetchrowArray() ) {
             $OrphanedTicketLockIndex = $Row[0];
         }
 
@@ -48,8 +57,8 @@ sub Run {
             );
         }
 
-        $Self->{DBObject}->Prepare( SQL => 'SELECT count(*) from ticket_index' );
-        while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        $DBObject->Prepare( SQL => 'SELECT count(*) from ticket_index' );
+        while ( my @Row = $DBObject->FetchrowArray() ) {
             $OrphanedTicketIndex = $Row[0];
         }
 
