@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Ticket/ArticleSearchIndex/StaticDB.pm - article search index backend static
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,13 +12,22 @@ package Kernel::System::Ticket::ArticleSearchIndex::StaticDB;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::DB',
+    'Kernel::System::Log',
+);
+
 sub ArticleIndexBuild {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
     for my $Needed (qw(ArticleID UserID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
@@ -46,8 +55,11 @@ sub ArticleIndexBuild {
         }
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # update search index table
-    $Self->{DBObject}->Do(
+    $DBObject->Do(
         SQL  => 'DELETE FROM article_search WHERE id = ?',
         Bind => [ \$Article{ArticleID}, ],
     );
@@ -56,7 +68,7 @@ sub ArticleIndexBuild {
     return 1 if !$Article{Body};
 
     # insert search index
-    $Self->{DBObject}->Do(
+    $DBObject->Do(
         SQL => '
             INSERT INTO article_search (id, ticket_id, article_type_id,
                 article_sender_type_id, a_from, a_to,
@@ -80,13 +92,16 @@ sub ArticleIndexDelete {
     # check needed stuff
     for my $Needed (qw(ArticleID UserID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
 
     # delete articles
-    return if !$Self->{DBObject}->Do(
+    return if !$Kernel::OM->Get('Kernel::System::DB')->Do(
         SQL  => 'DELETE FROM article_search WHERE id = ?',
         Bind => [ \$Param{ArticleID} ],
     );
@@ -100,13 +115,16 @@ sub ArticleIndexDeleteTicket {
     # check needed stuff
     for my $Needed (qw(TicketID UserID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!"
+            );
             return;
         }
     }
 
     # delete articles
-    return if !$Self->{DBObject}->Do(
+    return if !$Kernel::OM->Get('Kernel::System::DB')->Do(
         SQL  => 'DELETE FROM article_search WHERE ticket_id = ?',
         Bind => [ \$Param{TicketID} ],
     );
@@ -118,7 +136,10 @@ sub _ArticleIndexQuerySQL {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{Data} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need Data!" );
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Need Data!"
+        );
         return;
     }
 
@@ -143,7 +164,10 @@ sub _ArticleIndexQuerySQLExt {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{Data} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need Data!" );
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Need Data!"
+        );
         return;
     }
 
@@ -154,16 +178,21 @@ sub _ArticleIndexQuerySQLExt {
         Subject => 'art.a_subject',
         Body    => 'art.a_body',
     );
+
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     my $SQLExt      = '';
     my $FullTextSQL = '';
+    KEY:
     for my $Key ( sort keys %FieldSQLMapFullText ) {
-        next if !$Param{Data}->{$Key};
+        next KEY if !$Param{Data}->{$Key};
 
         # replace * by % for SQL like
         $Param{Data}->{$Key} =~ s/\*/%/gi;
 
         # check search attribute, we do not need to search for *
-        next if $Param{Data}->{$Key} =~ /^\%{1,3}$/;
+        next KEY if $Param{Data}->{$Key} =~ /^\%{1,3}$/;
 
         if ($FullTextSQL) {
             $FullTextSQL .= ' ' . $Param{Data}->{ContentSearch} . ' ';
@@ -171,12 +200,13 @@ sub _ArticleIndexQuerySQLExt {
 
         # check if search condition extension is used
         if ( $Param{Data}->{ConditionInline} ) {
-            $FullTextSQL .= $Self->{DBObject}->QueryCondition(
+            $FullTextSQL .= $DBObject->QueryCondition(
                 Key          => $FieldSQLMapFullText{$Key},
-                Value        => $Param{Data}->{$Key},
+                Value        => lc $Param{Data}->{$Key},
                 SearchPrefix => $Param{Data}->{ContentSearchPrefix},
                 SearchSuffix => $Param{Data}->{ContentSearchSuffix},
                 Extended     => 1,
+                CaseSensitive => 1,    # data in article_search are already stored in lower cases
             );
         }
         else {
@@ -198,7 +228,7 @@ sub _ArticleIndexQuerySQLExt {
             $Value =~ s/\*/%/g;
 
             # db quote
-            $Value = lc $Self->{DBObject}->Quote( $Value, 'Like' );
+            $Value = lc $DBObject->Quote( $Value, 'Like' );
 
             # Lower conversion is already done, don't use LOWER()/LCASE()
             $FullTextSQL .= " $Field LIKE '$Value'";
@@ -215,11 +245,15 @@ sub _ArticleIndexString {
     my ( $Self, %Param ) = @_;
 
     if ( !defined $Param{String} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need String!" );
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Need String!"
+        );
         return;
     }
 
-    my $Config = $Self->{ConfigObject}->Get('Ticket::SearchIndex::Attribute');
+    my $Config = $Kernel::OM->Get('Kernel::Config')->Get('Ticket::SearchIndex::Attribute');
+
     my $WordCountMax = $Config->{WordCountMax} || 1000;
 
     # get words (use eval to prevend exits on damaged utf8 signs)
@@ -230,20 +264,24 @@ sub _ArticleIndexString {
             WordLengthMax => $Param{WordLengthMax},
         );
     };
+
     return if !$ListOfWords;
 
     # find ranking of words
     my %List;
     my $IndexString = '';
     my $Count       = 0;
+    WORD:
     for my $Word ( @{$ListOfWords} ) {
+
         $Count++;
 
         # only index the first 1000 words
-        last if $Count > $WordCountMax;
+        last WORD if $Count > $WordCountMax;
+
         if ( $List{$Word} ) {
             $List{$Word}++;
-            next;
+            next WORD;
         }
         else {
             $List{$Word} = 1;
@@ -253,6 +291,7 @@ sub _ArticleIndexString {
             $IndexString .= $Word
         }
     }
+
     return $IndexString;
 }
 
@@ -261,13 +300,30 @@ sub _ArticleIndexStringToWord {
 
     # check needed stuff
     if ( !defined $Param{String} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need String!" );
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Need String!"
+        );
         return;
     }
 
-    my $Config   = $Self->{ConfigObject}->Get('Ticket::SearchIndex::Attribute');
-    my %StopWord = %{ $Self->{ConfigObject}->Get('Ticket::SearchIndex::StopWords') || {} };
-    my @Filters  = @{ $Self->{ConfigObject}->Get('Ticket::SearchIndex::Filters') || [] };
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
+    my $Config      = $ConfigObject->Get('Ticket::SearchIndex::Attribute');
+    my %StopWordRaw = %{ $ConfigObject->Get('Ticket::SearchIndex::StopWords') || {} };
+    my @Filters     = @{ $ConfigObject->Get('Ticket::SearchIndex::Filters') || [] };
+
+    my %StopWord;
+    WORD:
+    for my $Word ( sort keys %StopWordRaw ) {
+
+        next WORD if !$Word;
+
+        $Word = lc $Word;
+
+        $StopWord{$Word} = 1;
+    }
 
     # get words
     my $LengthMin = $Param{WordLengthMin} || $Config->{WordLengthMin} || 3;
@@ -277,24 +333,24 @@ sub _ArticleIndexStringToWord {
     WORD:
     for my $Word ( split /\s+/, ${ $Param{String} } ) {
 
-        # Apply filters
+        # apply filters
         for my $Filter (@Filters) {
             $Word =~ s/$Filter//g;
         }
 
+        next WORD if !$Word;
+
         # convert to lowercase to avoid LOWER()/LCASE() in the DB query
         $Word = lc $Word;
 
+        next WORD if $StopWord{$Word};
+
         # only index words/strings within length boundaries
         my $Length = length $Word;
-        if ( $Length < $LengthMin || $Length > $LengthMax ) {
-            next WORD;
-        }
 
-        # Remove StopWords
-        if ( $Word && $StopWord{$Word} ) {
-            next WORD;
-        }
+        next WORD if $Length < $LengthMin;
+        next WORD if $Length > $LengthMax;
+
         push @ListOfWords, $Word;
     }
 
