@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Ticket/ArticleStorageFS.pm - article storage module for OTRS kernel
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,16 +19,21 @@ use Unicode::Normalize qw();
 
 use Kernel::System::VariableCheck qw(:all);
 
+our $ObjectManagerDisabled = 1;
+
 sub ArticleStorageInit {
     my ( $Self, %Param ) = @_;
 
     # ArticleDataDir
-    $Self->{ArticleDataDir} = $Self->{ConfigObject}->Get('ArticleDir')
+    $Self->{ArticleDataDir} = $Kernel::OM->Get('Kernel::Config')->Get('ArticleDir')
         || die 'Got no ArticleDir!';
 
+    # get time object
+    my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
+
     # create ArticleContentPath
-    my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $Self->{TimeObject}->SystemTime2Date(
-        SystemTime => $Self->{TimeObject}->SystemTime(),
+    my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $TimeObject->SystemTime2Date(
+        SystemTime => $TimeObject->SystemTime(),
     );
     $Self->{ArticleContentPath} = $Year . '/' . $Month . '/' . $Day;
 
@@ -42,12 +48,25 @@ sub ArticleStorageInit {
     }
     else {
         my $Error = $!;
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "Can't create $Path: $Error, try: \$OTRS_HOME/bin/otrs.SetPermissions.pl!",
         );
         die "Can't create $Path: $Error, try: \$OTRS_HOME/bin/otrs.SetPermissions.pl!";
     }
+
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
+    # get activated cache backend configuration
+    my $CacheModule = $ConfigObject->Get('Cache::Module') || '';
+
+    return 1 if $CacheModule ne 'Kernel::System::Cache::MemcachedFast';
+    return 1 if !$ConfigObject->Get('Cache::ArticleStorageCache');
+
+    $Self->{ArticleStorageCache} = 1;
+    $Self->{ArticleStorageCacheTTL} = $ConfigObject->Get('Cache::ArticleStorageCache::TTL') || 60 * 60 * 24;
+
     return 1;
 }
 
@@ -57,19 +76,22 @@ sub ArticleDelete {
     # check needed stuff
     for (qw(ArticleID UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $_!",
             );
             return;
         }
     }
 
-    my $DynamicFieldListArticle = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+    my $DynamicFieldListArticle = $Kernel::OM->Get('Kernel::System::DynamicField')->DynamicFieldListGet(
         ObjectType => 'Article',
         Valid      => 0,
     );
 
+    # get dynamic field backend object
+    my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
+
     # delete dynamicfield values for this article
     DYNAMICFIELD:
     for my $DynamicFieldConfig ( @{$DynamicFieldListArticle} ) {
@@ -79,7 +101,7 @@ sub ArticleDelete {
         next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
         next DYNAMICFIELD if !IsHashRefWithData( $DynamicFieldConfig->{Config} );
 
-        $Self->{DynamicFieldBackendObject}->ValueDelete(
+        $DynamicFieldBackendObject->ValueDelete(
             DynamicFieldConfig => $DynamicFieldConfig,
             ObjectID           => $Param{ArticleID},
             UserID             => $Param{UserID},
@@ -110,14 +132,17 @@ sub ArticleDelete {
         UserID    => $Param{UserID},
     );
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # delete article flags
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL  => 'DELETE FROM article_flag WHERE article_id = ?',
         Bind => [ \$Param{ArticleID} ],
     );
 
     # delete article history entries
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL  => 'DELETE FROM ticket_history WHERE article_id = ?',
         Bind => [ \$Param{ArticleID} ],
     );
@@ -129,11 +154,19 @@ sub ArticleDelete {
     );
 
     # delete articles
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL  => 'DELETE FROM article WHERE id = ?',
         Bind => [ \$Param{ArticleID} ],
     );
 
+    # delete cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+            Type => 'ArticleStorageFS_' . $Param{ArticleID},
+        );
+    }
+
     return 1;
 }
 
@@ -143,9 +176,9 @@ sub ArticleDeletePlain {
     # check needed stuff
     for (qw(ArticleID UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $_!",
             );
             return;
         }
@@ -156,7 +189,7 @@ sub ArticleDeletePlain {
     my $File = "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/plain.txt";
     if ( -f $File ) {
         if ( !unlink $File ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Can't remove: $File: $!!",
             );
@@ -164,11 +197,20 @@ sub ArticleDeletePlain {
         }
     }
 
+    # delete cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        $Kernel::OM->Get('Kernel::System::Cache')->Delete(
+            Type => 'ArticleStorageFS_' . $Param{ArticleID},
+            Key  => 'ArticlePlain',
+        );
+    }
+
     # return if only delete in my backend
     return 1 if $Param{OnlyMyBackend};
 
     # delete plain from db
-    return if !$Self->{DBObject}->Do(
+    return if !$Kernel::OM->Get('Kernel::System::DB')->Do(
         SQL  => 'DELETE FROM article_plain WHERE article_id = ?',
         Bind => [ \$Param{ArticleID} ],
     );
@@ -182,9 +224,9 @@ sub ArticleDeleteAttachment {
     # check needed stuff
     for (qw(ArticleID UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $_!",
             );
             return;
         }
@@ -193,16 +235,21 @@ sub ArticleDeleteAttachment {
     # delete from fs
     my $ContentPath = $Self->ArticleGetContentPath( ArticleID => $Param{ArticleID} );
     my $Path = "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}";
+
     if ( -e $Path ) {
-        my @List = $Self->{MainObject}->DirectoryRead(
+
+        my @List = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
             Directory => $Path,
             Filter    => "*",
         );
 
         for my $File (@List) {
+
             if ( $File !~ /(\/|\\)plain.txt$/ ) {
+
                 if ( !unlink "$File" ) {
-                    $Self->{LogObject}->Log(
+
+                    $Kernel::OM->Get('Kernel::System::Log')->Log(
                         Priority => 'error',
                         Message  => "Can't remove: $File: $!!",
                     );
@@ -211,11 +258,19 @@ sub ArticleDeleteAttachment {
         }
     }
 
+    # delete cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+            Type => 'ArticleStorageFS_' . $Param{ArticleID},
+        );
+    }
+
     # return if only delete in my backend
     return 1 if $Param{OnlyMyBackend};
 
     # delete attachments from db
-    return if !$Self->{DBObject}->Do(
+    return if !$Kernel::OM->Get('Kernel::System::DB')->Do(
         SQL  => 'DELETE FROM article_attachment WHERE article_id = ?',
         Bind => [ \$Param{ArticleID} ],
     );
@@ -229,9 +284,9 @@ sub ArticleWritePlain {
     # check needed stuff
     for (qw(ArticleID Email UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $_!",
             );
             return;
         }
@@ -247,21 +302,34 @@ sub ArticleWritePlain {
 
     # debug
     if ( $Self->{Debug} > 1 ) {
-        $Self->{LogObject}->Log( Message => "->WriteArticle: $Path" );
+        $Kernel::OM->Get('Kernel::System::Log')->Log( Message => "->WriteArticle: $Path" );
     }
 
     # write article to fs 1:1
     File::Path::mkpath( [$Path], 0, 0770 );    ## no critic
 
     # write article to fs
-    my $Success = $Self->{MainObject}->FileWrite(
+    my $Success = $Kernel::OM->Get('Kernel::System::Main')->FileWrite(
         Location   => "$Path/plain.txt",
         Mode       => 'binmode',
         Content    => \$Param{Email},
         Permission => '660',
     );
-    return if !$Success;
 
+    # set cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        $Kernel::OM->Get('Kernel::System::Cache')->Set(
+            Type           => 'ArticleStorageFS_' . $Param{ArticleID},
+            TTL            => $Self->{ArticleStorageCacheTTL},
+            Key            => 'ArticlePlain',
+            Value          => $Param{Email},
+            CacheInMemory  => 0,
+            CacheInBackend => 1,
+        );
+    }
+
+    return if !$Success;
     return 1;
 }
 
@@ -271,9 +339,9 @@ sub ArticleWriteAttachment {
     # check needed stuff
     for (qw(Content Filename ContentType ArticleID UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $_!",
             );
             return;
         }
@@ -293,9 +361,12 @@ sub ArticleWriteAttachment {
     # strip dots from filenames
     $Param{Filename} =~ s/^\.//g;
 
+    # get main object
+    my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
     # Perform FilenameCleanup here already to check for
     #   conflicting existing attachment files correctly
-    $Param{Filename} = $Self->{MainObject}->FilenameCleanUp(
+    $Param{Filename} = $MainObject->FilenameCleanUp(
         Filename => $Param{Filename},
         Type     => 'Local',
     );
@@ -331,7 +402,7 @@ sub ArticleWriteAttachment {
     # write attachment to backend
     if ( !-d $Param{Path} ) {
         if ( !File::Path::mkpath( [ $Param{Path} ], 0, 0770 ) ) {    ## no critic
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Can't create $Param{Path}: $!",
             );
@@ -340,7 +411,7 @@ sub ArticleWriteAttachment {
     }
 
     # write attachment content type to fs
-    my $SuccessContentType = $Self->{MainObject}->FileWrite(
+    my $SuccessContentType = $MainObject->FileWrite(
         Directory  => $Param{Path},
         Filename   => "$Param{Filename}.content_type",
         Mode       => 'binmode',
@@ -356,7 +427,7 @@ sub ArticleWriteAttachment {
 
     # write attachment content id to fs
     if ( $Param{ContentID} ) {
-        $Self->{MainObject}->FileWrite(
+        $MainObject->FileWrite(
             Directory  => $Param{Path},
             Filename   => "$Param{Filename}.content_id",
             Mode       => 'binmode',
@@ -365,9 +436,9 @@ sub ArticleWriteAttachment {
         );
     }
 
-    # write attachment content alternativ to fs
+    # write attachment content alternative to fs
     if ( $Param{ContentAlternative} ) {
-        $Self->{MainObject}->FileWrite(
+        $MainObject->FileWrite(
             Directory  => $Param{Path},
             Filename   => "$Param{Filename}.content_alternative",
             Mode       => 'binmode',
@@ -376,16 +447,39 @@ sub ArticleWriteAttachment {
         );
     }
 
+    # write attachment disposition to fs
+    if ( $Param{Disposition} ) {
+
+        my ( $Disposition, $FileName ) = split ';', $Param{Disposition};
+
+        $MainObject->FileWrite(
+            Directory  => $Param{Path},
+            Filename   => "$Param{Filename}.disposition",
+            Mode       => 'binmode',
+            Content    => \$Disposition || '',
+            Permission => 660,
+        );
+    }
+
     # write attachment content to fs
-    my $SuccessContent = $Self->{MainObject}->FileWrite(
+    my $SuccessContent = $MainObject->FileWrite(
         Directory  => $Param{Path},
         Filename   => $Param{Filename},
         Mode       => 'binmode',
         Content    => \$Param{Content},
         Permission => 660,
     );
+
     return if !$SuccessContent;
 
+    # delete cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+            Type => 'ArticleStorageFS_' . $Param{ArticleID},
+        );
+    }
+
     return 1;
 }
 
@@ -394,9 +488,9 @@ sub ArticlePlain {
 
     # check needed stuff
     if ( !$Param{ArticleID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => 'Need ArticleID!'
+            Message  => 'Need ArticleID!',
         );
         return;
     }
@@ -405,6 +499,22 @@ sub ArticlePlain {
     $Param{ArticleID} = quotemeta( $Param{ArticleID} );
     $Param{ArticleID} =~ s/\0//g;
 
+    # get cache object
+    my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
+
+    # read cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        my $Cache = $CacheObject->Get(
+            Type           => 'ArticleStorageFS_' . $Param{ArticleID},
+            Key            => 'ArticlePlain',
+            CacheInMemory  => 0,
+            CacheInBackend => 1,
+        );
+
+        return $Cache if $Cache;
+    }
+
     # get content path
     my $ContentPath = $Self->ArticleGetContentPath( ArticleID => $Param{ArticleID} );
 
@@ -412,35 +522,72 @@ sub ArticlePlain {
     if ( -f "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/plain.txt" ) {
 
         # read whole article
-        my $Data = $Self->{MainObject}->FileRead(
+        my $Data = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
             Directory => "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/",
             Filename  => 'plain.txt',
             Mode      => 'binmode',
         );
+
         return if !$Data;
+
+        # set cache
+        if ( $Self->{ArticleStorageCache} ) {
+
+            $CacheObject->Set(
+                Type           => 'ArticleStorageFS_' . $Param{ArticleID},
+                TTL            => $Self->{ArticleStorageCacheTTL},
+                Key            => 'ArticlePlain',
+                Value          => ${$Data},
+                CacheInMemory  => 0,
+                CacheInBackend => 1,
+            );
+        }
+
         return ${$Data};
     }
 
+    # return if we only need to check one backend
+    return if !$Self->{CheckAllBackends};
+
     # return if only delete in my backend
     return if $Param{OnlyMyBackend};
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # can't open article, try database
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL  => 'SELECT body FROM article_plain WHERE article_id = ?',
         Bind => [ \$Param{ArticleID} ],
     );
+
     my $Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $Data = $Row[0];
     }
+
     if ( !$Data ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message =>
                 "Can't open $Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/plain.txt: $!",
         );
         return;
     }
+
+    # set cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        $CacheObject->Set(
+            Type           => 'ArticleStorageFS_' . $Param{ArticleID},
+            TTL            => $Self->{ArticleStorageCacheTTL},
+            Key            => 'ArticlePlain',
+            Value          => $Data,
+            CacheInMemory  => 0,
+            CacheInBackend => 1,
+        );
+    }
+
     return $Data;
 }
 
@@ -449,41 +596,63 @@ sub ArticleAttachmentIndexRaw {
 
     # check ArticleContentPath
     if ( !$Self->{ArticleContentPath} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => 'Need ArticleContentPath!'
+            Message  => 'Need ArticleContentPath!',
         );
         return;
     }
 
     # check needed stuff
     if ( !$Param{ArticleID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => 'Need ArticleID!'
+            Message  => 'Need ArticleID!',
         );
         return;
     }
+
+    # get cache object
+    my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
+
+    # read cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        my $Cache = $CacheObject->Get(
+            Type           => 'ArticleStorageFS_' . $Param{ArticleID},
+            Key            => 'ArticleAttachmentIndexRaw',
+            CacheInMemory  => 0,
+            CacheInBackend => 1,
+        );
+
+        return %{$Cache} if $Cache;
+    }
+
     my $ContentPath = $Self->ArticleGetContentPath( ArticleID => $Param{ArticleID} );
     my %Index;
     my $Counter = 0;
 
+    # get main object
+    my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
     # try fs
-    my @List = $Self->{MainObject}->DirectoryRead(
+    my @List = $MainObject->DirectoryRead(
         Directory => "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}",
         Filter    => "*",
         Silent    => 1,
     );
 
+    FILENAME:
     for my $Filename ( sort @List ) {
         my $FileSize    = -s $Filename;
         my $FileSizeRaw = $FileSize;
 
         # do not use control file
-        next if $Filename =~ /\.content_alternative$/;
-        next if $Filename =~ /\.content_id$/;
-        next if $Filename =~ /\.content_type$/;
-        next if $Filename =~ /\/plain.txt$/;
+        next FILENAME if $Filename =~ /\.content_alternative$/;
+        next FILENAME if $Filename =~ /\.content_id$/;
+        next FILENAME if $Filename =~ /\.content_type$/;
+        next FILENAME if $Filename =~ /\.disposition$/;
+        next FILENAME if $Filename =~ /\/plain.txt$/;
 
         # human readable file size
         if ($FileSize) {
@@ -502,8 +671,9 @@ sub ArticleAttachmentIndexRaw {
         my $ContentType = '';
         my $ContentID   = '';
         my $Alternative = '';
+        my $Disposition = '';
         if ( -e "$Filename.content_type" ) {
-            my $Content = $Self->{MainObject}->FileRead(
+            my $Content = $MainObject->FileRead(
                 Location => "$Filename.content_type",
             );
             return if !$Content;
@@ -511,7 +681,7 @@ sub ArticleAttachmentIndexRaw {
 
             # content id (optional)
             if ( -e "$Filename.content_id" ) {
-                my $Content = $Self->{MainObject}->FileRead(
+                my $Content = $MainObject->FileRead(
                     Location => "$Filename.content_id",
                 );
                 if ($Content) {
@@ -519,20 +689,46 @@ sub ArticleAttachmentIndexRaw {
                 }
             }
 
-            # alternativ (optional)
+            # alternative (optional)
             if ( -e "$Filename.content_alternative" ) {
-                my $Content = $Self->{MainObject}->FileRead(
+                my $Content = $MainObject->FileRead(
                     Location => "$Filename.content_alternative",
                 );
                 if ($Content) {
                     $Alternative = ${$Content};
                 }
             }
+
+            # disposition
+            if ( -e "$Filename.disposition" ) {
+                my $Content = $MainObject->FileRead(
+                    Location => "$Filename.disposition",
+                );
+                if ($Content) {
+                    $Disposition = ${$Content};
+                }
+            }
+
+            # if no content disposition is set images with content id should be inline
+            elsif ( $ContentID && $ContentType =~ m{image}i ) {
+                $Disposition = 'inline';
+            }
+
+            # converted article body should be inline
+            elsif ( $Filename =~ m{file-[12]} ) {
+                $Disposition = 'inline'
+            }
+
+            # all others including attachments with content id that are not images
+            #   should NOT be inline
+            else {
+                $Disposition = 'attachment';
+            }
         }
 
         # read content type (old style)
         else {
-            my $Content = $Self->{MainObject}->FileRead(
+            my $Content = $MainObject->FileRead(
                 Location => $Filename,
                 Result   => 'ARRAY',
             );
@@ -554,22 +750,46 @@ sub ArticleAttachmentIndexRaw {
             ContentType        => $ContentType,
             ContentID          => $ContentID,
             ContentAlternative => $Alternative,
+            Disposition        => $Disposition,
         };
     }
 
-    # return if index exists
+    # set cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        $CacheObject->Set(
+            Type           => 'ArticleStorageFS_' . $Param{ArticleID},
+            TTL            => $Self->{ArticleStorageCacheTTL},
+            Key            => 'ArticleAttachmentIndexRaw',
+            Value          => \%Index,
+            CacheInMemory  => 0,
+            CacheInBackend => 1,
+        );
+    }
+
     return %Index if %Index;
 
+    # return if we only need to check one backend
+    return if !$Self->{CheckAllBackends};
+
     # return if only delete in my backend
     return %Index if $Param{OnlyMyBackend};
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # try database (if there is no index in fs)
-    return if !$Self->{DBObject}->Prepare(
-        SQL => 'SELECT filename, content_type, content_size, content_id, content_alternative'
-            . ' FROM article_attachment WHERE article_id = ? ORDER BY filename, id',
+    return if !$DBObject->Prepare(
+        SQL => '
+            SELECT filename, content_type, content_size, content_id, content_alternative,
+                disposition
+            FROM article_attachment
+            WHERE article_id = ?
+            ORDER BY filename, id',
         Bind => [ \$Param{ArticleID} ],
     );
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+
+    while ( my @Row = $DBObject->FetchrowArray() ) {
 
         # human readable file size
         my $FileSizeRaw = $Row[2];
@@ -585,6 +805,26 @@ sub ArticleAttachmentIndexRaw {
             }
         }
 
+        my $Disposition = $Row[5];
+        if ( !$Disposition ) {
+
+            # if no content disposition is set images with content id should be inline
+            if ( $Row[3] && $Row[1] =~ m{image}i ) {
+                $Disposition = 'inline';
+            }
+
+            # converted article body should be inline
+            elsif ( $Row[0] =~ m{file-[12]} ) {
+                $Disposition = 'inline';
+            }
+
+            # all others including attachments with content id that are not images
+            #   should NOT be inline
+            else {
+                $Disposition = 'attachment';
+            }
+        }
+
         # add the info the the hash
         $Counter++;
         $Index{$Counter} = {
@@ -594,8 +834,23 @@ sub ArticleAttachmentIndexRaw {
             ContentType        => $Row[1],
             ContentID          => $Row[3] || '',
             ContentAlternative => $Row[4] || '',
+            Disposition        => $Disposition,
         };
     }
+
+    # set cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        $CacheObject->Set(
+            Type           => 'ArticleStorageFS_' . $Param{ArticleID},
+            TTL            => $Self->{ArticleStorageCacheTTL},
+            Key            => 'ArticleAttachmentIndexRaw',
+            Value          => \%Index,
+            CacheInMemory  => 0,
+            CacheInBackend => 1,
+        );
+    }
+
     return %Index;
 }
 
@@ -605,9 +860,9 @@ sub ArticleAttachment {
     # check needed stuff
     for (qw(ArticleID FileID UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $_!",
             );
             return;
         }
@@ -617,6 +872,22 @@ sub ArticleAttachment {
     $Param{ArticleID} = quotemeta( $Param{ArticleID} );
     $Param{ArticleID} =~ s/\0//g;
 
+    # get cache object
+    my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
+
+    # read cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        my $Cache = $CacheObject->Get(
+            Type           => 'ArticleStorageFS_' . $Param{ArticleID},
+            Key            => 'ArticleAttachment' . $Param{FileID},
+            CacheInMemory  => 0,
+            CacheInBackend => 1,
+        );
+
+        return %{$Cache} if $Cache;
+    }
+
     # get attachment index
     my %Index = $Self->ArticleAttachmentIndex(
         ArticleID => $Param{ArticleID},
@@ -628,18 +899,27 @@ sub ArticleAttachment {
     my %Data        = %{ $Index{ $Param{FileID} } };
     my $Counter     = 0;
 
-    my @List = $Self->{MainObject}->DirectoryRead(
+    # get main object
+    my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
+    my @List = $MainObject->DirectoryRead(
         Directory => "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}",
         Filter    => "*",
         Silent    => 1,
     );
 
     if (@List) {
+
+        # get encode object
+        my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
+
+        FILENAME:
         for my $Filename (@List) {
-            next if $Filename =~ /\.content_alternative$/;
-            next if $Filename =~ /\.content_id$/;
-            next if $Filename =~ /\.content_type$/;
-            next if $Filename =~ /\/plain.txt$/;
+            next FILENAME if $Filename =~ /\.content_alternative$/;
+            next FILENAME if $Filename =~ /\.content_id$/;
+            next FILENAME if $Filename =~ /\.content_type$/;
+            next FILENAME if $Filename =~ /\/plain.txt$/;
+            next FILENAME if $Filename =~ /\.disposition$/;
 
             # add the info the the hash
             $Counter++;
@@ -648,14 +928,14 @@ sub ArticleAttachment {
                 if ( -e "$Filename.content_type" ) {
 
                     # read content type
-                    my $Content = $Self->{MainObject}->FileRead(
+                    my $Content = $MainObject->FileRead(
                         Location => "$Filename.content_type",
                     );
                     return if !$Content;
                     $Data{ContentType} = ${$Content};
 
                     # read content
-                    $Content = $Self->{MainObject}->FileRead(
+                    $Content = $MainObject->FileRead(
                         Location => $Filename,
                         Mode     => 'binmode',
                     );
@@ -664,7 +944,7 @@ sub ArticleAttachment {
 
                     # content id (optional)
                     if ( -e "$Filename.content_id" ) {
-                        my $Content = $Self->{MainObject}->FileRead(
+                        my $Content = $MainObject->FileRead(
                             Location => "$Filename.content_id",
                         );
                         if ($Content) {
@@ -672,20 +952,46 @@ sub ArticleAttachment {
                         }
                     }
 
-                    # alternativ (optional)
+                    # alternative (optional)
                     if ( -e "$Filename.content_alternative" ) {
-                        my $Content = $Self->{MainObject}->FileRead(
+                        my $Content = $MainObject->FileRead(
                             Location => "$Filename.content_alternative",
                         );
                         if ($Content) {
                             $Data{Alternative} = ${$Content};
                         }
                     }
+
+                    # disposition
+                    if ( -e "$Filename.disposition" ) {
+                        my $Content = $MainObject->FileRead(
+                            Location => "$Filename.disposition",
+                        );
+                        if ($Content) {
+                            $Data{Disposition} = ${$Content};
+                        }
+                    }
+
+                    # if no content disposition is set images with content id should be inline
+                    elsif ( $Data{ContentID} && $Data{ContentType} =~ m{image}i ) {
+                        $Data{Disposition} = 'inline';
+                    }
+
+                    # converted article body should be inline
+                    elsif ( $Filename =~ m{file-[12]} ) {
+                        $Data{Disposition} = 'inline'
+                    }
+
+                    # all others including attachments with content id that are not images
+                    #   should NOT be inline
+                    else {
+                        $Data{Disposition} = 'attachment';
+                    }
                 }
                 else {
 
                     # read content
-                    my $Content = $Self->{MainObject}->FileRead(
+                    my $Content = $MainObject->FileRead(
                         Location => $Filename,
                         Mode     => 'binmode',
                         Result   => 'ARRAY',
@@ -705,46 +1011,120 @@ sub ArticleAttachment {
                     && $Data{ContentType} =~ /(utf\-8|utf8)/i
                     )
                 {
-                    $Self->{EncodeObject}->EncodeInput( \$Data{Content} );
+                    $EncodeObject->EncodeInput( \$Data{Content} );
                 }
+
                 chomp $Data{ContentType};
+
+                # set cache
+                if ( $Self->{ArticleStorageCache} ) {
+
+                    $CacheObject->Set(
+                        Type           => 'ArticleStorageFS_' . $Param{ArticleID},
+                        TTL            => $Self->{ArticleStorageCacheTTL},
+                        Key            => 'ArticleAttachment' . $Param{FileID},
+                        Value          => \%Data,
+                        CacheInMemory  => 0,
+                        CacheInBackend => 1,
+                    );
+                }
+
                 return %Data;
             }
         }
     }
 
+    # return if we only need to check one backend
+    return if !$Self->{CheckAllBackends};
+
     # return if only delete in my backend
     return if $Param{OnlyMyBackend};
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # try database, if no content is found
-    return if !$Self->{DBObject}->Prepare(
-        SQL => 'SELECT content_type, content, content_id, content_alternative'
-            . ' FROM article_attachment WHERE article_id = ? ORDER BY filename, id',
-        Bind   => [ \$Param{ArticleID} ],
-        Limit  => $Param{FileID},
-        Encode => [ 1, 0, 0, 0 ],
+    return if !$DBObject->Prepare(
+        SQL => '
+            SELECT id
+            FROM article_attachment
+            WHERE article_id = ?
+            ORDER BY filename, id',
+        Bind  => [ \$Param{ArticleID} ],
+        Limit => $Param{FileID},
     );
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+
+    my $AttachmentID;
+    while ( my @Row = $DBObject->FetchrowArray() ) {
+        $AttachmentID = $Row[0];
+    }
+
+    return if !$DBObject->Prepare(
+        SQL => '
+            SELECT content_type, content, content_id, content_alternative, disposition, filename
+            FROM article_attachment
+            WHERE id = ?',
+        Bind   => [ \$AttachmentID ],
+        Encode => [ 1, 0, 0, 0, 1, 1 ],
+    );
+    while ( my @Row = $DBObject->FetchrowArray() ) {
+
         $Data{ContentType} = $Row[0];
 
         # decode attachment if it's e. g. a postgresql backend!!!
-        if ( !$Self->{DBObject}->GetDatabaseFunction('DirectBlob') ) {
+        if ( !$DBObject->GetDatabaseFunction('DirectBlob') ) {
             $Data{Content} = MIME::Base64::decode_base64( $Row[1] );
         }
         else {
             $Data{Content} = $Row[1];
         }
-        $Data{ContentID}          = $Row[2];
-        $Data{ContentAlternative} = $Row[3];
+        $Data{ContentID}          = $Row[2] || '';
+        $Data{ContentAlternative} = $Row[3] || '';
+        $Data{Disposition}        = $Row[4];
+        $Data{Filename}           = $Row[5];
     }
+
+    if ( !$Data{Disposition} ) {
+
+        # if no content disposition is set images with content id should be inline
+        if ( $Data{ContentID} && $Data{ContentType} =~ m{image}i ) {
+            $Data{Disposition} = 'inline';
+        }
+
+        # converted article body should be inline
+        elsif ( $Data{Filename} =~ m{file-[12]} ) {
+            $Data{Disposition} = 'inline'
+        }
+
+        # all others including attachments with content id that are not images
+        #   should NOT be inline
+        else {
+            $Data{Disposition} = 'attachment';
+        }
+    }
+
     if ( !$Data{Content} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message =>
                 "$!: $Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/$Data{Filename}!",
         );
         return;
     }
+
+    # set cache
+    if ( $Self->{ArticleStorageCache} ) {
+
+        $CacheObject->Set(
+            Type           => 'ArticleStorageFS_' . $Param{ArticleID},
+            TTL            => $Self->{ArticleStorageCacheTTL},
+            Key            => 'ArticleAttachment' . $Param{FileID},
+            Value          => \%Data,
+            CacheInMemory  => 0,
+            CacheInBackend => 1,
+        );
+    }
+
     return %Data;
 }
 
@@ -754,9 +1134,9 @@ sub _ArticleDeleteDirectory {
     # check needed stuff
     for (qw(ArticleID UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $_!",
             );
             return;
         }
@@ -767,13 +1147,14 @@ sub _ArticleDeleteDirectory {
     my $Path = "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}";
     if ( -d $Path ) {
         if ( !rmdir($Path) ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Can't remove: $Path: $!!",
             );
             return;
         }
     }
+
     return 1;
 }
 
