@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Ticket/Event/GenericAgent.pm - event handler module for the event based ticket actions
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,9 +12,14 @@ package Kernel::System::Ticket::Event::GenericAgent;
 use strict;
 use warnings;
 
-use Kernel::System::GenericAgent;
 use Kernel::System::VariableCheck qw(:all);
 
+our @ObjectDependencies = (
+    'Kernel::System::GenericAgent',
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -21,14 +27,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for my $Item (
-        qw(ConfigObject LogObject DBObject MainObject EncodeObject TimeObject QueueObject TicketObject)
-        )
-    {
-        $Self->{$Item} = $Param{$Item} || die "Got no $Item!";
-    }
-
     return $Self;
 }
 
@@ -38,7 +36,7 @@ sub Run {
     # check needed stuff
     for my $Needed (qw(Data Event Config)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Needed!"
             );
@@ -48,7 +46,7 @@ sub Run {
 
     # check for TicketID
     if ( !$Param{Data}->{TicketID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Need TicketID! in Data",
         );
@@ -56,17 +54,14 @@ sub Run {
     }
 
     # Loop protection: only execute this handler once for each ticket and event.
-    my $CacheKey = '';
-    if (
-        $Self->{TicketObject}->{'_GenericAgent::AlreadyProcessed'}->{ $Param{Data}->{TicketID} }
-        ->{ $Param{Event} }++
-        )
-    {
-        return;
-    }
+    return
+        if $Kernel::OM->Get('Kernel::System::Ticket')->{'_GenericAgent::AlreadyProcessed'}
+        ->{ $Param{Data}->{TicketID} }->{ $Param{Event} }++;
 
-    $Self->{GenericAgentObject} = Kernel::System::GenericAgent->new(%$Self);
-    my %JobEventList = $Self->{GenericAgentObject}->JobEventList();
+    # get generic agent object
+    my $GenericAgentObject = $Kernel::OM->Get('Kernel::System::GenericAgent');
+
+    my %JobEventList = $GenericAgentObject->JobEventList();
 
     # no configured jobs is OK
     return 1 if !IsHashRefWithData( \%JobEventList );
@@ -82,7 +77,7 @@ sub Run {
         next JOB if !grep { $_ eq $Param{Event} } @Events;
 
         # execute the job
-        my $Result = $Self->{GenericAgentObject}->JobRun(
+        my $Result = $GenericAgentObject->JobRun(
             Job          => $JobName,
             OnlyTicketID => $Param{Data}->{TicketID},
             UserID       => 1,                          # run the job as system user
