@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Ticket/Event/ResponsibleAutoSet.pm - a event module for auto set of responible
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -7,9 +8,16 @@
 # --
 
 package Kernel::System::Ticket::Event::ResponsibleAutoSet;
+
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -17,10 +25,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (qw(ConfigObject TicketObject LogObject UserObject CustomerUserObject SendmailObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
     return $Self;
 }
 
@@ -30,7 +34,7 @@ sub Run {
     # check needed stuff
     for (qw(Data Event Config UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -39,7 +43,7 @@ sub Run {
     }
     for (qw(TicketID)) {
         if ( !$Param{Data}->{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_ in Data!"
             );
@@ -47,12 +51,18 @@ sub Run {
         }
     }
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # set responsible if first change
-    return 1 if !$Self->{ConfigObject}->Get('Ticket::Responsible');
-    return 1 if !$Self->{ConfigObject}->Get('Ticket::ResponsibleAutoSet');
+    return 1 if !$ConfigObject->Get('Ticket::Responsible');
+    return 1 if !$ConfigObject->Get('Ticket::ResponsibleAutoSet');
+
+    # get ticket object
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
 
     # get current ticket data
-    my %Ticket = $Self->{TicketObject}->TicketGet(
+    my %Ticket = $TicketObject->TicketGet(
         TicketID      => $Param{Data}->{TicketID},
         UserID        => $Param{UserID},
         DynamicFields => 0,
@@ -60,13 +70,14 @@ sub Run {
 
     # check responible update
     if ( $Ticket{ResponsibleID} == 1 && $Param{UserID} != 1 ) {
-        $Self->{TicketObject}->TicketResponsibleSet(
+        $TicketObject->TicketResponsibleSet(
             TicketID           => $Param{Data}->{TicketID},
             NewUserID          => $Ticket{OwnerID},
             SendNoNotification => 1,
             UserID             => $Param{UserID},
         );
     }
+
     return 1;
 }
 
