@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Ticket/Event/Test.pm - test event module
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +12,11 @@ package Kernel::System::Ticket::Event::Test;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -18,11 +24,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (qw(ConfigObject TicketObject LogObject UserObject CustomerUserObject SendmailObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
-
     return $Self;
 }
 
@@ -32,7 +33,7 @@ sub Run {
     # check needed stuff
     for (qw(Data Event Config)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -41,7 +42,7 @@ sub Run {
     }
     for (qw(TicketID)) {
         if ( !$Param{Data}->{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_ in Data!"
             );
@@ -50,14 +51,19 @@ sub Run {
     }
 
     if ( $Param{Event} eq 'TicketCreate' ) {
-        my %Ticket = $Self->{TicketObject}->TicketGet(
+
+        # get ticket object
+        my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
+        my %Ticket = $TicketObject->TicketGet(
             TicketID      => $Param{Data}->{TicketID},
             DynamicFields => 0,
         );
+
         if ( $Ticket{State} eq 'Test' ) {
 
             # do some stuff
-            $Self->{TicketObject}->HistoryAdd(
+            $TicketObject->HistoryAdd(
                 TicketID     => $Param{Data}->{TicketID},
                 CreateUserID => $Param{UserID},
                 HistoryType  => 'Misc',
@@ -66,14 +72,19 @@ sub Run {
         }
     }
     elsif ( $Param{Event} eq 'TicketQueueUpdate' ) {
-        my %Ticket = $Self->{TicketObject}->TicketGet(
+
+        # get ticket object
+        my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
+        my %Ticket = $TicketObject->TicketGet(
             TicketID      => $Param{Data}->{TicketID},
             DynamicFields => 0,
         );
+
         if ( $Ticket{Queue} eq 'Test' ) {
 
             # do some stuff
-            $Self->{TicketObject}->HistoryAdd(
+            $TicketObject->HistoryAdd(
                 TicketID     => $Param{Data}->{TicketID},
                 CreateUserID => $Param{UserID},
                 HistoryType  => 'Misc',
@@ -81,6 +92,7 @@ sub Run {
             );
         }
     }
+
     return 1;
 }
 
