@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Ticket/Event/TicketNewMessageUpdate.pm - update ticket new message flag
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +12,12 @@ package Kernel::System::Ticket::Event::TicketNewMessageUpdate;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -18,14 +25,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for my $Needed (
-        qw(ConfigObject TicketObject LogObject UserObject CustomerUserObject TimeObject)
-        )
-    {
-        $Self->{$Needed} = $Param{$Needed} || die "Got no $Needed!";
-    }
-
     return $Self;
 }
 
@@ -35,7 +34,7 @@ sub Run {
     # check needed stuff
     for my $Parameter (qw(Data Event Config)) {
         if ( !$Param{$Parameter} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Parameter!"
             );
@@ -44,7 +43,7 @@ sub Run {
     }
     for my $DataParameter (qw(TicketID ArticleID)) {
         if ( !$Param{Data}->{$DataParameter} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $DataParameter in Data!",
             );
@@ -54,31 +53,49 @@ sub Run {
 
     # update ticket new message flag
     if ( $Param{Event} eq 'ArticleCreate' ) {
-        $Self->{TicketObject}->TicketFlagDelete(
+
+        # get ticket object
+        my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
+        $TicketObject->TicketFlagDelete(
             TicketID => $Param{Data}->{TicketID},
             Key      => 'Seen',
             AllUsers => 1,
         );
 
-        # set the seen flag to 1 for the agent who created the article
-        $Self->{TicketObject}->ArticleFlagSet(
-            ArticleID => $Param{Data}->{ArticleID},
-            Key       => 'Seen',
-            Value     => 1,
-            UserID    => $Param{UserID},
+        my %Article = $TicketObject->ArticleGet(
+            ArticleID     => $Param{Data}->{ArticleID},
+            DynamicFields => 0,
         );
+
+        if ( %Article && $Article{SenderType} eq 'agent' ) {
+
+            # set the seen flag to 1 for the agent who created the article
+            $TicketObject->ArticleFlagSet(
+                ArticleID => $Param{Data}->{ArticleID},
+                Key       => 'Seen',
+                Value     => 1,
+                UserID    => $Param{UserID},
+            );
+        }
+
         return 1;
     }
     elsif ( $Param{Event} eq 'ArticleFlagSet' ) {
+
+        # get ticket object
+        my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
         my @ArticleList;
         my @SenderTypes = (qw(customer agent system));
 
         # ignore system sender
-        if ( $Self->{ConfigObject}->Get('Ticket::NewArticleIgnoreSystemSender') ) {
+        if ( $Kernel::OM->Get('Kernel::Config')->Get('Ticket::NewArticleIgnoreSystemSender') ) {
             @SenderTypes = (qw(customer agent));
         }
+
         for my $SenderType (@SenderTypes) {
-            push @ArticleList, $Self->{TicketObject}->ArticleIndex(
+            push @ArticleList, $TicketObject->ArticleIndex(
                 TicketID   => $Param{Data}->{TicketID},
                 SenderType => $SenderType,
             );
@@ -88,12 +105,12 @@ sub Run {
         my $ArticleAllSeen = 1;
         ARTICLE:
         for my $ArticleID (@ArticleList) {
-            my %ArticleFlag = $Self->{TicketObject}->ArticleFlagGet(
+            my %ArticleFlag = $TicketObject->ArticleFlagGet(
                 ArticleID => $ArticleID,
                 UserID    => $Param{Data}->{UserID},
             );
 
-            # last if article was not shown
+            # last ARTICLE if article was not shown
             if ( !$ArticleFlag{Seen} ) {
                 $ArticleAllSeen = 0;
                 last ARTICLE;
@@ -102,15 +119,15 @@ sub Run {
 
         # mark ticket as seen if all articles have been seen
         if ($ArticleAllSeen) {
-            $Self->{TicketObject}->TicketFlagSet(
+            $TicketObject->TicketFlagSet(
                 TicketID => $Param{Data}->{TicketID},
                 Key      => 'Seen',
                 Value    => 1,
                 UserID   => $Param{Data}->{UserID},
             );
         }
-
     }
+
     return;
 }
 
