@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Ticket/Event/TriggerEscalationStopEvents.pm - trigger escalation stop events
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +12,11 @@ package Kernel::System::Ticket::Event::TriggerEscalationStopEvents;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -18,14 +24,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for my $Object (
-        qw(ConfigObject TicketObject LogObject UserObject CustomerUserObject TimeObject)
-        )
-    {
-        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
-    }
-
     return $Self;
 }
 
@@ -35,7 +33,7 @@ sub Run {
     # check needed stuff
     for my $Needed (qw(Event UserID Config)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Needed!"
             );
@@ -44,7 +42,7 @@ sub Run {
     }
     for my $Needed (qw(OldTicketData TicketID)) {
         if ( !$Param{Data}->{$Needed} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Needed in Data!"
             );
@@ -52,8 +50,11 @@ sub Run {
         }
     }
 
+    # get ticket object
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
     # get the current escalation status
-    my %Ticket = $Self->{TicketObject}->TicketGet(
+    my %Ticket = $TicketObject->TicketGet(
         TicketID      => $Param{Data}->{TicketID},
         UserID        => $Param{UserID},
         DynamicFields => 0,
@@ -65,11 +66,13 @@ sub Run {
         UpdateTimeEscalation        => 'EscalationUpdateTimeStop',
         SolutionTimeEscalation      => 'EscalationSolutionTimeStop',
     );
+
     while ( my ( $Attr, $Event ) = each %Attr2Event ) {
+
         if ( $Param{Data}->{OldTicketData}->{$Attr} && !$Ticket{$Attr} ) {
 
             # trigger the event
-            $Self->{TicketObject}->EventHandler(
+            $TicketObject->EventHandler(
                 Event  => $Event,
                 UserID => $Param{UserID},
                 Data   => {
@@ -79,7 +82,7 @@ sub Run {
             );
 
             # log the triggered event in the history
-            $Self->{TicketObject}->HistoryAdd(
+            $TicketObject->HistoryAdd(
                 TicketID     => $Param{Data}->{TicketID},
                 HistoryType  => $Event,
                 Name         => "%%$Event%%triggered",
