@@ -1,13 +1,12 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Ticket/Number/Random.pm - a ticket number random generator
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
-# Note:
-# available objects are: ConfigObject, LogObject and DBObject
-#
+
 # Generates random ticket numbers like ss.... (e. g. 100057866352, 103745394596, ...)
 # --
 
@@ -16,14 +15,22 @@ package Kernel::System::Ticket::Number::Random;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+);
+
 sub TicketCreateNumber {
     my $Self = shift;
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # get needed config options
-    my $SystemID = $Self->{ConfigObject}->Get('SystemID');
+    my $SystemID = $ConfigObject->Get('SystemID');
 
     # random counter
-    my $Count = int( rand(9999999999) );
+    my $Count = int rand 9999999999;
 
     $Count = sprintf "%.*u", 10, $Count;
 
@@ -32,11 +39,13 @@ sub TicketCreateNumber {
 
     # Check ticket number. If exists generate new one!
     if ( $Self->TicketCheckNumber( Tn => $Tn ) ) {
+
         $Self->{LoopProtectionCounter}++;
+
         if ( $Self->{LoopProtectionCounter} >= 16000 ) {
 
             # loop protection
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "CounterLoopProtection is now $Self->{LoopProtectionCounter}!"
                     . " Stopped TicketCreateNumber()!",
@@ -45,29 +54,37 @@ sub TicketCreateNumber {
         }
 
         # create new ticket number again
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "Tn ($Tn) exists! Creating a new one.",
         );
+
         $Tn = $Self->TicketCreateNumber();
     }
+
     return $Tn;
 }
 
 sub GetTNByString {
     my ( $Self, $String ) = @_;
+
     if ( !$String ) {
         return;
     }
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # get needed config options
-    my $CheckSystemID = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::CheckSystemID');
+    my $CheckSystemID = $ConfigObject->Get('Ticket::NumberGenerator::CheckSystemID');
     my $SystemID      = '';
+
     if ($CheckSystemID) {
-        $SystemID = $Self->{ConfigObject}->Get('SystemID');
+        $SystemID = $ConfigObject->Get('SystemID');
     }
-    my $TicketHook        = $Self->{ConfigObject}->Get('Ticket::Hook');
-    my $TicketHookDivider = $Self->{ConfigObject}->Get('Ticket::HookDivider');
+
+    my $TicketHook        = $ConfigObject->Get('Ticket::Hook');
+    my $TicketHookDivider = $ConfigObject->Get('Ticket::HookDivider');
 
     # check current setting
     if ( $String =~ /\Q$TicketHook$TicketHookDivider\E($SystemID\d{2,20})/i ) {
