@@ -1,5 +1,7 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Ticket/Permission/WatcherCheck.pm - the sub module of
+# the global ticket handle
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +13,12 @@ package Kernel::System::Ticket::Permission::WatcherCheck;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -18,11 +26,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (qw(ConfigObject LogObject DBObject TicketObject QueueObject UserObject GroupObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
-
     return $Self;
 }
 
@@ -32,7 +35,7 @@ sub Run {
     # check needed stuff
     for (qw(TicketID UserID Type)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -41,13 +44,13 @@ sub Run {
     }
 
     # return if no watcher feature is active
-    return if !$Self->{ConfigObject}->Get('Ticket::Watcher');
+    return if !$Kernel::OM->Get('Kernel::Config')->Get('Ticket::Watcher');
 
     # return no acces if it's wrong permission type
     return if $Param{Type} ne 'ro';
 
     # get ticket data, return access if current user is watcher
-    my %Ticket = $Self->{TicketObject}->TicketWatchGet(
+    my %Ticket = $Kernel::OM->Get('Kernel::System::Ticket')->TicketWatchGet(
         TicketID => $Param{TicketID},
     );
     return 1 if $Ticket{ $Param{UserID} };
