@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Selenium.pm - run frontend tests
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,13 +13,20 @@ package Kernel::System::UnitTest::Selenium;
 use strict;
 use warnings;
 
+use base qw(Selenium::Remote::Driver);
 use MIME::Base64();
-use File::Path();
 use File::Temp();
 
 use Kernel::Config;
 use Kernel::System::User;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::UnitTest',
+);
+
 =head1 NAME
 
 Kernel::System::UnitTest::Selenium - run frontend tests
@@ -58,15 +66,11 @@ Then you can use the full API of Selenium::Remote::Driver on this object.
 sub new {
     my ( $Class, %Param ) = @_;
 
-    for my $Needed (qw(UnitTestObject)) {
-        if ( !$Param{$Needed} ) {
-            die "Got no $Needed!";
-        }
-    }
+    $Param{UnitTestObject} ||= $Kernel::OM->Get('Kernel::System::UnitTest');
 
     $Param{UnitTestObject}->True( 1, "Starting up Selenium scenario..." );
 
-    my %SeleniumTestsConfig = %{ $Param{UnitTestObject}->{ConfigObject}->Get('SeleniumTestsConfig') // {} };
+    my %SeleniumTestsConfig = %{ $Kernel::OM->Get('Kernel::Config')->Get('SeleniumTestsConfig') // {} };
 
     if ( !%SeleniumTestsConfig ) {
         my $Self = bless {}, $Class;
@@ -80,9 +84,6 @@ sub new {
         }
     }
 
-    $Param{UnitTestObject}->{MainObject}->RequireBaseClass('Selenium::Remote::Driver')
-        || die "Could not load Selenium::Remote::Driver";
-
     my $Self = $Class->SUPER::new(%SeleniumTestsConfig);
     $Self->{UnitTestObject}      = $Param{UnitTestObject};
     $Self->{SeleniumTestsActive} = 1;
@@ -91,7 +92,7 @@ sub new {
     $Self->set_window_size( 1024, 768 );
 
     # get remote host with some precautions for certain unit test systems
-    my $FQDN = $Self->{UnitTestObject}->{ConfigObject}->Get('FQDN');
+    my $FQDN = $Kernel::OM->Get('Kernel::Config')->Get('FQDN');
 
     # try to resolve fqdn host
     if ( $FQDN ne 'yourhost.example.com' && gethostbyname($FQDN) ) {
@@ -108,7 +109,7 @@ sub new {
         $Self->{BaseURL} = '127.0.0.1';
     }
 
-    $Self->{BaseURL} = $Self->{UnitTestObject}->{ConfigObject}->Get('HttpType') . '://' . $Self->{BaseURL};
+    $Self->{BaseURL} = $Kernel::OM->Get('Kernel::Config')->Get('HttpType') . '://' . $Self->{BaseURL};
 
     return $Self;
 }
@@ -153,7 +154,7 @@ sub _execute_command {    ## no critic
     my $Result = $Self->SUPER::_execute_command( $Res, $Params );
 
     my $TestName = 'Selenium command success: ';
-    $TestName .= $Self->{UnitTestObject}->{MainObject}->Dump(
+    $TestName .= $Kernel::OM->Get('Kernel::System::Main')->Dump(
         {
             %{ $Res    || {} },
             %{ $Params || {} },
@@ -204,9 +205,9 @@ sub Login {
     # check needed stuff
     for (qw(Type User Password)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $_!",
             );
             return;
         }
@@ -217,7 +218,7 @@ sub Login {
     eval {
         $Self->delete_all_cookies();
 
-        my $ScriptAlias = $Self->{UnitTestObject}->{ConfigObject}->Get('ScriptAlias');
+        my $ScriptAlias = $Kernel::OM->Get('Kernel::Config')->Get('ScriptAlias');
 
         if ( $Param{Type} eq 'Agent' ) {
             $ScriptAlias .= 'index.pl';
@@ -249,7 +250,7 @@ sub Login {
         # Wait until form has loaded, if neccessary
         ACTIVESLEEP:
         for my $Second ( 1 .. 20 ) {
-            if ( $Self->execute_script('return typeof($) === "function" && $("a#LogoutButton").length') ) {
+            if ( $Self->execute_script("return \$('a#LogoutButton').length") ) {
                 last ACTIVESLEEP;
             }
             sleep 1;
@@ -296,7 +297,7 @@ sub HandleError {
         UNLINK => 0,
     );
     close $FH;
-    $Self->{UnitTestObject}->{MainObject}->FileWrite(
+    $Kernel::OM->Get('Kernel::System::Main')->FileWrite(
         Location => $Filename,
         Content  => \$Data,
     );
@@ -309,14 +310,13 @@ sub HandleError {
     #}
 }
 
-=head2 DEMOLISH()
+=item DESTROY()
 
-override DEMOLISH from L<Selenium::Remote::Driver> (required because this class is managed by L<Moo>).
-Adds a unit test result to indicate the shutdown, and performs some cleanups.
+cleanup. Adds a unit test result to indicate the shutdown.
 
 =cut
 
-sub DEMOLISH {
+sub DESTROY {
     my $Self = shift;
 
     # Could be missing on early die.
@@ -325,19 +325,7 @@ sub DEMOLISH {
     }
 
     if ( $Self->{SeleniumTestsActive} ) {
-        $Self->SUPER::DEMOLISH(@_);
-    }
-
-    # Cleanup possibly leftover zombie firefox profiles.
-    my @LeftoverFirefoxProfiles = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
-        Directory => '/tmp/',
-        Filter    => 'anonymous*webdriver-profile',
-    );
-
-    for my $LeftoverFirefoxProfile (@LeftoverFirefoxProfiles) {
-        if ( -d $LeftoverFirefoxProfile ) {
-            File::Path::remove_tree($LeftoverFirefoxProfile);
-        }
+        $Self->SUPER::DESTROY();
     }
 }
 
