@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Web/InterfaceCustomer.pm - the customer interface file (incl. auth)
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,18 +12,22 @@ package Kernel::System::Web::InterfaceCustomer;
 use strict;
 use warnings;
 
-use Kernel::Config;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::Encode;
-use Kernel::System::Time;
-use Kernel::System::Web::Request;
-use Kernel::System::DB;
-use Kernel::System::AuthSession;
-use Kernel::System::CustomerAuth;
-use Kernel::System::CustomerUser;
-use Kernel::System::CustomerGroup;
-use Kernel::Output::HTML::Layout;
+use Kernel::System::Email;
+
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::Output::HTML::Layout',
+    'Kernel::System::AuthSession',
+    'Kernel::System::CustomerAuth',
+    'Kernel::System::CustomerGroup',
+    'Kernel::System::CustomerUser',
+    'Kernel::System::DB',
+    'Kernel::System::Encode',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::Time',
+    'Kernel::System::Web::Request',
+);
 
 =head1 NAME
 
@@ -67,19 +71,27 @@ sub new {
     $Self->{PerformanceLogStart} = time();
 
     # create common framework objects 1/2
-    $Self->{ConfigObject} = Kernel::Config->new();
-    $Self->{LogObject}    = Kernel::System::Log->new(
-        LogPrefix => $Self->{ConfigObject}->Get('CGILogPrefix'),
-        %{$Self},
-    );
-    $Self->{EncodeObject} = Kernel::System::Encode->new( %{$Self} );
-    $Self->{MainObject}   = Kernel::System::Main->new( %{$Self} );
-    $Self->{TimeObject}   = Kernel::System::Time->new( %{$Self} );
-    $Self->{ParamObject}  = Kernel::System::Web::Request->new(
-        %{$Self},
-        WebRequest => $Param{WebRequest} || 0,
+    $Self->{ConfigObject} = $Kernel::OM->Get('Kernel::Config');
+    $Kernel::OM->ObjectParamAdd(
+        'Kernel::System::Log' => {
+            LogPrefix => $Self->{ConfigObject}->Get('CGILogPrefix'),
+        },
+        'Kernel::System::Web::Request' => {
+            WebRequest => $Param{WebRequest} || 0,
+        },
+
+        # Don't autoconnect as this would cause internal server errors on failure.
+        'Kernel::System::DB' => {
+            AutoConnectNo => 1,
+        },
     );
 
+    $Self->{EncodeObject} = $Kernel::OM->Get('Kernel::System::Encode');
+    $Self->{LogObject}    = $Kernel::OM->Get('Kernel::System::Log');
+    $Self->{MainObject}   = $Kernel::OM->Get('Kernel::System::Main');
+    $Self->{ParamObject}  = $Kernel::OM->Get('Kernel::System::Web::Request');
+    $Self->{TimeObject}   = $Kernel::OM->Get('Kernel::System::Time');
+
     # debug info
     if ( $Self->{Debug} ) {
         $Self->{LogObject}->Log(
@@ -125,6 +137,13 @@ sub Run {
             || $FrameworkParams->{$Key};
     }
 
+    # validate language
+    if ( $Param{Lang} && $Param{Lang} !~ m{\A[a-z]{2}(?:_[A-Z]{2})?\z}xms ) {
+        delete $Param{Lang};
+    }
+
+    my $BrowserHasCookie = 0;
+
     # Check if the browser sends the SessionID cookie and set the SessionID-cookie
     # as SessionID! GET or POST SessionID have the lowest priority.
     if ( $Self->{ConfigObject}->Get('SessionUseCookie') ) {
@@ -141,44 +160,52 @@ sub Run {
         $CookieSecureAttribute = 1;
     }
 
-    # check common objects
-    $Self->{DBObject} = Kernel::System::DB->new( %{$Self} );
-    if ( !$Self->{DBObject} || $Self->{ParamObject}->Error() ) {
-        my $LayoutObject = Kernel::Output::HTML::Layout->new( %{$Self}, Lang => $Param{Lang} );
-        if ( !$Self->{DBObject} ) {
+    $Kernel::OM->ObjectParamAdd(
+        'Kernel::Output::HTML::Layout' => {
+            Lang => $Param{Lang},
+        },
+        'Kernel::Language' => {
+            UserLanguage => $Param{Lang},
+        },
+    );
+
+    # get needed objects
+    $Self->{DBObject} = $Kernel::OM->Get('Kernel::System::DB');
+
+    my $DBCanConnect = $Self->{DBObject}->Connect();
+
+    # Restore original behaviour of Kernel::System::DB for all objects created in future
+    $Kernel::OM->ObjectParamAdd(
+        'Kernel::System::DB' => {
+            AutoConnectNo => undef,
+        },
+    );
+    if ( !$DBCanConnect || $Self->{ParamObject}->Error() ) {
+        my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+        if ( !$DBCanConnect ) {
             $LayoutObject->CustomerFatalError(
-                Comment => 'Please contact your administrator',
+                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
             );
             return;
         }
         if ( $Self->{ParamObject}->Error() ) {
             $LayoutObject->CustomerFatalError(
                 Message => $Self->{ParamObject}->Error(),
-                Comment => 'Please contact your administrator',
+                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
             );
             return;
         }
     }
 
     # create common framework objects 2/2
-    $Self->{UserObject}    = Kernel::System::CustomerUser->new( %{$Self} );
-    $Self->{GroupObject}   = Kernel::System::CustomerGroup->new( %{$Self} );
-    $Self->{SessionObject} = Kernel::System::AuthSession->new( %{$Self} );
+    $Self->{UserObject}    = $Kernel::OM->Get('Kernel::System::CustomerUser');
+    $Self->{GroupObject}   = $Kernel::OM->Get('Kernel::System::CustomerGroup');
+    $Self->{SessionObject} = $Kernel::OM->Get('Kernel::System::AuthSession');
 
     # application and add on application common objects
     my %CommonObject = %{ $Self->{ConfigObject}->Get('CustomerFrontend::CommonObject') };
     for my $Key ( sort keys %CommonObject ) {
-        if ( $Self->{MainObject}->Require( $CommonObject{$Key} ) ) {
-
-            # workaround for bug# 977 - do not use GroupObject in Kernel::System::Ticket
-            $Self->{$Key} = $CommonObject{$Key}->new( %{$Self}, GroupObject => undef );
-        }
-        else {
-
-            # print error
-            my $LayoutObject = Kernel::Output::HTML::Layout->new( %{$Self}, Lang => $Param{Lang} );
-            $LayoutObject->CustomerFatalError( Comment => 'Please contact your administrator' );
-        }
+        $Self->{$Key} //= $Kernel::OM->Get( $CommonObject{$Key} );
     }
 
     # get common application and add on application params
@@ -191,23 +218,61 @@ sub Run {
     $Param{Action} =~ s/\W//g;
 
     # check request type
-    if ( $Param{Action} eq 'Login' ) {
+    if ( $Param{Action} eq 'PreLogin' ) {
+        my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
-        # new layout object
-        my $LayoutObject = Kernel::Output::HTML::Layout->new( %{$Self}, Lang => $Param{Lang} );
+        # login screen
+        $LayoutObject->Print(
+            Output => \$LayoutObject->CustomerLogin(
+                Title => 'Login',
+                Mode  => 'PreLogin',
+                %Param,
+            ),
+        );
+
+        return;
+    }
+    elsif ( $Param{Action} eq 'Login' ) {
 
         # get params
         my $PostUser = $Self->{ParamObject}->GetParam( Param => 'User' ) || '';
-        my $PostPw = $Self->{ParamObject}->GetParam( Param => 'Password', Raw => 1 ) || '';
+        my $PostPw = $Self->{ParamObject}->GetParam(
+            Param => 'Password',
+            Raw   => 1
+        ) || '';
 
         # create AuthObject
-        my $AuthObject = Kernel::System::CustomerAuth->new( %{$Self} );
+        my $AuthObject = $Kernel::OM->Get('Kernel::System::CustomerAuth');
 
         # check submitted data
-        my $User = $AuthObject->Auth( User => $PostUser, Pw => $PostPw );
+        my $User = $AuthObject->Auth(
+            User => $PostUser,
+            Pw   => $PostPw
+        );
 
-        # login is vailid
+        my $Expires = '+' . $Self->{ConfigObject}->Get('SessionMaxTime') . 's';
+        if ( !$Self->{ConfigObject}->Get('SessionUseCookieAfterBrowserClose') ) {
+            $Expires = '';
+        }
+
+        # login is invalid
         if ( !$User ) {
+            $Kernel::OM->ObjectParamAdd(
+                'Kernel::Output::HTML::Layout' => {
+                    SetCookies => {
+                        OTRSBrowserHasCookie => $Self->{ParamObject}->SetCookie(
+                            Key      => 'OTRSBrowserHasCookie',
+                            Value    => 1,
+                            Expires  => $Expires,
+                            Path     => $Self->{ConfigObject}->Get('ScriptAlias'),
+                            Secure   => $CookieSecureAttribute,
+                            HTTPOnly => 1,
+                        ),
+                    },
+                },
+            );
+
+            my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
             # redirect to alternate login
             if ( $Self->{ConfigObject}->Get('CustomerPanelLoginURL') ) {
@@ -227,7 +292,9 @@ sub Run {
                         Type => 'Info',
                         What => 'Message',
                         )
-                        || 'Login failed! Your user name or password was entered incorrectly.',
+                        || $AuthObject->GetLastErrorMessage()
+                        || $LayoutObject->{LanguageObject}
+                        ->Translate('Login failed! Your user name or password was entered incorrectly.'),
                     User        => $PostUser,
                     LoginFailed => 1,
                     %Param,
@@ -237,11 +304,25 @@ sub Run {
         }
 
         # login is successful
-        my %UserData = $Self->{UserObject}->CustomerUserDataGet( User => $User, Valid => 1 );
+        my %UserData = $Self->{UserObject}->CustomerUserDataGet(
+            User  => $User,
+            Valid => 1
+        );
+
+        # check if the browser supports cookies
+        if ( $Self->{ParamObject}->GetCookie( Key => 'OTRSBrowserHasCookie' ) ) {
+            $Kernel::OM->ObjectParamAdd(
+                'Kernel::Output::HTML::Layout' => {
+                    BrowserHasCookie => 1,
+                },
+            );
+        }
 
         # check needed data
         if ( !$UserData{UserID} || !$UserData{UserLogin} ) {
 
+            my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
             # redirect to alternate login
             if ( $Self->{ConfigObject}->Get('CustomerPanelLoginURL') ) {
                 print $LayoutObject->Redirect(
@@ -256,7 +337,9 @@ sub Run {
                 Output => \$LayoutObject->CustomerLogin(
                     Title => 'Panic!',
                     Message =>
-                        'Authentication succeeded, but no customer record is found in the customer backend. Please contact your administrator.',
+                        $LayoutObject->{LanguageObject}->Translate(
+                        'Authentication succeeded, but no customer record is found in the customer backend. Please contact your administrator.'
+                        ),
                     %Param,
                 ),
             );
@@ -293,6 +376,8 @@ sub Run {
             # get error message
             my $Error = $Self->{SessionObject}->SessionIDErrorMessage() || '';
 
+            my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
             # output error message
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
@@ -308,7 +393,6 @@ sub Run {
         if (
             $Self->{ConfigObject}->Get('TimeZoneUser')
             && $Self->{ConfigObject}->Get('TimeZoneUserBrowserAutoOffset')
-            && $LayoutObject->{BrowserJavaScriptSupport}
             )
         {
             my $TimeOffset = $Self->{ParamObject}->GetParam( Param => 'TimeOffset' ) || 0;
@@ -331,36 +415,43 @@ sub Run {
             );
         }
 
-        # create a new LayoutObject with SessionIDCookie
-        my $Expires = '+' . $Self->{ConfigObject}->Get('SessionMaxTime') . 's';
-        if ( !$Self->{ConfigObject}->Get('SessionUseCookieAfterBrowserClose') ) {
-            $Expires = '';
-        }
+        $Kernel::OM->ObjectParamAdd(
+            'Kernel::Output::HTML::Layout' => {
+                SetCookies => {
+                    SessionIDCookie => $Self->{ParamObject}->SetCookie(
+                        Key      => $Param{SessionName},
+                        Value    => $NewSessionID,
+                        Expires  => $Expires,
+                        Path     => $Self->{ConfigObject}->Get('ScriptAlias'),
+                        Secure   => scalar $CookieSecureAttribute,
+                        HTTPOnly => 1,
+                    ),
+                    OTRSBrowserHasCookie => $Self->{ParamObject}->SetCookie(
+                        Key      => 'OTRSBrowserHasCookie',
+                        Value    => '',
+                        Expires  => '-1y',
+                        Path     => $Self->{ConfigObject}->Get('ScriptAlias'),
+                        Secure   => $CookieSecureAttribute,
+                        HTTPOnly => 1,
+                    ),
 
-        $LayoutObject = Kernel::Output::HTML::Layout->new(
-            SetCookies => {
-                SessionIDCookie => $Self->{ParamObject}->SetCookie(
-                    Key      => $Param{SessionName},
-                    Value    => $NewSessionID,
-                    Expires  => $Expires,
-                    Path     => $Self->{ConfigObject}->Get('ScriptAlias'),
-                    Secure   => scalar $CookieSecureAttribute,
-                    HTTPOnly => 1,
-                ),
+                },
+                SessionID   => $NewSessionID,
+                SessionName => $Param{SessionName},
             },
-            SessionID   => $NewSessionID,
-            SessionName => $Param{SessionName},
-            %{$Self},
         );
 
         # redirect with new session id and old params
         # prepare old redirect URL -- do not redirect to Login or Logout (loop)!
-        if ( $Param{RequestedURL} =~ /Action=(Logout|Login|LostPassword)/ ) {
+        if ( $Param{RequestedURL} =~ /Action=(Logout|Login|LostPassword|PreLogin)/ ) {
             $Param{RequestedURL} = '';
         }
 
         # redirect with new session id
-        print $LayoutObject->Redirect( OP => $Param{RequestedURL} );
+        print $Kernel::OM->Get('Kernel::Output::HTML::Layout')->Redirect(
+            OP    => $Param{RequestedURL},
+            Login => 1,
+        );
         return 1;
     }
 
@@ -371,7 +462,7 @@ sub Run {
         if ( !$Self->{SessionObject}->CheckSessionID( SessionID => $Param{SessionID} ) ) {
 
             # new layout object
-            my $LayoutObject = Kernel::Output::HTML::Layout->new( %{$Self}, Lang => $Param{Lang} );
+            my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
             # redirect to alternate login
             if ( $Self->{ConfigObject}->Get('CustomerPanelLoginURL') ) {
@@ -385,35 +476,43 @@ sub Run {
             # show login screen
             print $LayoutObject->CustomerLogin(
                 Title   => 'Logout',
-                Message => 'Session invalid. Please log in again.',
+                Message => $LayoutObject->{LanguageObject}->Translate('Session invalid. Please log in again.'),
                 %Param,
             );
             return;
         }
 
         # get session data
-        my %UserData = $Self->{SessionObject}->GetSessionIDData( SessionID => $Param{SessionID}, );
+        my %UserData = $Self->{SessionObject}->GetSessionIDData(
+            SessionID => $Param{SessionID},
+        );
 
         # create new LayoutObject with new '%Param' and '%UserData'
-        my $LayoutObject = Kernel::Output::HTML::Layout->new(
-            SetCookies => {
-                SessionIDCookie => $Self->{ParamObject}->SetCookie(
-                    Key      => $Param{SessionName},
-                    Value    => '',
-                    Expires  => '-1y',
-                    Path     => $Self->{ConfigObject}->Get('ScriptAlias'),
-                    Secure   => scalar $CookieSecureAttribute,
-                    HTTPOnly => 1,
-                ),
+        $Kernel::OM->ObjectParamAdd(
+            'Kernel::Output::HTML::Layout' => {
+                SetCookies => {
+                    SessionIDCookie => $Self->{ParamObject}->SetCookie(
+                        Key      => $Param{SessionName},
+                        Value    => '',
+                        Expires  => '-1y',
+                        Path     => $Self->{ConfigObject}->Get('ScriptAlias'),
+                        Secure   => scalar $CookieSecureAttribute,
+                        HTTPOnly => 1,
+                    ),
+                },
+                %Param,
+                %UserData,
             },
-            %{$Self},
-            %Param,
-            %UserData,
         );
 
+        $Kernel::OM->ObjectsDiscard( Objects => ['Kernel::Output::HTML::Layout'] );
+        my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
         # remove session id
         if ( !$Self->{SessionObject}->RemoveSessionID( SessionID => $Param{SessionID} ) ) {
-            $LayoutObject->CustomerFatalError( Comment => 'Please contact your administrator' );
+            $LayoutObject->CustomerFatalError(
+                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator')
+            );
             return;
         }
 
@@ -426,10 +525,16 @@ sub Run {
         }
 
         # show logout screen
+        my $LogoutMessage = $LayoutObject->{LanguageObject}->Translate(
+            'Logout successful. Thank you for using %s!',
+            $Self->{ConfigObject}->Get("ProductName"),
+        );
+
         $LayoutObject->Print(
             Output => \$LayoutObject->CustomerLogin(
-                Title   => 'Logout',
-                Message => 'Logout successful. Thank you for using %s!", "$Config{"ProductName"}',
+                Title       => 'Logout',
+                Message     => $LogoutMessage,
+                MessageType => 'Logout',
                 %Param,
             ),
         );
@@ -440,7 +545,7 @@ sub Run {
     elsif ( $Param{Action} eq 'CustomerLostPassword' ) {
 
         # new layout object
-        my $LayoutObject = Kernel::Output::HTML::Layout->new( %{$Self}, Lang => $Param{Lang}, );
+        my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
         # check feature
         if ( !$Self->{ConfigObject}->Get('CustomerPanelLostPassword') ) {
@@ -449,7 +554,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => 'Feature not active!',
+                    Message => $LayoutObject->{LanguageObject}->Translate('Feature not active!'),
                 ),
             );
             return;
@@ -465,6 +570,7 @@ sub Run {
                 Key   => 'UserToken',
                 Value => $Token,
             );
+            USER_ID:
             for my $UserID ( sort keys %UserList ) {
                 my %UserData = $Self->{UserObject}->CustomerUserDataGet(
                     User  => $UserID,
@@ -472,7 +578,7 @@ sub Run {
                 );
                 if (%UserData) {
                     $User = $UserData{UserLogin};
-                    last;
+                    last USER_ID;
                 }
             }
         }
@@ -487,7 +593,8 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => 'Sent password reset instructions. Please check your email.',
+                    Message => $LayoutObject->{LanguageObject}
+                        ->Translate('Sent password reset instructions. Please check your email.'),
                 ),
             );
             return;
@@ -521,14 +628,15 @@ sub Run {
             );
             if ( !$Sent ) {
                 $LayoutObject->FatalError(
-                    Comment => 'Please contact your administrator'
+                    Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
                 );
                 return;
             }
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => 'Sent password reset instructions. Please check your email.',
+                    Message => $LayoutObject->{LanguageObject}
+                        ->Translate('Sent password reset instructions. Please check your email.'),
                     %Param,
                 ),
             );
@@ -557,15 +665,18 @@ sub Run {
         $UserData{NewPW} = $Self->{UserObject}->GenerateRandomPassword();
 
         # update new password
-        my $Success
-            = $Self->{UserObject}->SetPassword( UserLogin => $User, PW => $UserData{NewPW} );
+        my $Success = $Self->{UserObject}->SetPassword(
+            UserLogin => $User,
+            PW        => $UserData{NewPW}
+        );
 
         if ( !$Success ) {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title => 'Login',
                     Message =>
-                        "Reset password unsuccessful. Please contact your administrator",
+                        $LayoutObject->{LanguageObject}
+                        ->Translate('Reset password unsuccessful. Please contact your administrator'),
                     User => $User,
                 ),
             );
@@ -593,12 +704,15 @@ sub Run {
             );
             return;
         }
+        my $Message = $LayoutObject->{LanguageObject}->Translate(
+            'Sent new password to %s. Please check your email.',
+            $UserData{UserEmail},
+        );
         $LayoutObject->Print(
             Output => \$LayoutObject->CustomerLogin(
-                Title => 'Login',
-                Message =>
-                    "Sent new password to \%s. Please check your email.\", \"$UserData{UserEmail}",
-                User => $User,
+                Title   => 'Login',
+                Message => $Message,
+                User    => $User,
             ),
         );
         return 1;
@@ -608,7 +722,7 @@ sub Run {
     elsif ( $Param{Action} eq 'CustomerCreateAccount' ) {
 
         # new layout object
-        my $LayoutObject = Kernel::Output::HTML::Layout->new( %{$Self}, Lang => $Param{Lang} );
+        my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
         # check feature
         if ( !$Self->{ConfigObject}->Get('CustomerPanelCreateAccount') ) {
@@ -617,7 +731,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => 'Feature not active!',
+                    Message => $LayoutObject->{LanguageObject}->Translate('Feature not active!'),
                 ),
             );
             return;
@@ -650,7 +764,8 @@ sub Run {
                 Output => \$LayoutObject->CustomerLogin(
                     Title => 'Login',
                     Message =>
-                        'This email address already exists. Please log in or reset your password.',
+                        $LayoutObject->{LanguageObject}
+                        ->Translate('This e-mail address already exists. Please log in or reset your password.'),
                     UserTitle     => $GetParams{UserTitle},
                     UserFirstname => $GetParams{UserFirstname},
                     UserLastname  => $GetParams{UserLastname},
@@ -660,6 +775,65 @@ sub Run {
             return;
         }
 
+        # check for mail address restrictions
+        my @Whitelist = @{
+            $Self->{ConfigObject}->Get('CustomerPanelCreateAccount::MailRestrictions::Whitelist') // []
+        };
+        my @Blacklist = @{
+            $Self->{ConfigObject}->Get('CustomerPanelCreateAccount::MailRestrictions::Blacklist') // []
+        };
+
+        my $WhitelistMatched;
+        for my $WhitelistEntry (@Whitelist) {
+            my $Regex = eval {qr/$WhitelistEntry/i};
+            if ($@) {
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message =>
+                        $LayoutObject->{LanguageObject}->Translate(
+                        'The customer panel mail address whitelist contains the invalid regular expression $WhitelistEntry, please check and correct it.'
+                        ),
+                );
+            }
+            elsif ( $GetParams{UserEmail} =~ $Regex ) {
+                $WhitelistMatched++;
+            }
+        }
+        my $BlacklistMatched;
+        for my $BlacklistEntry (@Blacklist) {
+            my $Regex = eval {qr/$BlacklistEntry/i};
+            if ($@) {
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message =>
+                        $LayoutObject->{LanguageObject}->Translate(
+                        'The customer panel mail address blacklist contains the invalid regular expression $BlacklistEntry, please check and correct it.'
+                        ),
+                );
+            }
+            elsif ( $GetParams{UserEmail} =~ $Regex ) {
+                $BlacklistMatched++;
+            }
+        }
+
+        if ( ( @Whitelist && !$WhitelistMatched ) || ( @Blacklist && $BlacklistMatched ) ) {
+            $LayoutObject->Block( Name => 'SignupError' );
+            $LayoutObject->Print(
+                Output => \$LayoutObject->CustomerLogin(
+                    Title => 'Login',
+                    Message =>
+                        $LayoutObject->{LanguageObject}
+                        ->Translate('This email address is not allowed to register. Please contact support staff.'),
+                    UserTitle     => $GetParams{UserTitle},
+                    UserFirstname => $GetParams{UserFirstname},
+                    UserLastname  => $GetParams{UserLastname},
+                    UserEmail     => $GetParams{UserEmail},
+                ),
+            );
+
+            return;
+        }
+
         # create account
         my $Now = $Self->{TimeObject}->SystemTime2TimeStamp(
             SystemTime => $Self->{TimeObject}->SystemTime(),
@@ -729,13 +903,17 @@ sub Run {
             return 1;
         }
 
+        my $AccountCreatedMessage = $LayoutObject->{LanguageObject}->Translate(
+            'New account created. Sent login information to %s. Please check your email.',
+            $GetParams{UserEmail},
+        );
+
         # login screen
         $LayoutObject->Print(
             Output => \$LayoutObject->CustomerLogin(
-                Title => 'Login',
-                Message =>
-                    "New account created. Sent login information to \%s. Please check your email.\", \"$GetParams{UserEmail}",
-                User => $GetParams{UserLogin},
+                Title   => 'Login',
+                Message => $AccountCreatedMessage,
+                User    => $GetParams{UserLogin},
             ),
         );
         return 1;
@@ -745,16 +923,16 @@ sub Run {
     elsif ( !$Param{SessionID} ) {
 
         # new layout object
-        my $LayoutObject = Kernel::Output::HTML::Layout->new( %{$Self}, Lang => $Param{Lang} );
+        my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
         # create AuthObject
-        my $AuthObject = Kernel::System::CustomerAuth->new( %{$Self} );
+        my $AuthObject = $Kernel::OM->Get('Kernel::System::CustomerAuth');
         if ( $AuthObject->GetOption( What => 'PreAuth' ) ) {
 
             # automatic login
             $Param{RequestedURL} = $LayoutObject->LinkEncode( $Param{RequestedURL} );
             print $LayoutObject->Redirect(
-                OP => "Action=Login;RequestedURL=$Param{RequestedURL}",
+                OP => "Action=PreLogin;RequestedURL=$Param{RequestedURL}",
             );
             return;
         }
@@ -786,24 +964,41 @@ sub Run {
         if ( !$Self->{SessionObject}->CheckSessionID( SessionID => $Param{SessionID} ) ) {
 
             # create new LayoutObject with new '%Param'
-            my $LayoutObject = Kernel::Output::HTML::Layout->new(
-                SetCookies => {
-                    SessionIDCookie => $Self->{ParamObject}->SetCookie(
-                        Key      => $Param{SessionName},
-                        Value    => '',
-                        Expires  => '-1y',
-                        Path     => $Self->{ConfigObject}->Get('ScriptAlias'),
-                        Secure   => scalar $CookieSecureAttribute,
-                        HTTPOnly => 1,
-                    ),
-                },
-                %{$Self},
-                %Param,
+            $Kernel::OM->ObjectParamAdd(
+                'Kernel::Output::HTML::Layout' => {
+                    SetCookies => {
+                        SessionIDCookie => $Self->{ParamObject}->SetCookie(
+                            Key      => $Param{SessionName},
+                            Value    => '',
+                            Expires  => '-1y',
+                            Path     => $Self->{ConfigObject}->Get('ScriptAlias'),
+                            Secure   => scalar $CookieSecureAttribute,
+                            HTTPOnly => 1,
+                        ),
+                    },
+                    %Param,
+                    }
             );
 
-            # redirect to alternate login
-            if ( $Self->{ConfigObject}->Get('CustomerPanelLoginURL') ) {
+            $Kernel::OM->ObjectsDiscard( Objects => ['Kernel::Output::HTML::Layout'] );
+            my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
+            # create AuthObject
+            my $AuthObject = $Kernel::OM->Get('Kernel::System::CustomerAuth');
+            if ( $AuthObject->GetOption( What => 'PreAuth' ) ) {
+
+                # automatic re-login
+                $Param{RequestedURL} = $LayoutObject->LinkEncode( $Param{RequestedURL} );
+                print $LayoutObject->Redirect(
+                    OP => "?Action=PreLogin&RequestedURL=$Param{RequestedURL}",
+                );
+                return;
+            }
+
+            # redirect to alternate login
+            elsif ( $Self->{ConfigObject}->Get('CustomerPanelLoginURL') ) {
+
+                # redirect to alternate login
                 $Param{RequestedURL} = $LayoutObject->LinkEncode( $Param{RequestedURL} );
                 print $LayoutObject->Redirect(
                     ExtURL => $Self->{ConfigObject}->Get('CustomerPanelLoginURL')
@@ -815,8 +1010,9 @@ sub Run {
             # show login
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
-                    Title   => 'Login',
-                    Message => $Self->{SessionObject}->SessionIDErrorMessage(),
+                    Title => 'Login',
+                    Message =>
+                        $LayoutObject->{LanguageObject}->Translate( $Self->{SessionObject}->SessionIDErrorMessage() ),
                     %Param,
                 ),
             );
@@ -830,7 +1026,7 @@ sub Run {
 
         # check needed data
         if ( !$UserData{UserID} || !$UserData{UserLogin} || $UserData{UserType} ne 'Customer' ) {
-            my $LayoutObject = Kernel::Output::HTML::Layout->new( %{$Self}, Lang => $Param{Lang} );
+            my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
             # redirect to alternate login
             if ( $Self->{ConfigObject}->Get('CustomerPanelLoginURL') ) {
@@ -845,7 +1041,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Panic!',
-                    Message => 'Panic! Invalid Session!!!',
+                    Message => $LayoutObject->{LanguageObject}->Translate('Panic! Invalid Session!!!'),
                     %Param,
                 ),
             );
@@ -857,13 +1053,15 @@ sub Run {
         if ( !$ModuleReg ) {
 
             # new layout object
-            my $LayoutObject = Kernel::Output::HTML::Layout->new( %{$Self}, Lang => $Param{Lang}, );
+            my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
             $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message =>
                     "Module Kernel::Modules::$Param{Action} not registered in Kernel/Config.pm!",
             );
-            $LayoutObject->CustomerFatalError( Comment => 'Please contact your administrator' );
+            $LayoutObject->CustomerFatalError(
+                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
+            );
             return;
         }
 
@@ -873,18 +1071,20 @@ sub Run {
             $Param{AccessRw} = 1;
         }
         else {
+            PERMISSION:
             for my $Permission (qw(GroupRo Group)) {
                 my $AccessOk = 0;
                 my $Group    = $ModuleReg->{$Permission};
                 my $Key      = "UserIs$Permission";
-                next if !$Group;
+                next PERMISSION if !$Group;
                 if ( ref $Group eq 'ARRAY' ) {
+                    GROUP:
                     for ( @{$Group} ) {
-                        next if !$_;
-                        next if !$UserData{ $Key . "[$_]" };
-                        next if $UserData{ $Key . "[$_]" } ne 'Yes';
+                        next GROUP if !$_;
+                        next GROUP if !$UserData{ $Key . "[$_]" };
+                        next GROUP if $UserData{ $Key . "[$_]" } ne 'Yes';
                         $AccessOk = 1;
-                        last;
+                        last GROUP;
                     }
                 }
                 else {
@@ -901,13 +1101,10 @@ sub Run {
                     $Param{AccessRo} = 1;
                 }
             }
-            if ( !$Param{AccessRo} && !$Param{AccessRw} || !$Param{AccessRo} && $Param{AccessRw} ) {
+            if ( !$Param{AccessRo} ) {
 
                 # new layout object
-                my $LayoutObject = Kernel::Output::HTML::Layout->new(
-                    %{$Self},
-                    Lang => $Param{Lang},
-                );
+                my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
                 $Self->{LogObject}->Log(
                     Priority => 'error',
                     Message  => 'No Permission to use this frontend module!'
@@ -918,19 +1115,25 @@ sub Run {
         }
 
         # create new LayoutObject with new '%Param' and '%UserData'
-        my $LayoutObject = Kernel::Output::HTML::Layout->new(
-            %{$Self},
-            %Param,
-            %UserData,
-            ModuleReg => $ModuleReg,
+        $Kernel::OM->ObjectParamAdd(
+            'Kernel::Output::HTML::Layout' => {
+                %Param,
+                %UserData,
+                ModuleReg => $ModuleReg,
+            },
         );
 
-        # updated last request time
-        $Self->{SessionObject}->UpdateSessionID(
-            SessionID => $Param{SessionID},
-            Key       => 'UserLastRequest',
-            Value     => $Self->{TimeObject}->SystemTime(),
-        );
+        $Kernel::OM->ObjectsDiscard( Objects => ['Kernel::Output::HTML::Layout'] );
+        my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
+        # update last request time
+        if ( !$Self->{ParamObject}->IsAJAXRequest() ) {
+            $Self->{SessionObject}->UpdateSessionID(
+                SessionID => $Param{SessionID},
+                Key       => 'UserLastRequest',
+                Value     => $Self->{TimeObject}->SystemTime(),
+            );
+        }
 
         # pre application module
         my $PreModule = $Self->{ConfigObject}->Get('CustomerPanelPreApplicationModule');
@@ -942,10 +1145,12 @@ sub Run {
             else {
                 $PreModuleList{Init} = $PreModule;
             }
+
+            MODULE:
             for my $PreModuleKey ( sort keys %PreModuleList ) {
                 my $PreModule = $PreModuleList{$PreModuleKey};
-                next if !$PreModule;
-                next if !$Self->{MainObject}->Require($PreModule);
+                next MODULE if !$PreModule;
+                next MODULE if !$Self->{MainObject}->Require($PreModule);
 
                 # debug info
                 if ( $Self->{Debug} ) {
@@ -1031,13 +1236,19 @@ sub Run {
     }
 
     # print an error screen
-    my %Data = $Self->{SessionObject}->GetSessionIDData( SessionID => $Param{SessionID}, );
-    my $LayoutObject = Kernel::Output::HTML::Layout->new(
-        %{$Self},
-        %Param,
-        %Data,
+    my %Data = $Self->{SessionObject}->GetSessionIDData(
+        SessionID => $Param{SessionID},
+    );
+    $Kernel::OM->ObjectParamAdd(
+        'Kernel::Output::HTML::Layout' => {
+            %Param,
+            %Data,
+        },
+    );
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    $LayoutObject->CustomerFatalError(
+        Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
     );
-    $LayoutObject->CustomerFatalError( Comment => 'Please contact your administrator' );
     return;
 }
 
