@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/fcgi-bin/index.pl - the global FastCGI handle file (incl. auth) for OTRS
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -32,6 +33,7 @@ use CGI::Fast;
 
 # load agent web interface
 use Kernel::System::Web::InterfaceAgent();
+use Kernel::System::ObjectManager;
 
 # 0=off;1=on;
 my $Debug = 0;
@@ -41,13 +43,11 @@ my $Debug = 0;
 # Response loop
 while ( my $WebRequest = new CGI::Fast ) {
 
-    # create new object
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
     my $Interface = Kernel::System::Web::InterfaceAgent->new(
         Debug      => $Debug,
-        WebRequest => $WebRequest
+        WebRequest => $WebRequest,
     );
-
-    # execute object
     $Interface->Run();
 
     #    $Cnt++;
