@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.AddService.pl - add new Services
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -29,23 +30,16 @@ use lib dirname($RealBin) . '/Custom';
 
 use Getopt::Std;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Log;
-use Kernel::System::DB;
-use Kernel::System::Main;
-use Kernel::System::Service;
+use Kernel::System::ObjectManager;
 
 my %Param;
-my %CommonObject;
 
-# create common objects
-$CommonObject{ConfigObject}  = Kernel::Config->new();
-$CommonObject{EncodeObject}  = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}     = Kernel::System::Log->new( %CommonObject, LogPrefix => 'OTRS-otrs.AddService' );
-$CommonObject{MainObject}    = Kernel::System::Main->new(%CommonObject);
-$CommonObject{DBObject}      = Kernel::System::DB->new(%CommonObject);
-$CommonObject{ServiceObject} = Kernel::System::Service->new(%CommonObject);
+# create object manager
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-otrs.AddService',
+    },
+);
 
 my $NoOptions = $ARGV[0] ? 0 : 1;
 
@@ -67,7 +61,7 @@ my $ServiceName;
 
 # lookup parent service if given
 if ( $Opts{p} ) {
-    $Param{ParentID} = $CommonObject{ServiceObject}->ServiceLookup(
+    $Param{ParentID} = $Kernel::OM->Get('Kernel::System::Service')->ServiceLookup(
         Name   => $Opts{p},
         UserID => 1,
     );
@@ -81,7 +75,7 @@ if ( $Opts{p} ) {
 $ServiceName .= $Opts{n};
 
 # check if service already exists
-my %ServiceList = $CommonObject{ServiceObject}->ServiceList(
+my %ServiceList = $Kernel::OM->Get('Kernel::System::Service')->ServiceList(
     Valid  => 0,
     UserID => 1,
 );
@@ -99,7 +93,7 @@ $Param{ValidID} = '1';
 $Param{Name}    = $Opts{n} || '';
 $Param{Comment} = $Opts{c};
 
-if ( my $ID = $CommonObject{ServiceObject}->ServiceAdd(%Param) ) {
+if ( my $ID = $Kernel::OM->Get('Kernel::System::Service')->ServiceAdd(%Param) ) {
     print "Service '$ServiceName' added. ID is '$ID'\n";
 }
 else {
