@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# otrs.ArticleStorageSwitch.pl - to move stored attachments from one backend to other
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -30,21 +31,14 @@ use lib dirname($RealBin) . '/Custom';
 use Getopt::Std;
 use Time::HiRes qw(usleep);
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Log;
-use Kernel::System::Time;
-use Kernel::System::DB;
-use Kernel::System::PID;
-use Kernel::System::Main;
-use Kernel::System::Ticket;
+use Kernel::System::ObjectManager;
 
 # get options
 my %Opts;
-getopt( 'hsdcCb', \%Opts );
+getopt( 'sdcCb', \%Opts );
 if ( $Opts{h} ) {
     print "otrs.ArticleStorageSwitch.pl - to move storage content\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n";
     print
         "usage: otrs.ArticleStorageSwitch.pl -s ArticleStorageDB -d ArticleStorageFS [-c <JUST_SELECT_WHERE_CLOSE_DATE_IS_BEFORE> e. g. -c '2011-06-29 14:00:00' -C <JUST_SELECT_WHERE_CLOSE_IS_OLDER_IN_DAYS] e. g. -C '5' [-b sleeptime per ticket in microseconds] [-l liberal] [-f force]\n";
     exit 1;
@@ -68,33 +62,41 @@ if ( $Opts{b} && $Opts{b} !~ m{ \A \d+ \z }xms ) {
     exit 1;
 }
 
-# create common objects
-my %CommonObject;
-$CommonObject{ConfigObject} = Kernel::Config->new();
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    LogPrefix => 'OTRS-otrs.ArticleStorageSwitch.pl',
-    %CommonObject,
+# create object manager
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-otrs.ArticleStorageSwitch.pl',
+    },
 );
-$CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
-$CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
 
-# create needed objects
-$CommonObject{DBObject}     = Kernel::System::DB->new(%CommonObject);
-$CommonObject{PIDObject}    = Kernel::System::PID->new(%CommonObject);
-$CommonObject{TicketObject} = Kernel::System::Ticket->new(%CommonObject);
+# disable cache
+$Kernel::OM->Get('Kernel::System::Cache')->Configure(
+    CacheInMemory  => 0,
+    CacheInBackend => 1,
+);
 
 # disable ticket events
-$CommonObject{ConfigObject}->{'Ticket::EventModulePost'} = {};
+$Kernel::OM->Get('Kernel::Config')->{'Ticket::EventModulePost'} = {};
+
+# get pid object
+my $PIDObject = $Kernel::OM->Get('Kernel::System::PID');
 
 # create pid lock
-if ( !$Opts{f} && !$CommonObject{PIDObject}->PIDCreate( Name => 'ArticleStorageSwitch' ) ) {
+if (
+    !$Opts{f}
+    && !$PIDObject->PIDCreate( Name => 'ArticleStorageSwitch' )
+    )
+{
     print
         "NOTICE: otrs.ArticleStorageSwitch.pl is already running (use '-f' if you want to start it ";
     print "forced)!\n";
     exit 1;
 }
-elsif ( $Opts{f} && !$CommonObject{PIDObject}->PIDCreate( Name => 'ArticleStorageSwitch' ) ) {
+elsif (
+    $Opts{f}
+    && !$PIDObject->PIDCreate( Name => 'ArticleStorageSwitch' )
+    )
+{
     print "NOTICE: otrs.ArticleStorageSwitch.pl is already running but is starting again!\n";
 }
 
@@ -108,7 +110,7 @@ my %SearchParams;
 if ( $Opts{c} ) {
 
     # check time stamp format
-    if ( !$CommonObject{TimeObject}->TimeStamp2SystemTime( String => $Opts{c} ) ) {
+    if ( !$Kernel::OM->Get('Kernel::System::Time')->TimeStamp2SystemTime( String => $Opts{c} ) ) {
         print STDERR
             "ERROR: -c '$Opts{c}' is not a valid time stamp, please use 'yyyy-mm-dd hh:mm:ss'\n";
         exit 1;
@@ -127,8 +129,8 @@ elsif ( $Opts{C} ) {
         exit 1;
     }
     $Opts{C} = $Opts{C} * 60 * 60 * 24;
-    my $TimeStamp = $CommonObject{TimeObject}->SystemTime() - $Opts{C};
-    $TimeStamp = $CommonObject{TimeObject}->SystemTime2TimeStamp(
+    my $TimeStamp = $Kernel::OM->Get('Kernel::System::Time')->SystemTime() - $Opts{C};
+    $TimeStamp = $Kernel::OM->Get('Kernel::System::Time')->SystemTime2TimeStamp(
         SystemTime => $TimeStamp,
     );
     print "NOTICE: Searching for ticket which are closed before '$TimeStamp'\n";
@@ -139,14 +141,17 @@ elsif ( $Opts{C} ) {
 }
 
 # set new PID
-$CommonObject{PIDObject}->PIDCreate(
+$PIDObject->PIDCreate(
     Name  => 'ArticleStorageSwitch',
     Force => 1,
     TTL   => 60 * 60 * 24 * 3,
 );
 
+# get ticket object
+my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
 # get all tickets
-my @TicketIDs = $CommonObject{TicketObject}->TicketSearch(
+my @TicketIDs = $TicketObject->TicketSearch(
 
     # additional search params
     %SearchParams,
@@ -171,7 +176,7 @@ for my $TicketID (@TicketIDs) {
 
     print "NOTICE: $Count/$CountTotal (TicketID:$TicketID)\n";
 
-    my $Success = $CommonObject{TicketObject}->TicketArticleStorageSwitch(
+    my $Success = $TicketObject->TicketArticleStorageSwitch(
         TicketID    => $TicketID,
         Source      => $Opts{s},
         Destination => $Opts{d},
@@ -186,7 +191,7 @@ for my $TicketID (@TicketIDs) {
 }
 
 # delete pid lock
-$CommonObject{PIDObject}->PIDDelete( Name => 'ArticleStorageSwitch' );
+$PIDObject->PIDDelete( Name => 'ArticleStorageSwitch' );
 
 print "NOTICE: done.\n";
 
