@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.CleanupTicketMetadata.pl - remove unneeded ticket meta data
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -28,62 +29,51 @@ use lib dirname($RealBin) . '/Kernel/cpan-lib';
 use lib dirname($RealBin) . '/Custom';
 
 use Getopt::Long;
+use Time::HiRes qw(usleep);
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Time;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::DB;
-use Kernel::System::User;
-use Kernel::System::Group;
-use Kernel::System::Queue;
-use Kernel::System::Ticket;
-use Kernel::System::VariableCheck qw(:all);
+use Kernel::System::ObjectManager;
 
-sub _CommonObjects {
-    my %Objects;
-    $Objects{ConfigObject} = Kernel::Config->new();
-    $Objects{EncodeObject} = Kernel::System::Encode->new(%Objects);
-    $Objects{LogObject}    = Kernel::System::Log->new(
+# create object manager
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
         LogPrefix => 'OTRS-otrs.CleanupTicketMetadata.pl',
-        %Objects,
-    );
-    $Objects{TimeObject}   = Kernel::System::Time->new(%Objects);
-    $Objects{MainObject}   = Kernel::System::Main->new(%Objects);
-    $Objects{DBObject}     = Kernel::System::DB->new(%Objects);
-    $Objects{UserObject}   = Kernel::System::User->new(%Objects);
-    $Objects{GroupObject}  = Kernel::System::Group->new(%Objects);
-    $Objects{QueueObject}  = Kernel::System::Queue->new(%Objects);
-    $Objects{TicketObject} = Kernel::System::Ticket->new(%Objects);
+    },
+);
 
-    return \%Objects;
-}
+# disable cache
+$Kernel::OM->Get('Kernel::System::Cache')->Configure(
+    CacheInMemory  => 0,
+    CacheInBackend => 1,
+);
+
+# disable ticket events
+$Kernel::OM->Get('Kernel::Config')->{'Ticket::EventModulePost'} = {};
 
 sub Run {
 
-    my %Opts = ();
+    my %Opts;
     Getopt::Long::Configure('no_ignore_case');
     GetOptions(
         'archived|a'      => \$Opts{Archived},
         'invalid-users|i' => \$Opts{InvalidUsers},
         'help|h'          => \$Opts{h},
-    );
+        'break|b=s'       => \$Opts{b},
+    ) || die 'Invalid argument';
 
     if ( $Opts{h} || ( !$Opts{Archived} && !$Opts{InvalidUsers} ) ) {
         print <<EOF;
 otrs.CleanupTicketMetadata.pl - Remove unneeded ticket metadata
-Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 
 Usage:
 
-    otrs.CleanupTicketMetadata.pl --archived
+    otrs.CleanupTicketMetadata.pl --archived [-b sleeptime per ticket in microseconds]
 
     # Deletes ticket/article seen flags and ticket watcher entries for archived tickets.
     # This does not regularly need to be run as this data will automatically be removed
     #   when tickets are archived (depending on your system's configuration).
 
-    otrs.CleanupTicketMetadata.pl --invalid-users
+    otrs.CleanupTicketMetadata.pl --invalid-users [-b sleeptime per ticket in microseconds]
 
     # Deletes ticket/article seen flags and ticket watcher entries of users which have been
     #   invalid for more than a month. Run this to clean up this kind of data after invalidating
@@ -93,32 +83,36 @@ EOF
         exit 1;
     }
 
-    CleanupArchived()     if ( $Opts{Archived} );
-    CleanupInvalidUsers() if ( $Opts{InvalidUsers} );
+    if ( $Opts{b} && $Opts{b} !~ m{ \A \d+ \z }xms ) {
+        print STDERR "ERROR: sleeptime needs to be a numeric value! e.g. 1000\n";
+        exit 1;
+    }
+
+    CleanupArchived(%Opts)     if $Opts{Archived};
+    CleanupInvalidUsers(%Opts) if $Opts{InvalidUsers};
 }
 
 sub CleanupArchived {
-    my ( $Self, %Param ) = @_;
+    my (%Param) = @_;
 
-    my $CommonObject = _CommonObjects();
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
-    # Refresh common objects after a certain number of loop iterations.
-    #   This will call event handlers and clean up caches to avoid excessive mem usage.
-    my $CommonObjectRefresh = 50;
-
-    if ( !$CommonObject->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
+    if ( !$ConfigObject->Get('Ticket::ArchiveSystem') ) {
         print "Ticket::ArchiveSystem is not enabled!\n";
         return;
     }
 
-    my $DBObject2 = Kernel::System::DB->new( %{$CommonObject} );
+    # get needed objects
+    my $DBObject     = $Kernel::OM->Get('Kernel::System::DB');
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
 
-    if ( $CommonObject->{ConfigObject}->Get('Ticket::ArchiveSystem::RemoveSeenFlags') ) {
+    if ( $ConfigObject->Get('Ticket::ArchiveSystem::RemoveSeenFlags') ) {
 
         print "Checking for archived tickets with seen flags...\n";
 
         # Find all archived tickets which have ticket seen flags set
-        return if !$DBObject2->Prepare(
+        return if !$DBObject->Prepare(
             SQL => "
                 SELECT DISTINCT(ticket.id)
                 FROM ticket
@@ -129,26 +123,27 @@ sub CleanupArchived {
         );
 
         my $Count = 0;
+        ROW:
+        while ( my @Row = $DBObject->FetchrowArray() ) {
 
-        while ( my @Row = $DBObject2->FetchrowArray() ) {
-
-            $CommonObject->{TicketObject}->TicketFlagDelete(
+            $TicketObject->TicketFlagDelete(
                 TicketID => $Row[0],
                 Key      => 'Seen',
                 AllUsers => 1,
             );
 
-            if ( $Count++ % $CommonObjectRefresh == 0 ) {
-                print "    Removing seen flags of ticket $Count\n";
-                $CommonObject = _CommonObjects();
-            }
+            print "    Removing seen flags of ticket $Count\n";
+
+            next ROW if !$Param{b};
+
+            Time::HiRes::usleep( $Param{b} );
         }
 
         print "Done (changed $Count tickets).\n";
         print "Checking for archived articles with seen flags...\n";
 
         # Find all articles of archived tickets which have ticket seen flags set
-        return if !$DBObject2->Prepare(
+        return if !$DBObject->Prepare(
             SQL => "
                 SELECT DISTINCT(article.id)
                 FROM article
@@ -160,35 +155,35 @@ sub CleanupArchived {
         );
 
         $Count = 0;
+        ROW:
+        while ( my @Row = $DBObject->FetchrowArray() ) {
 
-        while ( my @Row = $DBObject2->FetchrowArray() ) {
-
-            $CommonObject->{TicketObject}->ArticleFlagDelete(
+            $TicketObject->ArticleFlagDelete(
                 ArticleID => $Row[0],
                 Key       => 'Seen',
                 AllUsers  => 1,
             );
 
-            if ( $Count++ % $CommonObjectRefresh == 0 ) {
-                print "    Removing seen flags of article $Count\n";
-                $CommonObject = _CommonObjects();
-            }
+            print "    Removing seen flags of article $Count\n";
 
+            next ROW if !$Param{b};
+
+            Time::HiRes::usleep( $Param{b} );
         }
-        print "Done (changed $Count articles).\n";
 
+        print "Done (changed $Count articles).\n";
     }
 
     if (
-        $CommonObject->{ConfigObject}->Get('Ticket::ArchiveSystem::RemoveTicketWatchers')
-        && $CommonObject->{ConfigObject}->Get('Ticket::Watcher')
+        $ConfigObject->Get('Ticket::ArchiveSystem::RemoveTicketWatchers')
+        && $ConfigObject->Get('Ticket::Watcher')
         )
     {
 
         print "Checking for archived tickets with ticket watcher entries...\n";
 
         # Find all archived tickets which have ticket seen flags set
-        return if !$DBObject2->Prepare(
+        return if !$DBObject->Prepare(
             SQL => "
                 SELECT DISTINCT(ticket.id)
                 FROM ticket
@@ -198,55 +193,56 @@ sub CleanupArchived {
         );
 
         my $Count = 0;
+        ROW:
+        while ( my @Row = $DBObject->FetchrowArray() ) {
 
-        while ( my @Row = $DBObject2->FetchrowArray() ) {
-
-            $CommonObject->{TicketObject}->TicketWatchUnsubscribe(
+            $TicketObject->TicketWatchUnsubscribe(
                 TicketID => $Row[0],
                 AllUsers => 1,
                 UserID   => 1,
             );
 
-            if ( $Count++ % $CommonObjectRefresh == 0 ) {
-                print "    Removing ticket watcher entries of ticket $Count\n";
-                $CommonObject = _CommonObjects();
-            }
+            print "    Removing ticket watcher entries of ticket $Count\n";
+
+            next ROW if !$Param{b};
+
+            Time::HiRes::usleep( $Param{b} );
         }
 
         print "Done (changed $Count tickets).\n";
-
     }
 }
 
 sub CleanupInvalidUsers {
-    my ( $Self, %Param ) = @_;
-
-    my $CommonObject = _CommonObjects();
-
-    # Refresh common objects after a certain number of loop iterations.
-    #   This will call event handlers and clean up caches to avoid excessive mem usage.
-    my $CommonObjectRefresh = 50;
+    my (%Param) = @_;
 
     my $InvalidID = 2;
 
     # Users must be invalid for at least one month
     my $Offset        = 60 * 60 * 24 * 31;
-    my $InvalidBefore = $CommonObject->{TimeObject}->SystemTime() - $Offset;
+    my $InvalidBefore = $Kernel::OM->Get('Kernel::System::Time')->SystemTime() - $Offset;
+
+    # get user object
+    my $UserObject = $Kernel::OM->Get('Kernel::System::User');
 
     # First, find all invalid users which are invalid for more than one month
-    my %AllUsers = $CommonObject->{UserObject}->UserList( Valid => 0 );
+    my %AllUsers = $UserObject->UserList( Valid => 0 );
     my @CleanupInvalidUsers;
     USERID:
     for my $UserID ( sort keys %AllUsers ) {
-        my %User = $CommonObject->{UserObject}->GetUserData( UserID => $UserID );
+
+        my %User = $UserObject->GetUserData(
+            UserID => $UserID,
+        );
 
         # Only take invalid users
         next USERID if ( $User{ValidID} != $InvalidID );
 
         # Only take users which are invalid for more than one month
-        my $InvalidTime = $CommonObject->{TimeObject}->TimeStamp2SystemTime(
+        my $InvalidTime = $Kernel::OM->Get('Kernel::System::Time')->TimeStamp2SystemTime(
             String => $User{ChangeTime},
         );
+
         next USERID if ( $InvalidTime >= $InvalidBefore );
 
         push @CleanupInvalidUsers, $UserID;
@@ -259,15 +255,21 @@ sub CleanupInvalidUsers {
 
     print "Cleanup for " . ( scalar @CleanupInvalidUsers ) . " starting...";
 
-    my $DBObject2 = Kernel::System::DB->new( %{$CommonObject} );
+    # get needed objects
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+    my $DBObject     = $Kernel::OM->Get('Kernel::System::DB');
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
 
     for my $UserID (@CleanupInvalidUsers) {
-        my %User = $CommonObject->{UserObject}->GetUserData( UserID => $UserID );
+
+        my %User = $UserObject->GetUserData(
+            UserID => $UserID,
+        );
 
         print "\nChecking for tickets with seen flags for user $User{UserLogin}...\n";
 
         # Find all archived tickets which have ticket seen flags set
-        return if !$DBObject2->Prepare(
+        return if !$DBObject->Prepare(
             SQL => "
                 SELECT DISTINCT(ticket.id)
                 FROM ticket
@@ -278,26 +280,27 @@ sub CleanupInvalidUsers {
         );
 
         my $Count = 0;
+        ROW:
+        while ( my @Row = $DBObject->FetchrowArray() ) {
 
-        while ( my @Row = $DBObject2->FetchrowArray() ) {
-
-            $CommonObject->{TicketObject}->TicketFlagDelete(
+            $TicketObject->TicketFlagDelete(
                 TicketID => $Row[0],
                 Key      => 'Seen',
                 UserID   => $UserID,
             );
 
-            if ( $Count++ % $CommonObjectRefresh == 0 ) {
-                print "    Removing seen flags of ticket $Count for user $User{UserLogin}\n";
-                $CommonObject = _CommonObjects();
-            }
+            print "    Removing seen flags of ticket $Count for user $User{UserLogin}\n";
+
+            next ROW if !$Param{b};
+
+            Time::HiRes::usleep( $Param{b} );
         }
 
         print "Done (changed $Count tickets for user $User{UserLogin}).\n";
         print "Checking for articles with seen flags for user $User{UserLogin}...\n";
 
         # Find all articles of archived tickets which have ticket seen flags set
-        return if !$DBObject2->Prepare(
+        return if !$DBObject->Prepare(
             SQL => "
                 SELECT DISTINCT(article.id)
                 FROM article
@@ -309,30 +312,30 @@ sub CleanupInvalidUsers {
         );
 
         $Count = 0;
+        ROW:
+        while ( my @Row = $DBObject->FetchrowArray() ) {
 
-        while ( my @Row = $DBObject2->FetchrowArray() ) {
-
-            $CommonObject->{TicketObject}->ArticleFlagDelete(
+            $TicketObject->ArticleFlagDelete(
                 ArticleID => $Row[0],
                 Key       => 'Seen',
                 UserID    => $UserID,
             );
 
-            if ( $Count++ % $CommonObjectRefresh == 0 ) {
-                print "    Removing seen flags of article $Count for user $User{UserLogin}\n";
-                $CommonObject = _CommonObjects();
-            }
+            print "    Removing seen flags of article $Count for user $User{UserLogin}\n";
 
+            next ROW if !$Param{b};
+
+            Time::HiRes::usleep( $Param{b} );
         }
+
         print "Done (changed $Count articles for user $User{UserLogin}).\n";
 
-        if ( $CommonObject->{ConfigObject}->Get('Ticket::Watcher') )
-        {
+        if ( $ConfigObject->Get('Ticket::Watcher') ) {
 
             print "Checking for tickets with ticket watcher entries for user $User{UserLogin}...\n";
 
             # Find all archived tickets which have ticket seen flags set
-            return if !$DBObject2->Prepare(
+            return if !$DBObject->Prepare(
                 SQL => "
                     SELECT DISTINCT(ticket.id)
                     FROM ticket
@@ -342,27 +345,26 @@ sub CleanupInvalidUsers {
             );
 
             my $Count = 0;
+            ROW:
+            while ( my @Row = $DBObject->FetchrowArray() ) {
 
-            while ( my @Row = $DBObject2->FetchrowArray() ) {
-
-                $CommonObject->{TicketObject}->TicketWatchUnsubscribe(
+                $TicketObject->TicketWatchUnsubscribe(
                     TicketID    => $Row[0],
                     WatchUserID => $UserID,
                     UserID      => 1,
                 );
 
-                if ( $Count++ % $CommonObjectRefresh == 0 ) {
-                    print
-                        "    Removing ticket watcher entries of ticket $Count for user $User{UserLogin}\n";
-                    $CommonObject = _CommonObjects();
-                }
+                print
+                    "    Removing ticket watcher entries of ticket $Count for user $User{UserLogin}\n";
+
+                next ROW if !$Param{b};
+
+                Time::HiRes::usleep( $Param{b} );
             }
 
             print "Done (changed $Count tickets for user $User{UserLogin}).\n";
-
         }
     }
-
 }
 
 Run();
