@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.DeleteCache.pl - delete all caches
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -29,17 +30,11 @@ use lib dirname($RealBin) . '/Custom';
 
 use Getopt::Long;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Time;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::DB;
-use Kernel::System::Cache;
+use Kernel::System::ObjectManager;
 
 # get options
 Getopt::Long::Configure('no_ignore_case');
-my %Opts = ();
+my %Opts;
 GetOptions(
     'expired|e' => \$Opts{e},
     'all|a'     => \$Opts{a},
@@ -48,7 +43,7 @@ GetOptions(
 );
 
 print "otrs.DeleteCache.pl - delete OTRS cache\n";
-print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n\n";
+print "Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n\n";
 
 if ( $Opts{h} ) {
     print "usage: otrs.DeleteCache.pl [--expired] [--type TYPE]\n";
@@ -65,23 +60,19 @@ if ( $Opts{t} ) {
     $Options{Type} = $Opts{t};
 }
 
-# common objects
-my %CommonObject;
-$CommonObject{ConfigObject} = Kernel::Config->new();
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    LogPrefix => 'OTRS-otrs.DeleteCache.pl',
-    %CommonObject,
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-otrs.DeleteCache.pl',
+    },
 );
-$CommonObject{TimeObject}  = Kernel::System::Time->new(%CommonObject);
-$CommonObject{MainObject}  = Kernel::System::Main->new(%CommonObject);
-$CommonObject{DBObject}    = Kernel::System::DB->new(%CommonObject);
-$CommonObject{CacheObject} = Kernel::System::Cache->new(%CommonObject);
 
-# cleanup
-if ( !$CommonObject{CacheObject}->CleanUp(%Options) ) {
+# get cache object
+my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
+
+if ( !$CacheObject->CleanUp(%Options) ) {
     exit 1;
 }
 
 print "Done.\n";
+
 exit;
