@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.GenerateStats.pl - send stats output via email
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -29,44 +30,21 @@ use lib dirname($RealBin) . '/Custom';
 
 use Getopt::Long;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Time;
-use Kernel::System::Main;
-use Kernel::System::DB;
-use Kernel::System::Log;
-use Kernel::System::Email;
-use Kernel::System::CheckItem;
-use Kernel::System::Stats;
-use Kernel::System::Group;
-use Kernel::System::User;
-use Kernel::System::CSV;
-use Kernel::System::PDF;
-use Kernel::Language;
+use Kernel::System::ObjectManager;
 
-# create common objects
-my %CommonObject = ();
-$CommonObject{UserID}       = 1;
-$CommonObject{ConfigObject} = Kernel::Config->new();
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    LogPrefix => 'OTRS-otrs.GenerateStats.pl',
-    %CommonObject,
+# create object manager
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-otrs.GenerateStats.pl',
+    },
+    'Kernel::System::Stats' => {
+        UserID => 1,
+    },
 );
-$CommonObject{CSVObject}       = Kernel::System::CSV->new(%CommonObject);
-$CommonObject{TimeObject}      = Kernel::System::Time->new(%CommonObject);
-$CommonObject{MainObject}      = Kernel::System::Main->new(%CommonObject);
-$CommonObject{DBObject}        = Kernel::System::DB->new(%CommonObject);
-$CommonObject{GroupObject}     = Kernel::System::Group->new(%CommonObject);
-$CommonObject{UserObject}      = Kernel::System::User->new(%CommonObject);
-$CommonObject{StatsObject}     = Kernel::System::Stats->new(%CommonObject);
-$CommonObject{CheckItemObject} = Kernel::System::CheckItem->new(%CommonObject);
-$CommonObject{EmailObject}     = Kernel::System::Email->new(%CommonObject);
-$CommonObject{PDFObject}       = Kernel::System::PDF->new(%CommonObject);
 
 # get options
 Getopt::Long::Configure('no_ignore_case');
-my %Opts = ();
+my %Opts;
 GetOptions(
     'number|n=n'     => \$Opts{n},
     'param|p=s'      => \$Opts{p},
@@ -84,12 +62,13 @@ GetOptions(
 
 if ( $Opts{h} || !$Opts{n} ) {
     print "otrs.GenerateStats.pl - OTRS cmd stats\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n";
     print
-        "usage: otrs.GenerateStats.pl -n <StatNumber> [-p <PARAM_STRING>] [-o <DIRECTORY>] [-r <RECIPIENT> -r ... -s <SENDER>] [-m <MESSAGE>] [-l <LANGUAGE>] [-f CSV|Print] [-S <SEPARATOR>] [-F <FILENAME> [-R]\n";
+        "usage: otrs.GenerateStats.pl -n <StatNumber> [-p <PARAM_STRING>] [-o <DIRECTORY>] [-r <RECIPIENT> -r ... -s <SENDER>] [-m <MESSAGE>] [-l <LANGUAGE>] [-f CSV|Excel|Print] [-S <SEPARATOR>] [-F <FILENAME> [-R]\n";
     print
         "       <PARAM_STRING> e. g. 'Year=1977&Month=10' (only for static files)\n";
     print "       <DIRECTORY> /output/dir/\n";
+    print "       [-R] Adds a heading line to the CSV output.\n";
     exit 1;
 }
 
@@ -124,20 +103,14 @@ if ( !$Opts{m} && $Opts{r} ) {
 }
 
 # language
-my $Lang = $CommonObject{ConfigObject}->Get('DefaultLanguage') || 'en';
+my $Lang = $Kernel::OM->Get('Kernel::Config')->Get('DefaultLanguage') || 'en';
 if ( $Opts{l} ) {
     $Lang = $Opts{l};
 }
-$CommonObject{LanguageObject} = Kernel::Language->new(
-    UserLanguage => $Lang,
-    LogObject    => $CommonObject{LogObject},
-    ConfigObject => $CommonObject{ConfigObject},
-    EncodeObject => $CommonObject{EncodeObject},
-    MainObject   => $CommonObject{MainObject},
-);
 
 # format
-my $Format = ( defined $Opts{f} && $Opts{f} eq 'Print' ) ? 'Print' : 'CSV';
+$Opts{f} //= 'CSV';
+my $Format = $Opts{f};
 
 # separator (for CSV files)
 # for backwards compatibility no comma as default
@@ -157,19 +130,19 @@ if ( $Opts{o} && !-e $Opts{o} ) {
 # process the information
 my $StatNumber = $Opts{n};
 my $StatID =
-    $CommonObject{StatsObject}->StatNumber2StatID( StatNumber => $StatNumber );
+    $Kernel::OM->Get('Kernel::System::Stats')->StatNumber2StatID( StatNumber => $StatNumber );
 if ( !$StatID ) {
     print STDERR "ERROR: No StatNumber: $Opts{n}\n";
     exit 1;
 }
 
 my ( $s, $m, $h, $D, $M, $Y ) =
-    $CommonObject{TimeObject}->SystemTime2Date(
-    SystemTime => $CommonObject{TimeObject}->SystemTime(),
+    $Kernel::OM->Get('Kernel::System::Time')->SystemTime2Date(
+    SystemTime => $Kernel::OM->Get('Kernel::System::Time')->SystemTime(),
     );
 
-my %GetParam = ();
-my $Stat = $CommonObject{StatsObject}->StatsGet( StatID => $StatID );
+my %GetParam;
+my $Stat = $Kernel::OM->Get('Kernel::System::Stats')->StatsGet( StatID => $StatID );
 
 if ( $Stat->{StatType} eq 'static' ) {
     $GetParam{Year}  = $Y;
@@ -178,7 +151,7 @@ if ( $Stat->{StatType} eq 'static' ) {
 
     # get params from -p
     # only for static files
-    my $Params = $CommonObject{StatsObject}->GetParams( StatID => $StatID );
+    my $Params = $Kernel::OM->Get('Kernel::System::Stats')->GetParams( StatID => $StatID );
     for my $ParamItem ( @{$Params} ) {
         if ( !$ParamItem->{Multiple} ) {
             my $Value = GetParam(
@@ -213,7 +186,7 @@ elsif ( $Stat->{StatType} eq 'dynamic' ) {
 
 # run stat...
 my @StatArray = @{
-    $CommonObject{StatsObject}->StatsRun(
+    $Kernel::OM->Get('Kernel::System::Stats')->StatsRun(
         StatID   => $StatID,
         GetParam => \%GetParam,
         )
@@ -230,21 +203,20 @@ if ( !@StatArray ) {
 }
 my %Attachment;
 
-if ( $Format eq 'Print' && $CommonObject{PDFObject} ) {
+if ( $Format eq 'Print' && $Kernel::OM->Get('Kernel::System::PDF') ) {
 
     # Create the PDF
-    my %User =
-        $CommonObject{UserObject}->GetUserData( UserID => $CommonObject{UserID} );
+    my %User = $Kernel::OM->Get('Kernel::System::User')->GetUserData( UserID => 1 );
 
-    my $PrintedBy  = $CommonObject{LanguageObject}->Get('printed by');
-    my $Page       = $CommonObject{LanguageObject}->Get('Page');
-    my $SystemTime = $CommonObject{TimeObject}->SystemTime();
+    my $PrintedBy  = $Kernel::OM->Get('Kernel::Language')->Translate('printed by');
+    my $Page       = $Kernel::OM->Get('Kernel::Language')->Translate('Page');
+    my $SystemTime = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
     my $TimeStamp =
-        $CommonObject{TimeObject}->SystemTime2TimeStamp(
+        $Kernel::OM->Get('Kernel::System::Time')->SystemTime2TimeStamp(
         SystemTime => $SystemTime,
         );
     my $Time =
-        $CommonObject{LanguageObject}->FormatTimeString(
+        $Kernel::OM->Get('Kernel::Language')->FormatTimeString(
         $TimeStamp, 'DateFormat'
         );
 
@@ -270,7 +242,7 @@ if ( $Format eq 'Print' && $CommonObject{PDFObject} ) {
     }
     if ( !$CellData->[0]->[0] ) {
         $CellData->[0]->[0]->{Content} =
-            $CommonObject{LanguageObject}->Get('No Result!');
+            $Kernel::OM->Get('Kernel::Language')->Translate('No Result!');
     }
 
     # page params
@@ -281,7 +253,7 @@ if ( $Format eq 'Print' && $CommonObject{PDFObject} ) {
     $PageParam{MarginBottom}    = 40;
     $PageParam{MarginLeft}      = 40;
     $PageParam{HeaderRight} =
-        $CommonObject{ConfigObject}->Get('Stats::StatsHook')
+        $Kernel::OM->Get('Kernel::Config')->Get('Stats::StatsHook')
         . $Stat->{StatNumber};
     $PageParam{FooterLeft}   = 'otrs.GenerateStats.pl';
     $PageParam{HeadlineLeft} = $Title;
@@ -305,14 +277,14 @@ if ( $Format eq 'Print' && $CommonObject{PDFObject} ) {
     $TableParam{PaddingBottom}       = 3;
 
     # get maximum number of pages
-    my $MaxPages = $CommonObject{ConfigObject}->Get('PDF::MaxPages');
+    my $MaxPages = $Kernel::OM->Get('Kernel::Config')->Get('PDF::MaxPages');
     if ( !$MaxPages || $MaxPages < 1 || $MaxPages > 1000 ) {
         $MaxPages = 100;
     }
 
     # create new pdf document
-    $CommonObject{PDFObject}->DocumentNew(
-        Title  => $CommonObject{ConfigObject}->Get('Product') . ': ' . $Title,
+    $Kernel::OM->Get('Kernel::System::PDF')->DocumentNew(
+        Title  => $Kernel::OM->Get('Kernel::Config')->Get('Product') . ': ' . $Title,
         Encode => 'utf-8',
     );
 
@@ -323,21 +295,21 @@ if ( $Format eq 'Print' && $CommonObject{PDFObject} ) {
 
         # if first page
         if ( $Counter == 1 ) {
-            $CommonObject{PDFObject}->PageNew(
+            $Kernel::OM->Get('Kernel::System::PDF')->PageNew(
                 %PageParam,
                 FooterRight => $Page . ' ' . $Counter,
             );
         }
 
         # output table (or a fragment of it)
-        %TableParam = $CommonObject{PDFObject}->Table( %TableParam, );
+        %TableParam = $Kernel::OM->Get('Kernel::System::PDF')->Table( %TableParam, );
 
         # stop output or another page
         if ( $TableParam{State} ) {
             $Loop = 0;
         }
         else {
-            $CommonObject{PDFObject}->PageNew(
+            $Kernel::OM->Get('Kernel::System::PDF')->PageNew(
                 %PageParam,
                 FooterRight => $Page . ' ' . ( $Counter + 1 ),
             );
@@ -351,7 +323,7 @@ if ( $Format eq 'Print' && $CommonObject{PDFObject} ) {
     }
 
     # return the document
-    my $PDFString = $CommonObject{PDFObject}->DocumentOutput();
+    my $PDFString = $Kernel::OM->Get('Kernel::System::PDF')->DocumentOutput();
 
     # save the pdf with the title and timestamp as filename, or read it from param
     my $Filename;
@@ -359,7 +331,7 @@ if ( $Format eq 'Print' && $CommonObject{PDFObject} ) {
         $Filename = $Opts{F};
     }
     else {
-        $Filename = $CommonObject{StatsObject}->StringAndTimestamp2Filename(
+        $Filename = $Kernel::OM->Get('Kernel::System::Stats')->StringAndTimestamp2Filename(
             String => $Stat->{Title} . " Created",
         );
     }
@@ -371,6 +343,41 @@ if ( $Format eq 'Print' && $CommonObject{PDFObject} ) {
         Disposition => "attachment",
     );
 }
+elsif ( $Format eq 'Excel' ) {
+
+    # Create the Excel data
+    my $Output;
+    warn "creating data";
+
+    # Only add the name if parameter is set
+    if ( $Opts{R} ) {
+        $Output .= "Name: $Title; Created: $Time\n";
+    }
+    $Output .= $Kernel::OM->Get('Kernel::System::CSV')->Array2CSV(
+        Head   => $HeadArrayRef,
+        Data   => \@StatArray,
+        Format => 'Excel',
+    );
+
+    # save the Excel with the title and timestamp as filename, or read it from param
+    my $Filename;
+    if ( $Opts{F} ) {
+        $Filename = $Opts{F};
+    }
+    else {
+        $Filename = $Kernel::OM->Get('Kernel::System::Stats')->StringAndTimestamp2Filename(
+            String => $Stat->{Title} . " Created",
+        );
+    }
+
+    %Attachment = (
+        Filename    => $Filename . ".xlsx",
+        ContentType => "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
+        Content     => $Output,
+        Encoding    => "base64",
+        Disposition => "attachment",
+    );
+}
 else {
 
     # Create the CSV data
@@ -381,7 +388,7 @@ else {
     if ( $Opts{R} ) {
         $Output .= "Name: $Title; Created: $Time\n";
     }
-    $Output .= $CommonObject{CSVObject}->Array2CSV(
+    $Output .= $Kernel::OM->Get('Kernel::System::CSV')->Array2CSV(
         Head      => $HeadArrayRef,
         Data      => \@StatArray,
         Separator => $Separator,
@@ -393,7 +400,7 @@ else {
         $Filename = $Opts{F};
     }
     else {
-        $Filename = $CommonObject{StatsObject}->StringAndTimestamp2Filename(
+        $Filename = $Kernel::OM->Get('Kernel::System::Stats')->StringAndTimestamp2Filename(
             String => $Stat->{Title} . " Created",
         );
     }
@@ -427,16 +434,16 @@ RECIPIENT:
 for my $Recipient ( @{ $Opts{r} } ) {
 
     # recipient check
-    if ( !$CommonObject{CheckItemObject}->CheckEmail( Address => $Recipient ) ) {
+    if ( !$Kernel::OM->Get('Kernel::System::CheckItem')->CheckEmail( Address => $Recipient ) ) {
         print STDERR "Warning: email address $Recipient invalid, skipping address."
-            . $CommonObject{CheckItemObject}->CheckError() . "\n";
+            . $Kernel::OM->Get('Kernel::System::CheckItem')->CheckError() . "\n";
         next RECIPIENT;
     }
-    $CommonObject{EmailObject}->Send(
+    $Kernel::OM->Get('Kernel::System::Email')->Send(
         From       => $Opts{s},
         To         => $Recipient,
         Subject    => "[Stats - $CountStatArray Records] $Title; Created: $Time",
-        Body       => $CommonObject{LanguageObject}->Get( $Opts{m} ),
+        Body       => $Kernel::OM->Get('Kernel::Language')->Translate( $Opts{m} ),
         Charset    => 'utf-8',
         Attachment => [ {%Attachment}, ],
     );
