@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.PackageManager.pl - otrs package manager cmd version
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -30,31 +31,18 @@ use lib dirname($RealBin) . '/Custom';
 use File::Spec;
 use Getopt::Std;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::DB;
-use Kernel::System::Time;
-use Kernel::System::Package;
+use Kernel::System::ObjectManager;
 
-# common objects
-my %CommonObject = ();
-$CommonObject{ConfigObject} = Kernel::Config->new();
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    LogPrefix => 'OTRS-otrs.PackageManager.pl',
-    %CommonObject,
+# create object manager
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-otrs.PackageManager.pl',
+    },
 );
-$CommonObject{MainObject}    = Kernel::System::Main->new(%CommonObject);
-$CommonObject{TimeObject}    = Kernel::System::Time->new(%CommonObject);
-$CommonObject{DBObject}      = Kernel::System::DB->new(%CommonObject);
-$CommonObject{PackageObject} = Kernel::System::Package->new(%CommonObject);
-$CommonObject{CacheObject}   = Kernel::System::Cache->new(%CommonObject);
 
 # get options
 my %Opts;
-getopt( 'hapofdv', \%Opts );
+getopt( 'apodv', \%Opts );
 
 # set defaults
 if ( !$Opts{o} ) {
@@ -79,7 +67,7 @@ if ( $Opts{a} && $Opts{a} eq 'index' ) {
 # check needed params
 if ( $Opts{h} ) {
     print "otrs.PackageManager.pl - OTRS Package Manager\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n";
     print
         "usage: otrs.PackageManager.pl -a list|install|upgrade|uninstall|reinstall|reinstall-all|list-repository|file|build|index \n";
     print
@@ -87,10 +75,9 @@ if ( $Opts{h} ) {
     print " user (local):\n";
     print "   otrs.PackageManager.pl -a list\n";
     print "   otrs.PackageManager.pl -a list -p Package\n";
-    print "   otrs.PackageManager.pl -a list -i (show package deployment information)\n";
+    print "   otrs.PackageManager.pl -a list -i\n";
     print "   otrs.PackageManager.pl -a list -i -p Package\n";
-    print "   otrs.PackageManager.pl -a list -e    (show package verification information)\n";
-    print "   otrs.PackageManager.pl -a list -e -c (show package verification information deleting the cache before)\n";
+    print "   otrs.PackageManager.pl -a listinstalledfiles\n";
     print "   otrs.PackageManager.pl -a install -p /path/to/Package-1.0.0.opm\n";
     print "   otrs.PackageManager.pl -a upgrade -p /path/to/Package-1.0.1.opm\n";
     print "   otrs.PackageManager.pl -a reinstall -p Package\n";
@@ -120,7 +107,7 @@ if ( $Opts{h} ) {
 my $FileString = '';
 if ( $Opts{a} !~ /^(list|file)/ && $Opts{p} ) {
     if ( -e $Opts{p} ) {
-        my $ContentRef = $CommonObject{MainObject}->FileRead(
+        my $ContentRef = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
             Location => $Opts{p},
             Mode     => 'utf8',      # optional - binmode|utf8
             Result   => 'SCALAR',    # optional - SCALAR|ARRAY
@@ -136,8 +123,11 @@ if ( $Opts{a} !~ /^(list|file)/ && $Opts{p} ) {
         my $URL         = $1;
         my $PackageName = $2;
         if ( $URL eq 'online' ) {
-            my %List = %{ $CommonObject{ConfigObject}->Get('Package::RepositoryList') };
-            %List = ( %List, $CommonObject{PackageObject}->PackageOnlineRepositories() );
+            my %List = %{ $Kernel::OM->Get('Kernel::Config')->Get('Package::RepositoryList') };
+            %List = (
+                %List,
+                $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineRepositories()
+            );
             for ( sort keys %List ) {
                 if ( $List{$_} =~ /^\[-Master-\]/ ) {
                     $URL = $_;
@@ -145,18 +135,19 @@ if ( $Opts{a} !~ /^(list|file)/ && $Opts{p} ) {
             }
         }
         if ( $PackageName !~ /^.+?.opm$/ ) {
-            my @Packages = $CommonObject{PackageObject}->PackageOnlineList(
+            my @Packages = $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineList(
                 URL  => $URL,
-                Lang => $CommonObject{ConfigObject}->Get('DefaultLanguage'),
+                Lang => $Kernel::OM->Get('Kernel::Config')->Get('DefaultLanguage'),
             );
+            PACKAGE:
             for my $Package (@Packages) {
                 if ( $Package->{Name} eq $PackageName ) {
                     $PackageName = $Package->{File};
-                    last;
+                    last PACKAGE;
                 }
             }
         }
-        $FileString = $CommonObject{PackageObject}->PackageOnlineGet(
+        $FileString = $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineGet(
             Source => $URL,
             File   => $PackageName,
         );
@@ -166,19 +157,20 @@ if ( $Opts{a} !~ /^(list|file)/ && $Opts{p} ) {
     }
     else {
         if ( $Opts{p} =~ /^(.*)\-(\d{1,4}\.\d{1,4}\.\d{1,4})$/ ) {
-            $FileString = $CommonObject{PackageObject}->RepositoryGet(
+            $FileString = $Kernel::OM->Get('Kernel::System::Package')->RepositoryGet(
                 Name    => $1,
                 Version => $2,
             );
         }
         else {
-            for my $Package ( $CommonObject{PackageObject}->RepositoryList() ) {
+            PACKAGE:
+            for my $Package ( $Kernel::OM->Get('Kernel::System::Package')->RepositoryList() ) {
                 if ( $Opts{p} eq $Package->{Name}->{Content} ) {
-                    $FileString = $CommonObject{PackageObject}->RepositoryGet(
+                    $FileString = $Kernel::OM->Get('Kernel::System::Package')->RepositoryGet(
                         Name    => $Package->{Name}->{Content},
                         Version => $Package->{Version}->{Content},
                     );
-                    last;
+                    last PACKAGE;
                 }
             }
         }
@@ -192,7 +184,17 @@ if ( $Opts{a} !~ /^(list|file)/ && $Opts{p} ) {
 if ( $Opts{a} eq 'file' ) {
     $Opts{p} =~ s/\/\//\//g;
     my $Hit = 0;
-    for my $Package ( $CommonObject{PackageObject}->RepositoryList() ) {
+    PACKAGE:
+    for my $Package ( $Kernel::OM->Get('Kernel::System::Package')->RepositoryList() ) {
+
+        # just shown in list if PackageIsVisible flag is enable
+        if (
+            defined $Package->{PackageIsVisible}
+            && !$Package->{PackageIsVisible}->{Content}
+            )
+        {
+            next PACKAGE;
+        }
         for my $File ( @{ $Package->{Filelist} } ) {
             if ( $Opts{p} =~ /^\Q$File->{Location}\E$/ ) {
                 print
@@ -225,7 +227,7 @@ if ( $Opts{a} eq 'exportfile' ) {
 
     # read package
     if ( -e $Opts{p} ) {
-        my $ContentRef = $CommonObject{MainObject}->FileRead(
+        my $ContentRef = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
             Location => $Opts{p},
             Mode     => 'utf8',      # optional - binmode|utf8
             Result   => 'SCALAR',    # optional - SCALAR|ARRAY
@@ -249,13 +251,27 @@ if ( $Opts{a} eq 'exportfile' ) {
         exit 1;
     }
 
+    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
+        String => $String,
+    );
+
+    # just export files if PackageIsDownloadable flag is enable
+    if (
+        defined $Structure{PackageIsDownloadable}
+        && !$Structure{PackageIsDownloadable}->{Content}
+        )
+    {
+        print STDERR "ERROR: Not possible to export files!\n";
+        exit 1;
+    }
+
     # export it
     print "+----------------------------------------------------------------------------+\n";
     print "| Export files of:\n";
     print "| Package: $Opts{p}\n";
     print "| To:      $Opts{d}\n";
     print "+----------------------------------------------------------------------------+\n";
-    $CommonObject{PackageObject}->PackageExport(
+    $Kernel::OM->Get('Kernel::System::Package')->PackageExport(
         String => $String,
         Home   => $Opts{d},
     );
@@ -264,9 +280,20 @@ if ( $Opts{a} eq 'exportfile' ) {
 
 # build
 if ( $Opts{a} eq 'build' ) {
-    my %Structure = $CommonObject{PackageObject}->PackageParse(
+    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
         String => $FileString,
     );
+
+    # just build it if PackageIsDownloadable flag is enable
+    if (
+        defined $Structure{PackageIsDownloadable}
+        && !$Structure{PackageIsDownloadable}->{Content}
+        )
+    {
+        print STDERR "ERROR: Not available package!\n";
+        exit 1;
+    }
+
     if ( $Opts{v} && $Opts{v} =~ m/\d{1,4}\.\d{1,4}\.\d{1,4}/ ) {
         $Structure{Version}->{Content} = $Opts{v}
     }
@@ -290,8 +317,8 @@ if ( $Opts{a} eq 'build' ) {
     }
 
     my $Filename = $Structure{Name}->{Content} . '-' . $Structure{Version}->{Content} . '.opm';
-    my $Content  = $CommonObject{PackageObject}->PackageBuild(%Structure);
-    my $File     = $CommonObject{MainObject}->FileWrite(
+    my $Content  = $Kernel::OM->Get('Kernel::System::Package')->PackageBuild(%Structure);
+    my $File     = $Kernel::OM->Get('Kernel::System::Main')->FileWrite(
         Location   => $Opts{o} . '/' . $Filename,
         Content    => \$Content,
         Mode       => 'utf8',                       # binmode|utf8
@@ -311,10 +338,30 @@ elsif ( $Opts{a} eq 'uninstall' ) {
 
     # get package file from db
     # parse package
-    my %Structure = $CommonObject{PackageObject}->PackageParse(
+    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
         String => $FileString,
     );
 
+    # just un-install it if PackageIsRemovable flag is enable
+    if (
+        defined $Structure{PackageIsRemovable}
+        && !$Structure{PackageIsRemovable}->{Content}
+        )
+    {
+        my $ExitMessage = "ERROR: Not possible to remove this package!\n";
+
+        # exchange message if package should not be visible
+        if (
+            defined $Structure{PackageIsVisible}
+            && !$Structure{PackageIsVisible}->{Content}
+            )
+        {
+            $ExitMessage = "ERROR: No such package!\n";
+        }
+        print STDERR $ExitMessage;
+        exit 1;
+    }
+
     # intro screen
     if ( $Structure{IntroUninstallPre} ) {
         my %Data = _MessageGet( Info => $Structure{IntroUninstallPre} );
@@ -326,7 +373,7 @@ elsif ( $Opts{a} eq 'uninstall' ) {
     }
 
     # uninstall
-    $CommonObject{PackageObject}->PackageUninstall(
+    $Kernel::OM->Get('Kernel::System::Package')->PackageUninstall(
         String => $FileString,
         Force  => $Opts{f},
     );
@@ -345,7 +392,7 @@ elsif ( $Opts{a} eq 'uninstall' ) {
 elsif ( $Opts{a} eq 'install' ) {
 
     # parse package
-    my %Structure = $CommonObject{PackageObject}->PackageParse(
+    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
         String => $FileString,
     );
 
@@ -360,7 +407,7 @@ elsif ( $Opts{a} eq 'install' ) {
     }
 
     # install
-    my $Success = $CommonObject{PackageObject}->PackageInstall(
+    $Kernel::OM->Get('Kernel::System::Package')->PackageInstall(
         String => $FileString,
         Force  => $Opts{f},
     );
@@ -374,16 +421,12 @@ elsif ( $Opts{a} eq 'install' ) {
         print "$Data{Description}";
         print "+----------------------------------------------------------------------------+\n";
     }
-
-    # Set the correct exit code.
-    my $ExitCode = $Success ? 0 : 1;
-
-    exit $ExitCode;
+    exit;
 }
 elsif ( $Opts{a} eq 'reinstall' ) {
 
     # parse package
-    my %Structure = $CommonObject{PackageObject}->PackageParse(
+    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
         String => $FileString,
     );
 
@@ -398,7 +441,7 @@ elsif ( $Opts{a} eq 'reinstall' ) {
     }
 
     # install
-    $CommonObject{PackageObject}->PackageReinstall(
+    $Kernel::OM->Get('Kernel::System::Package')->PackageReinstall(
         String => $FileString,
         Force  => $Opts{f},
     );
@@ -419,10 +462,10 @@ elsif ( $Opts{a} eq 'reinstall-all' ) {
     my @ReinstalledPackages;
 
     # loop all locally installed packages
-    for my $Package ( $CommonObject{PackageObject}->RepositoryList() ) {
+    for my $Package ( $Kernel::OM->Get('Kernel::System::Package')->RepositoryList() ) {
 
         # do a deploy check to see if reinstallation is needed
-        my $ReinstallNeeded = $CommonObject{PackageObject}->DeployCheck(
+        my $ReinstallNeeded = $Kernel::OM->Get('Kernel::System::Package')->DeployCheck(
             Name    => $Package->{Name}->{Content},
             Version => $Package->{Version}->{Content},
         );
@@ -431,12 +474,12 @@ elsif ( $Opts{a} eq 'reinstall-all' ) {
 
             push @ReinstalledPackages, $Package->{Name}->{Content};
 
-            my $FileString = $CommonObject{PackageObject}->RepositoryGet(
+            my $FileString = $Kernel::OM->Get('Kernel::System::Package')->RepositoryGet(
                 Name    => $Package->{Name}->{Content},
                 Version => $Package->{Version}->{Content},
             );
 
-            $CommonObject{PackageObject}->PackageReinstall(
+            $Kernel::OM->Get('Kernel::System::Package')->PackageReinstall(
                 String => $FileString,
                 Force  => $Opts{f},
             );
@@ -459,7 +502,7 @@ elsif ( $Opts{a} eq 'reinstall-all' ) {
 elsif ( $Opts{a} eq 'upgrade' ) {
 
     # parse package
-    my %Structure = $CommonObject{PackageObject}->PackageParse(
+    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
         String => $FileString,
     );
 
@@ -474,7 +517,7 @@ elsif ( $Opts{a} eq 'upgrade' ) {
     }
 
     # upgrade
-    $CommonObject{PackageObject}->PackageUpgrade(
+    $Kernel::OM->Get('Kernel::System::Package')->PackageUpgrade(
         String => $FileString,
         Force  => $Opts{f},
     );
@@ -492,10 +535,17 @@ elsif ( $Opts{a} eq 'upgrade' ) {
 }
 elsif ( $Opts{a} eq 'list' ) {
 
-    my %VerificationInfo;
-
     PACKAGE:
-    for my $Package ( $CommonObject{PackageObject}->RepositoryList() ) {
+    for my $Package ( $Kernel::OM->Get('Kernel::System::Package')->RepositoryList() ) {
+
+        # just shown in list if PackageIsVisible flag is enable
+        if (
+            defined $Package->{PackageIsVisible}
+            && !$Package->{PackageIsVisible}->{Content}
+            )
+        {
+            next PACKAGE;
+        }
 
         if ( defined $Opts{p} && length $Opts{p} ) {
             my $PackageString = $Package->{Name}->{Content} . '-' . $Package->{Version}->{Content};
@@ -515,14 +565,15 @@ elsif ( $Opts{a} eq 'list' ) {
         print "| Description: $Data{Description}\n";
 
         if ( defined $Opts{i} ) {
-            my $PackageDeploymentOK = $CommonObject{PackageObject}->DeployCheck(
+
+            my $PackageDeploymentOK = $Kernel::OM->Get('Kernel::System::Package')->DeployCheck(
                 Name    => $Package->{Name}->{Content},
                 Version => $Package->{Version}->{Content},
                 Log     => 0,
             );
             print '| Deployment:  ' . ( $PackageDeploymentOK ? 'OK' : 'Not OK' ) . "\n";
 
-            my %PackageDeploymentInfo = $CommonObject{PackageObject}->DeployCheckInfo();
+            my %PackageDeploymentInfo = $Kernel::OM->Get('Kernel::System::Package')->DeployCheckInfo();
             if ( defined $PackageDeploymentInfo{File} && %{ $PackageDeploymentInfo{File} } ) {
                 for my $File ( sort keys %{ $PackageDeploymentInfo{File} } ) {
                     my $FileMessage = $PackageDeploymentInfo{File}->{$File};
@@ -530,39 +581,38 @@ elsif ( $Opts{a} eq 'list' ) {
                 }
             }
         }
-
-        if ( defined $Opts{e} ) {
-
-            if ( !%VerificationInfo ) {
-
-                # clear the package verification cache to get fresh results
-                if ( $Opts{c} ) {
-                    $CommonObject{CacheObject}->CleanUp(
-                        Type => 'PackageVerification',
-                    );
-                }
-
-                # get verification info for all packages (this will create the cache again)
-                %VerificationInfo = $CommonObject{PackageObject}->PackageVerifyAll();
-            }
-
-            my $VerifyString = ( $VerificationInfo{ $Package->{Name}->{Content} } // 'unknown' ) eq 'verified'
-                ? 'Verified'
-                : 'Not Verified';
-
-            print "| OTRS Verify: $VerifyString\n";
-        }
     }
     print "+----------------------------------------------------------------------------+\n";
     exit;
 }
+elsif ( $Opts{a} eq 'listinstalledfiles' ) {
+    my @Packages = $Kernel::OM->Get('Kernel::System::Package')->RepositoryList();
+
+    PACKAGE:
+    for my $Package (@Packages) {
+
+        # Just show if PackageIsVisible flag is enabled.
+        if (
+            defined $Package->{PackageIsVisible}
+            && !$Package->{PackageIsVisible}->{Content}
+            )
+        {
+            next PACKAGE;
+        }
+
+        for my $File ( @{ $Package->{Filelist} } ) {
+            print "  $Package->{Name}->{Content}: $File->{Location}\n";
+        }
+    }
+    exit;
+}
 elsif ( $Opts{a} eq 'list-repository' ) {
     my $Count = 0;
-    my %List  = ();
-    if ( $CommonObject{ConfigObject}->Get('Package::RepositoryList') ) {
-        %List = %{ $CommonObject{ConfigObject}->Get('Package::RepositoryList') };
+    my %List;
+    if ( $Kernel::OM->Get('Kernel::Config')->Get('Package::RepositoryList') ) {
+        %List = %{ $Kernel::OM->Get('Kernel::Config')->Get('Package::RepositoryList') };
     }
-    %List = ( %List, $CommonObject{PackageObject}->PackageOnlineRepositories() );
+    %List = ( %List, $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineRepositories() );
     for my $URL ( sort { $List{$a} cmp $List{$b} } keys %List ) {
         $Count++;
         print "+----------------------------------------------------------------------------+\n";
@@ -583,12 +633,22 @@ elsif ( $Opts{a} eq 'list-repository' ) {
             print
                 "+----------------------------------------------------------------------------+\n";
             print "| Package Overview:\n";
-            my @Packages = $CommonObject{PackageObject}->PackageOnlineList(
+            my @Packages = $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineList(
                 URL  => $URL,
-                Lang => $CommonObject{ConfigObject}->Get('DefaultLanguage'),
+                Lang => $Kernel::OM->Get('Kernel::Config')->Get('DefaultLanguage'),
             );
             my $Count = 0;
+            PACKAGE:
             for my $Package (@Packages) {
+
+                # just shown in list if PackageIsVisible flag is enable
+                if (
+                    defined $Package->{PackageIsVisible}
+                    && !$Package->{PackageIsVisible}->{Content}
+                    )
+                {
+                    next PACKAGE;
+                }
                 $Count++;
                 print
                     "+----------------------------------------------------------------------------+\n";
@@ -609,11 +669,11 @@ elsif ( $Opts{a} eq 'list-repository' ) {
             for my $Package (@Packages) {
                 $Count++;
                 if ( $Count eq $PackageCount ) {
-                    my $FileString = $CommonObject{PackageObject}->PackageOnlineGet(
+                    my $FileString = $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineGet(
                         Source => $URL,
                         File   => $Package->{File},
                     );
-                    $CommonObject{PackageObject}->PackageInstall(
+                    $Kernel::OM->Get('Kernel::System::Package')->PackageInstall(
                         String => $FileString,
                         Force  => $Opts{'f'},
                     );
@@ -624,17 +684,59 @@ elsif ( $Opts{a} eq 'list-repository' ) {
     exit;
 }
 elsif ( $Opts{a} eq 'p' ) {
-    my @Data = $CommonObject{PackageObject}->PackageParse(
+
+    # parse package
+    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
         String => $FileString,
     );
-    for my $Tag (@Data) {
-        print STDERR "Tag: $Tag->{Type} $Tag->{Tag} $Tag->{Content}\n";
+
+    # perform parsing only if PackageIsVisible flag is enable
+    if (
+        defined $Structure{PackageIsVisible}
+        && !$Structure{PackageIsVisible}->{Content}
+        )
+    {
+        print STDERR "ERROR: no such package $Opts{p}!\n";
+        exit 1;
     }
+
+    my @Data = keys %Structure;
+    for my $Tag (@Data) {
+        if ( ref $Structure{$Tag} eq 'HASH' ) {
+            print STDERR "Tag: $Structure{$Tag}->{TagType} - $Structure{$Tag}->{Tag} $Structure{$Tag}->{Content}\n";
+        }
+        elsif ( ref $Structure{$Tag} eq 'ARRAY' ) {
+
+            # add a sub-level reference
+            print STDERR "\n--- Open Sub-Tag: $Tag ---\n";
+
+            # loop over the second level tags
+            my @SubData = @{ $Structure{$Tag} };
+            for my $SubTag (@SubData) {
+                print STDERR "Tag: $SubTag->{TagType} $SubTag->{Tag} $SubTag->{Content}\n";
+            }
+
+            # add a sub-level reference
+            print STDERR "--- Close Sub-Tag: $Tag ---\n\n";
+        }
+    }
+
 }
 elsif ( $Opts{a} eq 'parse' ) {
-    my %Structure = $CommonObject{PackageObject}->PackageParse(
+    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
         String => $FileString,
     );
+
+    # perform parsing only if PackageIsVisible flag is enable
+    if (
+        defined $Structure{PackageIsVisible}
+        && !$Structure{PackageIsVisible}->{Content}
+        )
+    {
+        print STDERR "ERROR: no such package $Opts{p}!\n";
+        exit 1;
+    }
+
     for my $Key ( sort keys %Structure ) {
         if ( ref( $Structure{$Key} ) eq 'ARRAY' ) {
             for my $Data ( @{ $Structure{$Key} } ) {
@@ -666,7 +768,7 @@ elsif ( $Opts{a} eq 'index' ) {
     elsif ( !-d $Opts{d} ) {
         die "ERROR: invalid package root location '$Opts{d}'";
     }
-    my @Dirs = ();
+    my @Dirs;
     print "<?xml version=\"1.0\" encoding=\"utf-8\" ?>\n";
     print "<otrs_package_list version=\"1.0\">\n";
     BuildPackageIndex( $Opts{d} );
@@ -680,7 +782,7 @@ else {
 sub BuildPackageIndex {
     my $In = shift;
 
-    my @List = $CommonObject{MainObject}->DirectoryRead(
+    my @List = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
         Directory => $In,
         Filter    => '*',
     );
@@ -690,19 +792,19 @@ sub BuildPackageIndex {
             BuildPackageIndex($File);
             $File =~ s/$Opts{d}//;
 
-            #            print "Directory: $File\n";
+            # print "Directory: $File\n";
         }
         else {
             my $OrigFile = $File;
             $File =~ s/$Opts{d}//;
 
-            #               print "File: $File\n";
-            #               my $Dir =~ s/^(.*)\//$1/;
+            # print "File: $File\n";
+            # my $Dir =~ s/^(.*)\//$1/;
             if ( $File !~ /Entries|Repository|Root|CVS/ && $File =~ /\.opm$/ ) {
 
-                #               print "F: $File\n";
+                # print "F: $File\n";
                 my $Content    = '';
-                my $ContentRef = $CommonObject{MainObject}->FileRead(
+                my $ContentRef = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
                     Location => $OrigFile,
                     Mode     => 'utf8',      # optional - binmode|utf8
                     Result   => 'SCALAR',    # optional - SCALAR|ARRAY
@@ -711,8 +813,8 @@ sub BuildPackageIndex {
                     print STDERR "ERROR: Can't open $OrigFile: $!\n";
                     exit 1;
                 }
-                my %Structure = $CommonObject{PackageObject}->PackageParse( String => ${$ContentRef} );
-                my $XML = $CommonObject{PackageObject}->PackageBuild( %Structure, Type => 'Index' );
+                my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse( String => ${$ContentRef} );
+                my $XML = $Kernel::OM->Get('Kernel::System::Package')->PackageBuild( %Structure, Type => 'Index' );
                 print "<Package>\n";
                 print $XML;
                 print "  <File>$File</File>\n";
