@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.PostMasterDaemon.pl - the daemon for the PostMasterClient.pl client
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -29,12 +30,7 @@ use lib dirname($RealBin) . '/Custom';
 
 my $Debug = 1;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Time;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::DB;
+use Kernel::System::ObjectManager;
 use Kernel::System::PostMaster;
 
 use IO::Socket;
@@ -45,7 +41,7 @@ my $MaxConnects     = 30;
 $SIG{CHLD} = \&StopChild;
 
 my $Children = 0;
-my %Children = ();
+my %Children;
 
 my $Server = IO::Socket::INET->new(
     LocalPort => 5555,
@@ -81,8 +77,8 @@ sub MakeNewChild {
         while ( my $Client = $Server->accept() ) {
             $MaxConnectsCount++;
             print $Client "* --OK-- ($PID/$$)\n";
-            my @Input = ();
-            my $Data  = 0;
+            my @Input;
+            my $Data = 0;
             while ( my $Line = <$Client> ) {
                 if ( $Line =~ /^\* --END EMAIL--$/ ) {
                     $Data = 0;
@@ -124,40 +120,36 @@ sub StopChild {
 sub PipeEmail {
     my (@Email) = @_;
 
-    # create common objects
-    my %CommonObject = ();
-    $CommonObject{ConfigObject} = Kernel::Config->new();
-    $CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-    $CommonObject{TimeObject}   = Kernel::System::Time->new(%CommonObject);
-    $CommonObject{LogObject}    = Kernel::System::Log->new(
-        LogPrefix => 'OTRS-otrs.PostMasterDaemon.pl',
-        %CommonObject,
+    # create object manager
+    local $Kernel::OM = Kernel::System::ObjectManager->new(
+        'Kernel::System::Log' => {
+            LogPrefix => 'OTRS-otrs.PostMasterDaemon.pl',
+        },
     );
-    $CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
-    $CommonObject{DBObject}   = Kernel::System::DB->new(%CommonObject);
 
     # debug info
     if ($Debug) {
-        $CommonObject{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'debug',
             Message  => 'Email handle (PostMasterDaemon.pl) started...',
         );
     }
 
-    # ... common objects ...
-    $CommonObject{PostMaster} = Kernel::System::PostMaster->new( %CommonObject, Email => \@Email );
-    my @Return = $CommonObject{PostMaster}->Run();
+    my $PostMasterObject = Kernel::System::PostMaster->new(
+        Email => \@Email
+    );
+    my @Return = $PostMasterObject->Run();
     if ( !$Return[0] ) {
-        $CommonObject{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't process mail, see log sub system!",
         );
     }
-    undef $CommonObject{PostMaster};
+    undef $PostMasterObject;
 
     # debug info
     if ($Debug) {
-        $CommonObject{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'debug',
             Message  => 'Email handle (PostMasterDaemon.pl) stopped.',
         );
