@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.PostMasterMailbox.pl - the global eMail handle for email2db
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -29,22 +30,15 @@ use lib dirname($RealBin) . '/Custom';
 
 use Getopt::Std;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::Time;
-use Kernel::System::DB;
-use Kernel::System::PID;
-use Kernel::System::PostMaster;
 use Kernel::System::MailAccount;
+use Kernel::System::ObjectManager;
 
 # get options
-my %Opts = ();
-getopt( 'upshdftb', \%Opts );
+my %Opts;
+getopt( 'upsdtb', \%Opts );
 if ( $Opts{h} ) {
     print "PostMasterMailbox.pl - Fetch mail accounts for OTRS\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n";
     print "usage: PostMasterMailbox.pl -t <TYPE> (POP3|POP3S|IMAP|IMAPS) -s <SERVER> -u <USER> ";
     print "-p <PASSWORD> [-d 1-2] [-b <BACKGROUND_INTERVAL_IN_MIN>] [-f force]\n";
     exit 1;
@@ -62,32 +56,34 @@ if ( $Opts{b} && $Opts{b} !~ /^\d+$/ ) {
     exit 1;
 }
 
-# create common objects
-my %CommonObject = ();
-$CommonObject{ConfigObject} = Kernel::Config->new();
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    LogPrefix => 'OTRS-otrs.PostMasterMailbox.pl',
-    %CommonObject,
+# create object manager
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-otrs.PostMasterMailbox.pl',
+    },
 );
-$CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
-$CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
-$CommonObject{DBObject}   = Kernel::System::DB->new(%CommonObject);
-$CommonObject{PIDObject}  = Kernel::System::PID->new(%CommonObject);
 
 # create pid lock
-if ( !$Opts{f} && !$CommonObject{PIDObject}->PIDCreate( Name => 'PostMasterMailbox' ) ) {
+if (
+    !$Opts{f}
+    && !$Kernel::OM->Get('Kernel::System::PID')->PIDCreate( Name => 'PostMasterMailbox' )
+    )
+{
     print "NOTICE: PostMasterMailbox.pl is already running (use '-f 1' if you want to start it ";
     print "forced)!\n";
     exit 1;
 }
-elsif ( $Opts{f} && !$CommonObject{PIDObject}->PIDCreate( Name => 'PostMasterMailbox' ) ) {
+elsif (
+    $Opts{f}
+    && !$Kernel::OM->Get('Kernel::System::PID')->PIDCreate( Name => 'PostMasterMailbox' )
+    )
+{
     print "NOTICE: PostMasterMailbox.pl is already running but is starting again!\n";
 }
 
 # fetch mails -b is not used
 if ( !$Opts{b} ) {
-    Fetch(%CommonObject);
+    Fetch();
 }
 
 # while to run several times if -b is used
@@ -95,13 +91,13 @@ else {
     while (1) {
 
         # set new PID
-        $CommonObject{PIDObject}->PIDCreate(
+        $Kernel::OM->Get('Kernel::System::PID')->PIDCreate(
             Name  => 'PostMasterMailbox',
             Force => 1,
         );
 
         # fetch mails
-        Fetch(%CommonObject);
+        Fetch();
 
         # sleep till next interval
         print "NOTICE: Waiting for next interval ($Opts{b} min)...\n";
@@ -110,18 +106,17 @@ else {
 }
 
 # delete pid lock
-$CommonObject{PIDObject}->PIDDelete( Name => 'PostMasterMailbox' );
+$Kernel::OM->Get('Kernel::System::PID')->PIDDelete( Name => 'PostMasterMailbox' );
 exit(0);
 
 sub Fetch {
-    my (%CommonObject) = @_;
 
-    my $MailAccount = Kernel::System::MailAccount->new(%CommonObject);
+    my $MailAccount = Kernel::System::MailAccount->new();
 
     # debug info
 
     if ( $Opts{d} > 1 ) {
-        $CommonObject{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'debug',
             Message  => 'Global OTRS email handle (PostMasterMailbox.pl) started...',
         );
@@ -131,28 +126,28 @@ sub Fetch {
         if ( !$Opts{t} ) {
 
             # delete pid lock
-            $CommonObject{PIDObject}->PIDDelete( Name => 'PostMasterMailbox' );
+            $Kernel::OM->Get('Kernel::System::PID')->PIDDelete( Name => 'PostMasterMailbox' );
             print STDERR "ERROR: Need -t <TYPE> (POP3|IMAP)\n";
             exit 1;
         }
         if ( !$Opts{s} ) {
 
             # delete pid lock
-            $CommonObject{PIDObject}->PIDDelete( Name => 'PostMasterMailbox' );
+            $Kernel::OM->Get('Kernel::System::PID')->PIDDelete( Name => 'PostMasterMailbox' );
             print STDERR "ERROR: Need -s <SERVER>\n";
             exit 1;
         }
         if ( !$Opts{u} ) {
 
             # delete pid lock
-            $CommonObject{PIDObject}->PIDDelete( Name => 'PostMasterMailbox' );
+            $Kernel::OM->Get('Kernel::System::PID')->PIDDelete( Name => 'PostMasterMailbox' );
             print STDERR "ERROR: Need -u <USER>\n";
             exit 1;
         }
         if ( !$Opts{p} ) {
 
             # delete pid lock
-            $CommonObject{PIDObject}->PIDDelete( Name => 'PostMasterMailbox' );
+            $Kernel::OM->Get('Kernel::System::PID')->PIDDelete( Name => 'PostMasterMailbox' );
             print STDERR "ERROR: Need -p <PASSWORD>\n";
             exit 1;
         }
@@ -184,7 +179,7 @@ sub Fetch {
 
     # debug info
     if ( $Opts{d} > 1 ) {
-        $CommonObject{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'debug',
             Message  => 'Global OTRS email handle (PostMasterMailbox.pl) stopped.',
         );
