@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.SetPassword.pl - Changes or Sets password for a user
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -29,26 +30,15 @@ use lib dirname($RealBin) . '/Custom';
 
 use Getopt::Long;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Log;
-use Kernel::System::DB;
-use Kernel::System::CustomerUser;
-use Kernel::System::User;
-use Kernel::System::Main;
-use Kernel::System::Time;
+use Kernel::System::ObjectManager;
 
-# create common objects
-my %CommonObject = ();
-$CommonObject{ConfigObject} = Kernel::Config->new(%CommonObject);
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    %CommonObject,
-    LogPrefix => 'OTRS-otrs.SetPassword.pl',
+# create object manager
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-otrs.SetPassword.pl',
+    },
 );
-$CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
-$CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
-$CommonObject{DBObject}   = Kernel::System::DB->new(%CommonObject);
+my $AccountObject;
 
 my %Options;
 GetOptions(
@@ -71,14 +61,14 @@ my %AccountList;
 # define which object we need to operate on, default to UserObject
 # search if login exists
 if ( $Type eq 'customer' ) {
-    $CommonObject{AccountObject} = Kernel::System::CustomerUser->new(%CommonObject);
-    %AccountList = $CommonObject{AccountObject}->CustomerSearch(
+    $AccountObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
+    %AccountList   = $AccountObject->CustomerSearch(
         UserLogin => $Login,
     );
 }
 else {
-    $CommonObject{AccountObject} = Kernel::System::User->new(%CommonObject);
-    %AccountList = $CommonObject{AccountObject}->UserSearch(
+    $AccountObject = $Kernel::OM->Get('Kernel::System::User');
+    %AccountList   = $AccountObject->UserSearch(
         UserLogin => $Login,
     );
 }
@@ -91,11 +81,11 @@ if ( !scalar %AccountList ) {
 
 # if no password has been provided, generate one
 if ( !$Pw ) {
-    $Pw = $CommonObject{AccountObject}->GenerateRandomPassword( Size => 12 );
+    $Pw = $AccountObject->GenerateRandomPassword( Size => 12 );
     print "Generated password '$Pw'\n";
 }
 
-my $Result = $CommonObject{AccountObject}->SetPassword(
+my $Result = $AccountObject->SetPassword(
     UserLogin => $Login,
     PW        => $Pw,
 );
@@ -113,7 +103,7 @@ sub Usage {
 
     print "\n";
     print "$0 - set a new password\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n";
     print "Usage: otrs.SetPassword [--customer | --agent] user [password]\n";
     print "\n";
     print "\tIf you do not specify --customer, --agent is assumed.\n";
