@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.WebserviceConfig.pl - script to read/write/list webservice config
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -28,22 +29,14 @@ use lib dirname($RealBin) . '/Kernel/cpan-lib';
 use lib dirname($RealBin) . '/Custom';
 
 use Getopt::Std;
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::Time;
-use Kernel::System::DB;
-use Kernel::System::GenericInterface::Webservice;
-
-use Kernel::System::YAML;
+use Kernel::System::ObjectManager;
 
 # get options
 my %Opts;
-getopt( 'hiafn', \%Opts );
+getopt( 'iafn', \%Opts );
 if ( $Opts{h} ) {
     print "otrs.WebserviceConfig.pl - read/write/list webservice config\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n";
     print
         "usage: otrs.WebserviceConfig.pl -a read  -i \$ID                         (read config, print to STDOUT)\n";
     print
@@ -57,22 +50,12 @@ if ( $Opts{h} ) {
     exit 1;
 }
 
-# create common objects
-my %CommonObject;
-
-$CommonObject{ConfigObject} = Kernel::Config->new();
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    LogPrefix => 'OTRS-otrs.WebserviceConfig.pl',
-    %CommonObject,
+# create object manager
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-otrs.WebserviceConfig.pl',
+    },
 );
-$CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
-$CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
-$CommonObject{DBObject}   = Kernel::System::DB->new(%CommonObject);
-
-# create needed objects
-$CommonObject{WebserviceObject} = Kernel::System::GenericInterface::Webservice->new(%CommonObject);
-$CommonObject{YAMLObject}       = Kernel::System::YAML->new(%CommonObject);
 
 # validate -a param
 if ( !$Opts{a} ) {
@@ -87,7 +70,7 @@ if ( lc( $Opts{a} ) !~ /^(read|write|list|delete)$/ ) {
 # list webservices
 if ( lc( $Opts{a} ) eq 'list' ) {
     print "List Config: (ID:Name)\n";
-    my $List = $CommonObject{WebserviceObject}->WebserviceList();
+    my $List = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice')->WebserviceList();
     for my $ID ( sort keys %{$List} ) {
         print "$ID:$List->{$ID}\n";
     }
@@ -108,14 +91,14 @@ if ( lc( $Opts{a} ) eq 'write' ) {
     }
 
     # read config
-    my $Content = $CommonObject{MainObject}->FileRead(
+    my $Content = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
         Location => $Opts{f},
     );
     if ( !$Content ) {
         print STDERR "ERROR: No content in file (-f '$Opts{f}')!\n";
         exit 1;
     }
-    my $Config = $CommonObject{YAMLObject}->Load( Data => ${$Content} );
+    my $Config = $Kernel::OM->Get('Kernel::System::YAML')->Load( Data => ${$Content} );
 
     if ( !$Config ) {
         print STDERR "ERROR: Unable to read config file: $! (-f '$Opts{f}')!\n";
@@ -124,19 +107,20 @@ if ( lc( $Opts{a} ) eq 'write' ) {
 
     # webservice lookup
     if ( $Opts{i} ) {
-        my $List = $CommonObject{WebserviceObject}->WebserviceList();
+        my $List = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice')->WebserviceList();
         if ( !$List->{ $Opts{i} } ) {
             print STDERR "ERROR: No such webservice with id (-i '$Opts{i}')!\n";
             exit 1;
         }
-        my $Webservice = $CommonObject{WebserviceObject}->WebserviceGet( ID => $Opts{i} );
+        my $Webservice
+            = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice')->WebserviceGet( ID => $Opts{i} );
         if ( !$Webservice ) {
             print STDERR "ERROR: No such webservice with id (-i '$Opts{i}')!\n";
             exit 1;
         }
 
         # update webservice
-        my $Success = $CommonObject{WebserviceObject}->WebserviceUpdate(
+        my $Success = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice')->WebserviceUpdate(
             ID      => $Webservice->{ID},
             Name    => $Webservice->{Name},
             Config  => $Config,
@@ -152,7 +136,7 @@ if ( lc( $Opts{a} ) eq 'write' ) {
     }
 
     # webservice add
-    my $ID = $CommonObject{WebserviceObject}->WebserviceAdd(
+    my $ID = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice')->WebserviceAdd(
         Name    => $Opts{n},
         Config  => $Config,
         ValidID => 1,
@@ -176,21 +160,21 @@ if ( lc( $Opts{a} ) eq 'read' ) {
     }
 
     # webservice lookup
-    my $List = $CommonObject{WebserviceObject}->WebserviceList();
+    my $List = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice')->WebserviceList();
     if ( !$List->{ $Opts{i} } ) {
         print STDERR "ERROR: No such webservice with id (-i '$Opts{i}')!\n";
         exit 1;
     }
 
     # get webservice
-    my $Webservice = $CommonObject{WebserviceObject}->WebserviceGet( ID => $Opts{i} );
+    my $Webservice = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice')->WebserviceGet( ID => $Opts{i} );
     if ( !$Webservice ) {
         print STDERR "ERROR: No such webservice with id (-i '$Opts{i}')!\n";
         exit 1;
     }
 
     # dump config as string
-    my $Config = $CommonObject{YAMLObject}->Dump( Data => $Webservice->{Config} );
+    my $Config = $Kernel::OM->Get('Kernel::System::YAML')->Dump( Data => $Webservice->{Config} );
     print "$Config\n";
     exit 0;
 }
@@ -205,14 +189,14 @@ if ( lc( $Opts{a} ) eq 'delete' ) {
     }
 
     # get webservice
-    my $Webservice = $CommonObject{WebserviceObject}->WebserviceGet( ID => $Opts{i} );
+    my $Webservice = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice')->WebserviceGet( ID => $Opts{i} );
     if ( !$Webservice ) {
         print STDERR "ERROR: No such webservice with id (-i '$Opts{i}')!\n";
         exit 1;
     }
 
     # webservice lookup
-    my $Success = $CommonObject{WebserviceObject}->WebserviceDelete(
+    my $Success = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice')->WebserviceDelete(
         ID     => $Opts{i},
         UserID => 1,
     );
