@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # --
 # scripts/restore.pl - the restore script
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -30,12 +30,7 @@ use lib dirname($RealBin) . "/Kernel/cpan-lib";
 
 use Getopt::Std;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Time;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::DB;
+use Kernel::System::ObjectManager;
 
 # get options
 my %Opts;
@@ -44,7 +39,7 @@ my $DBDump = '';
 getopt( 'hbd', \%Opts );
 if ( exists $Opts{h} ) {
     print "restore.pl - restore script\n";
-    print "Copyright (C) 2001-2014 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n";
     print "usage: restore.pl -b /data_backup/<TIME>/ -d /opt/otrs/\n";
     exit 1;
 }
@@ -73,22 +68,18 @@ if ( -e "$Opts{b}/Config.tar.gz" ) {
 }
 
 # create common objects
-my %CommonObject;
-$CommonObject{ConfigObject} = Kernel::Config->new();
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    LogPrefix => 'OTRS-Restore',
-    %CommonObject,
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-restore.pl',
+    },
 );
-$CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
-$CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
-$CommonObject{DBObject}   = Kernel::System::DB->new(%CommonObject);
-my $DatabaseHost = $CommonObject{ConfigObject}->Get('DatabaseHost');
-my $Database     = $CommonObject{ConfigObject}->Get('Database');
-my $DatabaseUser = $CommonObject{ConfigObject}->Get('DatabaseUser');
-my $DatabasePw   = $CommonObject{ConfigObject}->Get('DatabasePw');
-my $DatabaseDSN  = $CommonObject{ConfigObject}->Get('DatabaseDSN');
-my $ArticleDir   = $CommonObject{ConfigObject}->Get('ArticleDir');
+
+my $DatabaseHost = $Kernel::OM->Get('Kernel::Config')->Get('DatabaseHost');
+my $Database     = $Kernel::OM->Get('Kernel::Config')->Get('Database');
+my $DatabaseUser = $Kernel::OM->Get('Kernel::Config')->Get('DatabaseUser');
+my $DatabasePw   = $Kernel::OM->Get('Kernel::Config')->Get('DatabasePw');
+my $DatabaseDSN  = $Kernel::OM->Get('Kernel::Config')->Get('DatabaseDSN');
+my $ArticleDir   = $Kernel::OM->Get('Kernel::Config')->Get('ArticleDir');
 
 # check db backup support
 if ( $DatabaseDSN =~ m/:mysql/i ) {
@@ -122,38 +113,36 @@ for my $CMD ( 'cp', 'tar', $DBDump ) {
 }
 
 # check database env
-if ( $CommonObject{DBObject} ) {
-    if ( $DB =~ m/mysql/i ) {
-        $CommonObject{DBObject}->Prepare( SQL => "SHOW TABLES" );
-        my $Check = 0;
-        while ( my @RowTmp = $CommonObject{DBObject}->FetchrowArray() ) {
-            $Check++;
-        }
-        if ($Check) {
-            print STDERR
-                "ERROR: Already existing tables in this database. A empty database is required for restore!\n";
-            exit 1;
-        }
+if ( $DB =~ m/mysql/i ) {
+    $Kernel::OM->Get('Kernel::System::DB')->Prepare( SQL => "SHOW TABLES" );
+    my $Check = 0;
+    while ( my @RowTmp = $Kernel::OM->Get('Kernel::System::DB')->FetchrowArray() ) {
+        $Check++;
     }
-    else {
-        $CommonObject{DBObject}->Prepare(
-            SQL =>
-                "SELECT table_name FROM information_schema.tables WHERE table_catalog = 'otrs' AND table_schema = 'public'",
-        );
-        my $Check = 0;
-        while ( my @RowTmp = $CommonObject{DBObject}->FetchrowArray() ) {
-            $Check++;
-        }
-        if ($Check) {
-            print STDERR
-                "ERROR: Already existing tables in this database. A empty database is required for restore!\n";
-            exit 1;
-        }
+    if ($Check) {
+        print STDERR
+            "ERROR: Already existing tables in this database. A empty database is required for restore!\n";
+        exit 1;
+    }
+}
+else {
+    $Kernel::OM->Get('Kernel::System::DB')->Prepare(
+        SQL =>
+            "SELECT table_name FROM information_schema.tables WHERE table_catalog = 'otrs' AND table_schema = 'public'",
+    );
+    my $Check = 0;
+    while ( my @RowTmp = $Kernel::OM->Get('Kernel::System::DB')->FetchrowArray() ) {
+        $Check++;
+    }
+    if ($Check) {
+        print STDERR
+            "ERROR: Already existing tables in this database. A empty database is required for restore!\n";
+        exit 1;
     }
 }
 
 # restore
-my $Home = $CommonObject{ConfigObject}->Get('Home');
+my $Home = $Kernel::OM->Get('Kernel::Config')->Get('Home');
 chdir($Home);
 
 # extract application
