@@ -1,5 +1,6 @@
 // --
-// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+// Core.Agent.Admin.GenericAgent.js - provides the special module functions for the GenericInterface job.
+// Copyright (C) 2003-2013 OTRS AG, http://otrs.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -44,7 +45,7 @@ Core.Agent.Admin.GenericAgent = (function (TargetNS) {
             var Size = parseInt($(this).attr('size'), 10),
                 $SelectField = $(this),
                 SelectID = this.id,
-                ButtonHTML = '<a href="#" title="' + TargetNS.Localization.RemoveSelection + '" class="GenericAgentClearSelect" data-select="' + SelectID + '"><span>' + TargetNS.Localization.RemoveSelection + '</span><i class="icon-undo"></i></a>';
+                ButtonHTML = '<a href="#" title="' + TargetNS.Localization.RemoveSelection + '" class="GenericAgentClearSelect" data-select="' + SelectID + '"><span>' + TargetNS.Localization.RemoveSelection + '</span><i class="fa fa-undo"></i></a>';
 
 
             // Only handle select fields with a size > 1, leave all single-dropdown fields untouched
@@ -106,9 +107,10 @@ Core.Agent.Admin.GenericAgent = (function (TargetNS) {
             return false;
         });
 
-        $('#AddEvent').bind('click', function (){
+        $('#AddEvent').bind('click', function (Event){
             if ( $('#EventType').val() !== null ) {
                 TargetNS.AddEvent( $('#EventType').val() );
+                return false;
             }
         });
 
