@@ -1,5 +1,6 @@
 // --
-// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+// Core.Agent.Login.js - provides the special module functions for the login
+// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -25,7 +26,7 @@ Core.Agent.Login = (function (TargetNS) {
      */
     TargetNS.Init = function (LoginFailed) {
         // Browser is too old
-        if (!Core.Debug.BrowserCheckAgent()) {
+        if (!Core.Agent.SupportedBrowser) {
             $('#LoginBox').hide();
             $('#OldBrowser').show();
             return;
@@ -55,6 +56,11 @@ Core.Agent.Login = (function (TargetNS) {
         if (LoginFailed) {
             Core.UI.Shake($('#LoginBox'));
         }
+
+        // if in PreLogin mode, automatically submit form
+        if ( $('#LoginBox').hasClass('PreLogin') ) {
+            $('#LoginBox form').submit();
+        }
     };
 
     return TargetNS;
