@@ -1,5 +1,6 @@
 // --
-// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+// Core.Debug.js - provides debugging functions
+// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -81,52 +82,6 @@ Core.Debug = (function (TargetNS) {
     };
     /*jslint evil: false */
 
-    /**
-     * @exports TargetNS.BrowserCheck as Core.Debug.BrowserCheckAgent
-     * @function
-     * @description
-     *      Checks if the used browser is not on the OTRS browser blacklist
-     *      of the agent interface.
-     * @return true if the used browser is *not* on the black list.
-     */
-    TargetNS.BrowserCheckAgent = function () {
-        var AppropriateBrowser = true,
-            BrowserBlackList = Core.Config.Get('BrowserBlackList::Agent');
-        if (typeof BrowserBlackList !== 'undefined') {
-            $.each(BrowserBlackList, function (Key, Value) {
-                if ($.isFunction(Value)) {
-                    if (Value()) {
-                        AppropriateBrowser = false;
-                    }
-                }
-            });
-            return AppropriateBrowser;
-        }
-    };
-
-    /**
-     * @exports TargetNS.BrowserCheck as Core.Debug.BrowserCheckCustomer
-     * @function
-     * @description
-     *      Checks if the used browser is not on the OTRS browser blacklist
-     *      of the customer interface.
-     * @return true if the used browser is *not* on the black list.
-     */
-    TargetNS.BrowserCheckCustomer = function () {
-        var AppropriateBrowser = true,
-        BrowserBlackList = Core.Config.Get('BrowserBlackList::Customer');
-        if (typeof BrowserBlackList !== 'undefined') {
-            $.each(BrowserBlackList, function (Key, Value) {
-                if ($.isFunction(Value)) {
-                    if (Value()) {
-                        AppropriateBrowser = false;
-                    }
-                }
-            });
-            return AppropriateBrowser;
-        }
-    };
-
     /**
      * @exports TargetNS.SimulateRTLPage as Core.Debug.SimulateRTLPage
      * @function
