@@ -1,5 +1,6 @@
 // --
-// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+// Core.Form.ErrorTooltips.js - provides provides Tooltip functions
+// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -53,7 +54,7 @@ Core.Form.ErrorTooltips = (function (TargetNS) {
         /*
          * Now create and fill the tooltip with the error message.
          */
-        $Tooltip = $('<div class="Tooltip ' + TongueClass + '"><div class="Tongue"></div></div>');
+        $Tooltip = $('<div class="Tooltip ' + TongueClass + '"></div>');
         $TooltipContent.html(TooltipContent);
         $Tooltip.append($TooltipContent);
 
