@@ -1,5 +1,6 @@
 // --
-// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+// Core.Form.Validate.js - provides functions for validating form inputs
+// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -90,7 +91,7 @@ Core.Form.Validate = (function (TargetNS) {
         // save value of element for a later check if field value was changed.
         // if the field has a servererror class and the value was not changed,
         // keep the error class.
-        if ($Element.is('input:checkbox, input:radio')) {
+        if ($Element.is('input[type="checkbox"], input[type="radio"]')) {
             $Element.data('ValidateOldValue', $Element.prop('checked'));
         }
         else {
@@ -120,6 +121,11 @@ Core.Form.Validate = (function (TargetNS) {
                 $Element.focus();
             }, 0);
         }
+
+        // if the element is within a collapsed widget, expand that widget to show the error message to the user
+        if ($Element.closest('.WidgetSimple.Collapsed').find('.WidgetAction.Toggle > a').length) {
+            $Element.closest('.WidgetSimple.Collapsed').find('.WidgetAction.Toggle > a').trigger('click');
+        }
     };
 
     /**
@@ -136,7 +142,7 @@ Core.Form.Validate = (function (TargetNS) {
         // check ServerError
         // if the field value has not changed, do not remove error class
         if ($Element.hasClass(Options.ServerErrorClass)) {
-            if ($Element.is('input:checkbox, input:radio')) {
+            if ($Element.is('input[type="checkbox"], input[type="radio"]')) {
                 ElementValue = $Element.prop('checked');
             }
             else {
@@ -230,7 +236,7 @@ Core.Form.Validate = (function (TargetNS) {
         }
 
         // checkable inputs
-        if ($Element.filter('input:checkbox, input:radio').length) {
+        if ($Element.filter('input[type="checkbox"], input[type="radio"]').length) {
             return $Element.filter(':checked').length > 0;
         }
 
@@ -272,14 +278,22 @@ Core.Form.Validate = (function (TargetNS) {
         DateObject,
         RegExYear,
         RegExMonth,
+        RegExHour,
+        RegExMinute,
         YearElement = '',
         MonthElement = '',
+        HourElement = '',
+        MinuteElement = '',
         DateYearClassPrefix = 'Validate_DateYear_',
         DateMonthClassPrefix = 'Validate_DateMonth_',
+        DateHourClassPrefix = 'Validate_DateHour_',
+        DateMinuteClassPrefix = 'Validate_DateMinute_',
         DateCheck;
 
         RegExYear = new RegExp(DateYearClassPrefix);
         RegExMonth = new RegExp(DateMonthClassPrefix);
+        RegExHour = new RegExp(DateHourClassPrefix);
+        RegExMinute = new RegExp(DateMinuteClassPrefix);
         $.each(Classes.split(' '), function (Index, Value) {
             if (RegExYear.test(Value)) {
                 YearElement = Value.replace(DateYearClassPrefix, '');
@@ -287,19 +301,37 @@ Core.Form.Validate = (function (TargetNS) {
             if (RegExMonth.test(Value)) {
                 MonthElement = Value.replace(DateMonthClassPrefix, '');
             }
+            if (RegExHour.test(Value)) {
+                HourElement = Value.replace(DateHourClassPrefix, '');
+            }
+            if (RegExMinute.test(Value)) {
+                MinuteElement = Value.replace(DateMinuteClassPrefix, '');
+            }
         });
         if (YearElement.length && MonthElement.length && $('#' + YearElement).length && $('#' + MonthElement).length) {
             DateObject = new Date($('#' + YearElement).val(), $('#' + MonthElement).val() - 1, Value);
             if (DateObject.getFullYear() === parseInt($('#' + YearElement).val(), 10) &&
                 DateObject.getMonth() + 1 === parseInt($('#' + MonthElement).val(), 10) &&
                 DateObject.getDate() === parseInt(Value, 10)) {
-                if (Options.DateInFuture) {
-                    DateCheck = new Date();
+
+                DateCheck = new Date();
+                if ( MinuteElement.length && HourElement.length ) {
+                    DateObject.setHours($('#' + HourElement).val(), $('#' + MinuteElement).val(), 0, 0);
+                }
+                else {
                     DateCheck.setHours(0, 0, 0, 0);
+                }
+
+                if (Options.DateInFuture) {
                     if (DateObject >= DateCheck) {
                         return true;
                     }
                 }
+                else if (Options.DateNotInFuture) {
+                    if (DateObject <= DateCheck) {
+                        return true;
+                    }
+                }
                 else {
                     return true;
                 }
@@ -313,9 +345,25 @@ Core.Form.Validate = (function (TargetNS) {
     }, "");
 
     $.validator.addMethod("Validate_DateInFuture", function (Value, Element) {
+        var $DateSelection = $(Element).parent().find('input[type=checkbox].DateSelection');
+        // do not do this check for unchecked date/datetime fields
+        // check first if the field exists to regard the check for the pending reminder field
+        if ($DateSelection.length && !$DateSelection.prop("checked")) {
+            return true;
+        }
         return DateValidator(Value, Element, { DateInFuture: true });
     }, "");
 
+    $.validator.addMethod("Validate_DateNotInFuture", function (Value, Element) {
+        var $DateSelection = $(Element).parent().find('input[type=checkbox].DateSelection');
+        // do not do this check for unchecked date/datetime fields
+        // check first if the field exists to regard the check for the pending reminder field
+        if ($DateSelection.length && !$DateSelection.prop("checked")) {
+            return true;
+        }
+        return DateValidator(Value, Element, { DateNotInFuture: true });
+    }, "");
+
     $.validator.addMethod("Validate_DateHour", function (Value, Element) {
         return (parseInt(Value, 10) >= 0 && parseInt(Value, 10) < 24);
     }, "");
@@ -354,6 +402,35 @@ Core.Form.Validate = (function (TargetNS) {
         }
     });
 
+    /*
+     * Adds a generic method to compare if the given fields are not equal
+     */
+    $.validator.addMethod("Validate_NotEqual", function (Value, Element) {
+        var Classes = $(Element).attr('class'),
+            GroupClass = '',
+            ApplyRule = 1,
+            EqualClassPrefix = 'Validate_NotEqual_',
+            RegExEqual;
+
+        RegExEqual = new RegExp(EqualClassPrefix);
+        $.each(Classes.split(' '), function (Index, ClassValue) {
+            if (RegExEqual.test(ClassValue)) {
+                GroupClass = ClassValue;
+            }
+        });
+
+        if ( GroupClass !== '' ) {
+            $(Element).closest('fieldset fieldset.TableLike').find('.' + GroupClass).each( function () {
+                if ( $(Element).attr('id') !== $(this).attr('id') && $(this).val() === Value ) {
+                    ApplyRule = 0;
+                }
+            });
+
+        }
+
+        return ApplyRule;
+    });
+
     $.validator.addClassRules("Validate_Required", {
         Validate_Required: true
     });
@@ -407,6 +484,10 @@ Core.Form.Validate = (function (TargetNS) {
         Validate_Equal: true
     });
 
+    $.validator.addClassRules("Validate_NotEqual", {
+        Validate_NotEqual: true
+    });
+
     function GetDependentElements(Element) {
         var Classes = $(Element).attr('class'),
         DependentElementIDs = [],
@@ -435,7 +516,7 @@ Core.Form.Validate = (function (TargetNS) {
 
         for (I = 0; I < DependentElementIDs.length; I++) {
             $DependentElement = $('#' + $.trim(DependentElementIDs[I]));
-            if (ValidatorMethodRequired($DependentElement.val(), $DependentElement[0])) {
+            if ($DependentElement.length && ValidatorMethodRequired($DependentElement.val(), $DependentElement[0])) {
                 return ValidatorMethodRequired(Value, Element);
             }
         }
@@ -460,7 +541,7 @@ Core.Form.Validate = (function (TargetNS) {
 
         for (I = 0; I < DependentElementIDs.length; I++) {
             $DependentElement = $('#' + $.trim(DependentElementIDs[I]));
-            if (ValidatorMethodRequired($DependentElement.val(), $DependentElement[0])) {
+            if ($DependentElement.length && ValidatorMethodRequired($DependentElement.val(), $DependentElement[0])) {
                 return true;
             }
         }
