@@ -1,5 +1,6 @@
 // --
-// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+// Core.UI.DnD.js - provides all UI functions
+// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -73,12 +74,14 @@ Core.UI.DnD = (function (TargetNS) {
         }
     );
      */
+
     TargetNS.Sortable = function ($Elements, Options) {
         $Elements.sortable({
             handle: Options.Handle,
             items: Options.Items,
             axis: Options.Axis,
             placeholder: Options.Placeholder,
+            helper: Options.Helper,
             containment: Options.Containment,
             forcePlaceholderSize: true,
             distance: Options.Distance,
