@@ -1,5 +1,6 @@
 // --
-// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+// Core.UI.TreeSelection.js - Tree selection for select elements
+// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -475,19 +476,12 @@ Core.UI.TreeSelection = (function (TargetNS) {
                 DisabledAttr = ' disabled="disabled"';
             }
 
-            // append the delete filter value on top
-            // and do not push it to the array
-            if ( Key === 'DeleteFilter' ) {
-                $FieldObj.append('<option value="' + Key + '"' + SelectedAttr + DisabledAttr + '>' + Value + '</option>');
-            }
-            else {
-                SelectData.push({
-                    'Key'          : Key,
-                    'Value'        : Value,
-                    'SelectedAttr' : SelectedAttr,
-                    'DisabledAttr' : DisabledAttr
-                });
-            }
+            SelectData.push({
+                'Key'          : Key,
+                'Value'        : Value,
+                'SelectedAttr' : SelectedAttr,
+                'DisabledAttr' : DisabledAttr
+            });
         });
 
         SelectData.sort(function(a, b) {
