@@ -1,5 +1,6 @@
 // --
-// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+// Core.UI.js - provides all UI functions
+// Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -66,6 +67,7 @@ Core.UI = (function (TargetNS) {
                         .end()
                         .end()
                         .attr('aria-expanded', $that.closest("div.Header").parent('div').hasClass('Expanded'));
+                        Core.App.Publish('Event.UI.ToggleWidget', [$WidgetElement]);
                 }
 
                 if (Animate && Core.Config.Get('AnimationEnabled')) {
@@ -162,17 +164,23 @@ Core.UI = (function (TargetNS) {
 
         // e.g. 'table td.Checkbox' or 'div.Checkbox'
         $Element.unbind('click.CheckboxSelection').bind('click.CheckboxSelection', function (Event) {
-            var $Checkbox = $(this).find('input:checkbox');
+            var $Checkbox = $(this).find('input[type="checkbox"]');
 
             if (!$Checkbox.length) {
                 return;
             }
 
+            if ($(Event.target).is('input[type="checkbox"]')) {
+                return;
+            }
+
+            Event.stopPropagation();
+
             $Checkbox
                 .prop('checked', !$Checkbox.prop('checked'))
                 .triggerHandler('click');
 
-            Event.stopPropagation();
+
         });
     };
 
